<?php
/**
 * Template for video post format.
 */
global $vlc_blog_style, $volcanno_options, $vlc_is_retina, $post, $vlc_post_timeline_position, $volcanno_theme_config;

// post audio
$audio_string = get_post_custom_values('pt_audio_files', get_the_ID());

// if Core plugin isn't activated or user didn't fill neccesarry data 
// for this post format, load default post format
if (!RWMB_META_BOX || empty($audio_string)) {
    get_template_part('content');
    return true;
}

// list item array of classes
$list_classes = array('blog-post');

// urls to audio files
$valid_urls = apply_filters('volcanno_verify_post_audio', $audio_string);
$encoded_urls = json_encode($valid_urls);

//get post meta
$post_title = get_the_title();
$post_permalink = get_permalink();
$post_author_name = get_the_author_meta('display_name');
$post_author_url = get_author_posts_url(get_the_author_meta('ID'));

//get thumbnail URL
$thumbnail = get_post_thumbnail_id();
$image_url = wp_get_attachment_url($thumbnail, 'full');

// get image size
$blog_image_size = apply_filters('volcanno_blog_image_width', $vlc_blog_style);

// if user is on retina device, double the size of image
if ($vlc_is_retina) {
    $blog_image_size['width'] = 2 * $blog_image_size['width'];
    $blog_image_size['height'] = 2 * $blog_image_size['height'];
}

// check if cropping images is disabled
$image_croppping = is_single() ? $volcanno_options['blog_single_image_crop'] : $volcanno_options['blog_image_crop'];

$post_image = '';
if (!empty($image_url)) {
    if ($image_croppping == '0') {
        $params = array('width' => $blog_image_size['width']);
        $featured_image = bfi_thumb($image_url, $params); //resize & crop the image
    } else {
        $params = array('width' => $blog_image_size['width'], 'height' => $blog_image_size['height']);
        $featured_image = bfi_thumb($image_url, $params); //resize & crop the image 
    }

    $post_image = "<img src='{$featured_image}' alt='{$post_title}' />";
}

if ($vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-masonry-sidebar')
    $list_classes[] = 'isotope-item';

// read more button
$read_more = $volcanno_options['blog_hide_readmore'];
$read_more_text = $volcanno_options['blog_readmore_text'];

// show/hide post meta
$single_post_meta = apply_filters('volcanno_blog_single_meta', $volcanno_options['blog_single_meta']);

// post format
$post_format = get_post_format();
if (empty($post_format)) {
    $post_format = esc_html__("Standard", 'pi_framework');
}
?>
<?php if ($vlc_blog_style == 'blog-post-timeline'): ?>
    <div class="post-timeline-item post-timeline-<?php echo sanitize_html_class($vlc_post_timeline_position) ?> animated" data-animate="fadeIn">
    <?php else: ?>
        <!-- .blog-post.format-standard start -->
        <li id="post-<?php the_ID(); ?>" <?php post_class($list_classes); ?>>
        <?php endif; ?>

        <?php if ($vlc_blog_style == 'blog-post-small' || $vlc_blog_style == 'blog-post-large') { ?>

            <?php if (!is_single() || (is_single() && $single_post_meta == '1')): ?>
                <ul class="post-info">
                    <li class="post-date">
                        <span class="month"><?php mb_strtoupper(the_time('M')); ?></span>
                        <span class="day"><?php the_time('d') ?></span>
                    </li>

                    <li class="post-avatar">
                        <div class="avatar-container">
                            <img src="<?php echo TEMPLATEURL ?>/img/blog/user-3.jpg" alt=""/>
                        </div>

                        <a href="<?php echo esc_url_raw($post_author_url); ?>"><?php echo esc_html($post_author_name); ?></a>
                    </li>

                    <li class="post-comment-number">
                        <a href="<?php echo esc_url($post_permalink) ?>"><i class="fa fa-comments"></i><?php echo get_comments_number(); ?></a>
                    </li>
                </ul><!-- .post-info end -->
            <?php endif; ?>

            <div class="post-media">
                <div class="audio-player with-image">
                    <div id="jquery_jplayer_1" class="jp-jplayer"></div>

                    <div id="jp_container_1" class="jp-audio">
                        <div class="jp-type-playlist">
                            <div class="jp-gui jp-interface">
                                <ul class="jp-controls">
                                    <li><a href="javascript:;" class="jp-previous" tabindex="1"><?php esc_html_e('previous', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-play" tabindex="1"><?php esc_html_e('play', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-pause" tabindex="1"><?php esc_html_e('pause', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-next" tabindex="1"><?php esc_html_e('next', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-stop" tabindex="1"><?php esc_html_e('stop', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-mute" tabindex="1" title="mute"><?php esc_html_e('mute', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-unmute" tabindex="1" title="unmute"><?php esc_html_e('unmute', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-volume-max" tabindex="1" title="max volume"><?php esc_html_e('max volume', 'pi_framework') ?></a></li>
                                </ul>
                                <div class="jp-progress">
                                    <div class="jp-seek-bar">
                                        <div class="jp-play-bar"></div>
                                    </div>
                                </div>
                                <div class="jp-volume-bar">
                                    <div class="jp-volume-bar-value"></div>
                                </div>
                                <div class="jp-time-holder">
                                    <div class="jp-current-time"></div>
                                    <div class="jp-duration"></div>
                                </div>
                                <ul class="jp-toggles">
                                    <li><a href="javascript:;" class="jp-shuffle" tabindex="1" title="shuffle"><?php esc_html_e('shuffle', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-shuffle-off" tabindex="1" title="shuffle off"><?php esc_html_e('shuffle off', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-repeat" tabindex="1" title="repeat"><?php esc_html_e('repeat', 'pi_framework') ?></a></li>
                                    <li><a href="javascript:;" class="jp-repeat-off" tabindex="1" title="repeat off"><?php esc_html_e('repeat off', 'pi_framework') ?></a></li>
                                </ul>
                            </div>
                            <div class="jp-no-solution">
                                <span><?php esc_html_e('Update Required', 'pi_framework') ?></span>
                                <?php echo wp_kses(__('To play the media you will need to either update your browser to a recent version or update your <a href="http://get.adobe.com/flashplayer/" target="_blank">Flash plugin', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']) ?></a>.
                            </div>
                        </div>
                    </div><!-- .jp-audio -->
                </div><!-- audio-player end -->
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                    
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                    <li class="post-tags fa fa-tags"><?php the_tags('', ', ') ?></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>
                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo!empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } else if ($vlc_blog_style == 'blog-post-masonry-sidebar' || $vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-timeline') { ?>
            <div class="post-media">
                <?php if ($vlc_blog_style != 'blog-post-timeline') { ?>
                    <div class="audio-player with-image">
                        <div id="jquery_jplayer_1" class="jp-jplayer"></div>

                        <div id="jp_container_1" class="jp-audio">
                            <div class="jp-type-playlist">
                                <div class="jp-gui jp-interface">
                                    <ul class="jp-controls">
                                        <li><a href="javascript:;" class="jp-previous" tabindex="1"><?php esc_html_e('previous', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-play" tabindex="1"><?php esc_html_e('play', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-pause" tabindex="1"><?php esc_html_e('pause', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-next" tabindex="1"><?php esc_html_e('next', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-stop" tabindex="1"><?php esc_html_e('stop', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-mute" tabindex="1" title="mute"><?php esc_html_e('mute', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-unmute" tabindex="1" title="unmute"><?php esc_html_e('unmute', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-volume-max" tabindex="1" title="max volume"><?php esc_html_e('max volume', 'pi_framework') ?></a></li>
                                    </ul>
                                    <div class="jp-progress">
                                        <div class="jp-seek-bar">
                                            <div class="jp-play-bar"></div>
                                        </div>
                                    </div>
                                    <div class="jp-volume-bar">
                                        <div class="jp-volume-bar-value"></div>
                                    </div>
                                    <div class="jp-time-holder">
                                        <div class="jp-current-time"></div>
                                        <div class="jp-duration"></div>
                                    </div>
                                    <ul class="jp-toggles">
                                        <li><a href="javascript:;" class="jp-shuffle" tabindex="1" title="shuffle"><?php esc_html_e('shuffle', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-shuffle-off" tabindex="1" title="shuffle off"><?php esc_html_e('shuffle off', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-repeat" tabindex="1" title="repeat"><?php esc_html_e('repeat', 'pi_framework') ?></a></li>
                                        <li><a href="javascript:;" class="jp-repeat-off" tabindex="1" title="repeat off"><?php esc_html_e('repeat off', 'pi_framework') ?></a></li>
                                    </ul>
                                </div>
                                <div class="jp-no-solution">
                                    <span><?php esc_html_e('Update Required', 'pi_framework') ?></span>
                                    <?php echo wp_kses(__('To play the media you will need to either update your browser to a recent version or update your <a href="http://get.adobe.com/flashplayer/" target="_blank">Flash plugin', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']) ?></a>.
                                </div>
                            </div>
                        </div><!-- .jp-audio -->
                    </div><!-- audio-player end -->
                <?php } else if ($vlc_blog_style == 'blog-post-timeline' && !empty($post_image)) { ?>
                    <a href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo wp_kses_post($post_image); ?>
                    </a>
                <?php } ?>                
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                
                    <li class="fa fa-calendar-o"><span><?php the_time() ?></span></li>
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>

                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo !empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>                        
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } ?>  
        <script>
            jQuery(function () {
                var audioEncodedUrls = <?php echo $encoded_urls ?>;
                var audioSwfPath = <?php echo '"' . TEMPLATEURL . '/js/jplayer/"'; ?>;
                VolcannoFunctions.audioPostInit(audioEncodedUrls, audioSwfPath);
            });

        </script>

        <?php if ($vlc_blog_style == 'blog-post-timeline') { ?>
    </div>
<?php } else { ?>
    </li><!-- blog post end -->
<?php } ?>