<?php
/**
 * The default template for displaying content
 */
global $vlc_blog_style, $volcanno_options, $vlc_is_retina, $post, $vlc_post_timeline_position;

// if Core plugin isn't activated or user didn't fill neccesarry data 
// for this post format, load default post format
if (!RWMB_META_BOX) {
    get_template_part('content');
    return true;
}

$gallery_images = rwmb_meta('pt_gallery_images', 'type=image&size=full', get_the_ID());

if (empty($gallery_images)) {
    get_template_part('content');
    return true;
}

// list item array of classes
$list_classes = array('blog-post');

//get post meta
$post_title = get_the_title();
$post_permalink = get_permalink();
$post_author_name = get_the_author_meta('display_name');
$post_author_url = get_author_posts_url(get_the_author_meta('ID'));

// get image size
$blog_image_size = apply_filters('volcanno_blog_image_width', $vlc_blog_style);

// if user is on retina device, double the size of image
if ($vlc_is_retina) {
    $blog_image_size['width'] = 2 * $blog_image_size['width'];
    $blog_image_size['height'] = 2 * $blog_image_size['height'];
}

// add custom classes if blog style is masonry
if ($vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-masonry-sidebar')
    $list_classes[] = 'isotope-item';

// auto sliding
$auto_sliding = $volcanno_options['blog_gallery_slider_autoslide'];
$disable_auto_sliding = $auto_sliding == '0' || empty($auto_sliding) ? 'true' : 'false';

// slide pause time
$slider_pause_time = $volcanno_options['blog_gallery_slider_delay'];
$slider_pause_time = empty($slider_pause_time) ? '3000' : $slider_pause_time;

// gallery post images
$gallery_image = '';

// check if cropping images is disabled
$image_croppping = is_single() ? $volcanno_options['blog_single_image_crop'] : $volcanno_options['blog_image_crop'];

// generate image HTML
foreach ($gallery_images as $image) {
    $image_url = $image['url'];

    if ($image_croppping == '0') {
        $params = array('width' => $blog_image_size['width']);
        $featured_image = bfi_thumb($image_url, $params); //resize & crop the image
    } else {
        $params = array('width' => $blog_image_size['width'], 'height' => $blog_image_size['height']);
        $featured_image = bfi_thumb($image_url, $params); //resize & crop the image 
    }
    $featured_image = esc_url($featured_image);

    $gallery_image .= "<img src='{$featured_image}' alt='{$image['title']}' />";
}
$gallery_post_slider = "<div id='post-slider' class='nivoSlider blog-slider nivo-wrapper'>{$gallery_image}</div>";

// read more button
$read_more = $volcanno_options['blog_hide_readmore'];
$read_more_text = $volcanno_options['blog_readmore_text'];

// show/hide post meta
$single_post_meta = apply_filters('volcanno_blog_single_meta', $volcanno_options['blog_single_meta']);

// post format
$post_format = get_post_format();
if (empty($post_format)) {
    $post_format = esc_html__("Standard", 'pi_framework');
}

?>

<?php if ($vlc_blog_style == 'blog-post-timeline'): ?>
    <div class="post-timeline-item post-timeline-<?php echo sanitize_html_class($vlc_post_timeline_position) ?> animated" data-animate="fadeIn">
    <?php else: ?>
        <!-- .blog-post.format-standard start -->
        <li id="post-<?php the_ID(); ?>" <?php post_class($list_classes); ?>>
        <?php endif; ?>

        <?php if ($vlc_blog_style == 'blog-post-small' || $vlc_blog_style == 'blog-post-large') { ?>

            <?php if (!is_single() || (is_single() && $single_post_meta == '1')): ?>
                <ul class="post-info">
                    <li class="post-date">
                        <span class="month"><?php mb_strtoupper(the_time('M')); ?></span>
                        <span class="day"><?php the_time('d') ?></span>
                    </li>

                    <li class="post-avatar">
                        <div class="avatar-container">
                            <img src="<?php echo TEMPLATEURL ?>/img/blog/user-3.jpg" alt=""/>
                        </div>

                        <a href="<?php echo esc_url($post_author_url); ?>"><?php echo esc_html($post_author_name); ?></a>
                    </li>

                    <li class="post-comment-number">
                        <a href="<?php echo esc_url($post_permalink) ?>"><i class="fa fa-comments"></i><?php echo get_comments_number(); ?></a>
                    </li>
                </ul><!-- .post-info end -->
            <?php endif; ?>

            <div class="post-media">
                <div class="nivo-wrapper">
                    <?php echo wp_kses_post($gallery_post_slider); ?>
                </div>            
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                    
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                    <li class="post-tags fa fa-tags"><?php the_tags('', ', ') ?></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>
                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo!empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } else if ($vlc_blog_style == 'blog-post-masonry-sidebar' || $vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-timeline') { ?>
            <div class="post-media">
                <?php if ($vlc_blog_style != 'blog-post-timeline') { ?>
                    <?php echo wp_kses_post($gallery_post_slider); ?>
                <?php } else if ($vlc_blog_style == 'blog-post-timeline' && !empty($post_image)) { ?>
                    <a href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo wp_kses_post($post_image); ?>
                    </a>
                <?php } ?>
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                
                    <li class="fa fa-calendar-o"><span><?php the_time() ?></span></li>
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>

                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo!empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } ?>  
        <script>
            jQuery(window).load(function () {
                VolcannoFunctions.gallery_post_slider(<?php echo esc_js($disable_auto_sliding) ?>, <?php echo esc_js($slider_pause_time) ?>, false, true);
            });
        </script>

        <?php if ($vlc_blog_style == 'blog-post-timeline') { ?>
    </div>
<?php } else { ?>
    </li><!-- blog post end -->
<?php } ?>