<?php
/**
 * Template for video post format.
 */
global $vlc_blog_style, $volcanno_options, $vlc_is_retina, $post, $vlc_post_timeline_position;

// post video
$post_video_url = get_post_meta(get_the_ID(), 'pt_video_url', true);

//get post meta
$post_title = get_the_title();
$post_permalink = get_permalink();
$post_author_name = get_the_author_meta('display_name');
$post_author_url = get_author_posts_url(get_the_author_meta('ID'));

// if Core plugin isn't activated or user didn't fill neccesarry data 
// for this post format, load default post format
if (!RWMB_META_BOX || empty($post_video_url)) {
    get_template_part('content');
    return true;
}

// list item array of classes
$list_classes = array('blog-post');

if ($vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-masonry-sidebar')
    $list_classes[] = 'isotope-item';

// read more button
$read_more = $volcanno_options['blog_hide_readmore'];
$read_more_text = $volcanno_options['blog_readmore_text'];

// show/hide post meta
$single_post_meta = apply_filters('volcanno_blog_single_meta', $volcanno_options['blog_single_meta']);

// post format
$post_format = get_post_format();
if (empty($post_format)) {
    $post_format = esc_html__("Standard", 'pi_framework');
}
?>
<?php if ($vlc_blog_style == 'blog-post-timeline'): ?>
    <div class="post-timeline-item post-timeline-<?php echo sanitize_html_class($vlc_post_timeline_position) ?> animated" data-animate="fadeIn">
    <?php else: ?>
        <!-- .blog-post.format-standard start -->
        <li id="post-<?php the_ID(); ?>" <?php post_class($list_classes); ?>>
        <?php endif; ?>

        <?php if ($vlc_blog_style == 'blog-post-small' || $vlc_blog_style == 'blog-post-large') { ?>

            <?php if (!is_single() || (is_single() && $single_post_meta == '1')): ?>
                <ul class="post-info">
                    <li class="post-date">
                        <span class="month"><?php mb_strtoupper(the_time('M')); ?></span>
                        <span class="day"><?php the_time('d') ?></span>
                    </li>

                    <li class="post-avatar">
                        <div class="avatar-container">
                            <img src="<?php echo TEMPLATEURL ?>/img/blog/user-3.jpg" alt=""/>
                        </div>

                        <a href="<?php echo esc_url($post_author_url); ?>"><?php echo esc_html($post_author_name); ?></a>
                    </li>

                    <li class="post-comment-number">
                        <a href="<?php echo esc_url($post_permalink) ?>"><i class="fa fa-comments"></i><?php echo get_comments_number(); ?></a>
                    </li>
                </ul><!-- .post-info end -->
            <?php endif; ?>

            <div class="post-media">
                <?php echo balanceTags($post_video_url); ?>
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                    
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                    <li class="post-tags fa fa-tags"><?php the_tags('', ', ') ?></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>
                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo !empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } else if ($vlc_blog_style == 'blog-post-masonry-sidebar' || $vlc_blog_style == 'blog-post-masonry-full' || $vlc_blog_style == 'blog-post-timeline') { ?>
            <div class="post-media">
                <?php if ($vlc_blog_style != 'blog-post-timeline') { ?>
                     <?php echo wp_kses_post($post_video_url); ?>
                <?php } else if ($vlc_blog_style == 'blog-post-timeline' && !empty($post_image)) { ?>
                    <a href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo wp_kses_post($post_image); ?>
                    </a>
                <?php } ?>
            </div><!-- .post-media end -->

            <article class="post-body">
                <a href="<?php echo esc_url($post_permalink) ?>">
                    <h2><?php the_title(); ?></h2>
                </a>

                <ul class="post-meta">                                
                    <li class="fa fa-calendar-o"><span><?php the_time() ?></span></li>
                    <li class="fa fa-camera-retro"><a href=""><?php echo esc_html($post_format) ?></a></li>
                </ul><!-- .post-meta end -->

                <?php
                if (is_single()) {
                    the_content();
                    wp_link_pages(array('before' => '<p class="wp-link-pages">Pages: ', 'after' => '</p>'));
                } else {
                    // if user inserts more tag get regular content instead excerpt
                    if (preg_match('/<!--more(.*?)?-->/', $post->post_content)) {
                        the_content();
                    } else {
                        the_excerpt();
                    }
                }
                ?>

                <?php if (!is_single() && $read_more == '1'): ?>
                    <a class="read-more" href="<?php echo esc_url($post_permalink) ?>">
                        <?php echo !empty($read_more_text) ? wp_kses($read_more_text, array('strong' => array())) : esc_html__('Read More', 'pi_framework') ?>
                    </a>
                <?php endif; ?>

                <?php
                if (is_single()) {
                    // echo post author content
                    do_action('volcanno_post_author_html');

                    // get comments html
                    comments_template('', true);
                }
                ?>
            </article><!-- .post-body end -->
        <?php } ?>

        <?php if ($vlc_blog_style == 'blog-post-timeline') { ?>
    </div>
<?php } else { ?>
    </li><!-- blog post end -->
<?php } ?>