<?php

/**
 * Class Volcanno_Theme_Importer
 *
 * This class provides the capability to import demo content as well as import widgets and WordPress menus
 *
 * @since 2.4
 *
 * @category VolcannoFramework
 * @author   Pixel Industry (based on work of Franklin M Gitonga http://radiumthemes.com/)
 * @link     http://pixel-industry.com
 *
 */
class Volcanno_Theme_Importer {

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    public $theme_options_file;

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    public $widgets;

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    public $content_demo;

    /**
     * Flag imported to prevent duplicates
     *
     * @since 2.2.0
     *
     * @var object
     */
    public $flag_as_imported = array();

    /**
     * Holds a copy of the object for easy reference.
     *
     * @since 2.2.0
     *
     * @var object
     */
    private static $instance;

    /**
     * Constructor. Hooks all interactions to initialize the class.
     *
     * @since 2.2.0
     */
    public function __construct() {

        self::$instance = $this;

        $this->content_demo = $this->demo_files;

        // add submenu page
        add_action('admin_menu', array($this, 'add_admin'));

        // enqueue stylesheets
        add_action('admin_enqueue_scripts', array($this, 'enqueue_stylesheet'));

        // enqueue script
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));

        // ajax call
        add_action('wp_ajax_vlc_import_demo', array($this, 'ajax_import_content'));
    }

    /**
     * Add Panel Page
     *
     * @since 2.2.0
     */
    public function add_admin() {

        add_submenu_page('volcanno_options', "One Click Install", "One Click Install", 'switch_themes', 'volcanno_demo_importer', array($this, 'demo_installer'));
    }

    /**
     * Add stylesheet to admin page
     * 
     * @since 2.4
     */
    public function enqueue_scripts($hook) {
        if (volcanno_ends_with($hook, '_page_volcanno_demo_importer')) {
            wp_enqueue_script('volcanno_demo_importer', get_template_directory_uri() . '/core/importer/importer.js', array(), '1.0', 'screen');
        }
    }

    /**
     * Add stylesheet to admin page
     * 
     * @since 2.3
     */
    public function enqueue_stylesheet($hook) {
        if (volcanno_ends_with($hook, '_page_volcanno_demo_importer')) {
            wp_enqueue_style('volcanno_demo_importer', get_template_directory_uri() . '/core/importer/importer.css', array(), '1.0', 'screen');
        }
    }

    /**
     * Outputs HTML
     *
     * @since 2.2.0
     *
     * @return [type] [description]
     */
    public function demo_installer() {
        ?>
        <div class="one-click-installer">
            <div class="demo-header">    
                <h2><?php esc_html_e('One Click Installer', 'pi_framework') ?></h2>
                <small><?php esc_html_e('Control Panel for installing Demo content.', 'pi_framework') ?></small>
            </div>

            <div class="demo-content">
                <div class="info">
                    <p class="note"><?php esc_html_e('Importing demo content (post, pages, images, theme settings, ...) is the easiest way to setup your theme. It will allow you to quickly edit everything instead of creating content from scratch.', 'pi_framework') ?></p>

                    <p><?php esc_html_e('When you import the data following things will happen:', 'pi_framework') ?></p>

                    <ul>
                        <li><?php esc_html_e('No existing posts, pages, categories, images, custom post types or any other data will be deleted or modified.', 'pi_framework') ?></li>
                        <li><?php esc_html_e('If all content or Pages are imported, Front page and Blog will be set in Settings.', 'pi_framework') ?></li>                            
                        <li><?php esc_html_e('Images will be downloaded from our server.', 'pi_framework') ?></li>
                        <li><?php esc_html_e('Importing can can take a couple of minutes.', 'pi_framework') ?></li>
                    </ul>
                </div>

                <div class="warning"><p><?php esc_html_e('Before you begin, make sure all the required plugins are activated.', 'pi_framework') ?> <a href="<?php echo admin_url('admin.php?page=install-required-plugins'); ?>"><?php esc_html_e('Check required plugins', 'pi_framework') ?></a></p></div>

                <div class="fields-container">

                    <table class="table-fields">
                        <tr>
                            <td><h4><?php esc_html_e('Pages / Menus', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="pages-menus" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Posts', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="posts" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Portfolio / Gallery', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="portfolio-gallery" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Contact', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="contact" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Revolution slider', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="slider" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Widgets', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="widgets" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Theme options', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="theme-options" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                        <tr>
                            <td><h4><?php esc_html_e('Images (attachments)', 'pi_framework') ?></h4></td>
                            <td>
                                <input type="button" class="button-primary import-button" id="attachments" value="<?php esc_html_e('Import', 'pi_framework') ?>"/>
                                <div class="importing-finished">
                                    <i class="fa fa-check-circle"></i>
                                </div>
                            </td>
                        </tr>

                    </table>

                    <div id="circularG">
                        <div id="circularG_1" class="circularG"></div>
                        <div id="circularG_2" class="circularG"></div>
                        <div id="circularG_3" class="circularG"></div>
                        <div id="circularG_4" class="circularG"></div>
                        <div id="circularG_5" class="circularG"></div>
                        <div id="circularG_6" class="circularG"></div>
                        <div id="circularG_7" class="circularG"></div>
                        <div id="circularG_8" class="circularG"></div>
                    </div>                    

                    <div class="results-container">
                        <div class="results-field" placeholder="<?php esc_html_e('Import log...', 'pi_framework') ?>"></div>
                    </div>

                    <input type="hidden" name="demononce" id="demo-nonce" value="<?php echo wp_create_nonce('volcanno-demo-code'); ?>" />

                </div>
            </div>


        </div>
        <?php
    }

    /**
     * Uploads content based on parameter from AJAX request.
     */
    public function ajax_import_content() {
        global $volcanno_theme_config;

        $action = isset($_REQUEST['action']) ? $_REQUEST['action'] : '';
        $content_id = isset($_REQUEST['content_id']) ? $_REQUEST['content_id'] : false;

        if ($action == 'vlc_import_demo' && check_ajax_referer('volcanno-demo-code', 'security')) {

            $demo_files = $this->content_demo;

            // UPLOAD PAGES AND MENUS
            if ($content_id == 'pages-menus') {
                $file_url = $this->demo_files_path . $demo_files['pages_menus'];
                $this->set_demo_data($file_url);
                $this->set_demo_menus();

                $this->setup_settings();

                // UPLOAD POSTS
            } else if ($content_id == 'posts') {
                $file_url = $this->demo_files_path . $demo_files['posts'];
                $this->set_demo_data($file_url);

                // UPLOAD PORTFOLIO AND GALLERY
            } else if ($content_id == 'portfolio-gallery') {

                if (!VOLCANNO_CPTS) {
                    echo wp_kses(__('<strong>Please activate/install Custom Post Types plugin before uploading demo content.</strong>', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']);
                    exit();
                }

                if (is_array($demo_files['portfolio_gallery'])) {
                    foreach ($demo_files['portfolio_gallery'] as $key => $value) {
                        $file_url = $this->demo_files_path . $value;
                        $this->set_demo_data($file_url);
                    }
                } else {
                    $file_url = $this->demo_files_path . $demo_files['portfolio_gallery'];
                    $this->set_demo_data($file_url);
                }

                // UPLOAD CONTACT FORMS
            } else if ($content_id == 'contact') {

                if (!VOLCANNO_CF7) {
                    echo wp_kses(__('<strong>Please activate/install Contact Form 7 plugin before uploading demo content.</strong>', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']);
                    exit();
                }

                $file_url = $this->demo_files_path . $demo_files['contact'];
                $this->set_demo_data($file_url);

                // UPLOAD SLIDER
            } else if ($content_id == 'slider') {

                if (!VOLCANNO_REVSLIDER) {
                    echo wp_kses(__('<strong>Please activate/install Revolution slider before uploading demo content.</strong>', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']);
                    exit();
                }

                if (is_array($demo_files['slider'])) {
                    foreach ($demo_files['slider'] as $key => $value) {
                        $file_url = $this->demo_files_path . $value;
                        $this->set_revslider_slides($file_url);
                    }
                } else {
                    $file_url = $this->demo_files_path . $demo_files['slider'];
                    $this->set_revslider_slides($file_url);
                }

                // UPLOAD THEME OPTIONS
            } else if ($content_id == 'theme-options') {
                $file_url = $this->demo_files_path . $demo_files['options'];
                $this->set_demo_theme_options($file_url); //import before widgets incase we need more sidebars
                // UPLOAD WIDGETS
            } else if ($content_id == 'widgets') {
                $file_url = $this->demo_files_path . $demo_files['widgets'];
                $this->process_widget_import_file($file_url);
                $this->widget_import_log();

                // UPLOAD ATTACHMENTS
            } else if ($content_id == 'attachments') {
                $file_url = $this->demo_files_path . $demo_files['attachments'];
                $this->set_demo_data($file_url);
            }
            ?>                        

            <?php
        }
        exit();
    }

    public function widget_import_log() {
        if (!empty($this->widget_import_results)) {
            ?>
            <table id="wie-import-results">

                <?php
                // Loop sidebars
                $results = $this->widget_import_results;
                foreach ($results as $sidebar) :
                    ?>

                    <tr class="wie-import-results-sidebar">
                        <td colspan="2" class="wie-import-results-sidebar-name">
                            <?php echo esc_html($sidebar['name']); // sidebar name if theme supports it; otherwise ID ?>
                        </td>
                        <td class="wie-import-results-sidebar-message wie-import-results-message wie-import-results-message-<?php echo sanitize_html_class($sidebar['message_type']); ?>">
                            <?php echo esc_html($sidebar['message']); // sidebar may not exist in theme ?>
                        </td>
                    </tr>

                    <?php
                    // Loop widgets
                    foreach ($sidebar['widgets'] as $widget) :
                        ?>
                        <tr class="wie-import-results-widget">
                            <td class="wie-import-results-widget-name">
                                <?php echo esc_html($widget['name']); // widget name or ID if name not available (not supported by site)        ?>
                            </td>
                            <td class="wie-import-results-widget-title">
                                <?php echo esc_html($widget['title']); // shows "No Title" if widget instance is untitled         ?>
                            </td>
                            <td class="wie-import-results-widget-message wie-import-results-message wie-import-results-message-<?php echo sanitize_html_class($widget['message_type']); ?>">
                                <?php echo esc_html($widget['message']); // sidebar may not exist in theme         ?>
                            </td>
                        </tr>

                    <?php endforeach; ?>

                    <tr class="wie-import-results-space">
                        <td colspan="100%"></td>
                    </tr>

                <?php endforeach; ?>

            </table>
            <?php
        }
    }

    /**
     * add_widget_to_sidebar Import sidebars
     * @param  string $sidebar_slug    Sidebar slug to add widget
     * @param  string $widget_slug     Widget slug
     * @param  string $count_mod       position in sidebar
     * @param  array  $widget_settings widget settings
     *
     * @since 2.2.0
     *
     * @return null
     */
    public function add_widget_to_sidebar($sidebar_slug, $widget_slug, $count_mod, $widget_settings = array()) {

        $sidebars_widgets = get_option('sidebars_widgets');

        if (!isset($sidebars_widgets[$sidebar_slug]))
            $sidebars_widgets[$sidebar_slug] = array('_multiwidget' => 1);

        $newWidget = get_option('widget_' . $widget_slug);

        if (!is_array($newWidget))
            $newWidget = array();

        $count = count($newWidget) + 1 + $count_mod;
        $sidebars_widgets[$sidebar_slug][] = $widget_slug . '-' . $count;

        $newWidget[$count] = $widget_settings;

        update_option('sidebars_widgets', $sidebars_widgets);
        update_option('widget_' . $widget_slug, $newWidget);
    }

    public function set_demo_data($file) {

        if (!defined('WP_LOAD_IMPORTERS'))
            define('WP_LOAD_IMPORTERS', true);

        require_once ABSPATH . 'wp-admin/includes/import.php';

        $importer_error = false;

        if (!class_exists('WP_Importer')) {

            $class_wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';

            if (file_exists($class_wp_importer)) {

                require_once $class_wp_importer;
            } else {

                $importer_error = true;
            }
        }

        if (!class_exists('WP_Import')) {

            $class_wp_import = get_template_directory() . '/core/importer/wordpress-importer.php';

            if (file_exists($class_wp_import))
                require_once $class_wp_import;
            else
                $importer_error = true;
        }

        if ($importer_error) {

            die("Error on import");
        } else {

            if (!is_file($file)) {
                esc_html_e("The XML file containing the dummy content is not available or could not be read .. You might want to try to set the file permission to chmod 755.<br/>If this doesn't work please use the Wordpress importer and import the XML file (should be located in your download .zip: Sample Content folder) manually.", 'pi_framework');
            } else {

                $wp_import = new WP_Import();
                $wp_import->fetch_attachments = true;
                $wp_import->import($file);
            }
        }
    }

    public function set_demo_menus() {
        
    }

    public function set_demo_theme_options($file) {

        // File exists?
        if (!file_exists($file)) {
            wp_die(
                    esc_html__('Theme options Import file could not be found. Please try again.', 'pi_framework'), '', array('back_link' => true)
            );
        }

        // Get file contents and decode
        $data = file_get_contents($file);
        $data = json_decode($data, true);

        // Have valid data?
        // If no data or could not decode
        if (empty($data) || !is_array($data)) {
            wp_die(
                    esc_html__('Theme options import data could not be read. Please try a different file.', 'pi_framework'), '', array('back_link' => true)
            );
        }

        // Hook before import
        $data = apply_filters('volcanno_theme_import_theme_options', $data);

        update_option($this->theme_option_name, $data);

        echo "<h4>" . esc_html__('Theme options successfully uploaded.', 'pi_framework') . "</h4>";
    }

    /**
     * Upload Revolution slider demo slides
     * 
     * @since 2.3
     * @param  string $file       url to slider file
     * @return void
     */
    public function set_revslider_slides($file) {

        $slider = new RevSlider();
        $response = $slider->importSliderFromPost(true, true, $file);
        $sliderID = $response["sliderID"];

        //handle error
        if ($response["success"] == false) {
            $message = $response["error"];
            esc_html_e('Error:', 'pi_framework');
            echo strip_tags($message);
        } else {
            esc_html_e('Slider Import Success.', 'pi_framework');
        }
    }

    /**
     * Available widgets
     *
     * Gather site's widgets into array with ID base, name, etc.
     * Used by export and import functions.
     *
     * @since 2.2.0
     *
     * @global array $wp_registered_widget_updates
     * @return array Widget information
     */
    function available_widgets() {

        global $wp_registered_widget_controls;

        $widget_controls = $wp_registered_widget_controls;

        $available_widgets = array();

        foreach ($widget_controls as $widget) {

            if (!empty($widget['id_base']) && !isset($available_widgets[$widget['id_base']])) { // no dupes
                $available_widgets[$widget['id_base']]['id_base'] = $widget['id_base'];
                $available_widgets[$widget['id_base']]['name'] = $widget['name'];
            }
        }

        return apply_filters('volcanno_theme_import_widget_available_widgets', $available_widgets);
    }

    /**
     * Process import file
     *
     * This parses a file and triggers importation of its widgets.
     *
     * @since 2.2.0
     *
     * @param string $file Path to .wie file uploaded
     * @global string $widget_import_results
     */
    function process_widget_import_file($file) {
        global $volcanno_theme_config;

        // File exists?
        if (!file_exists($file)) {
            wp_die(
                    esc_html__('Widget Import file could not be found. Please try again.', 'pi_framework'), '', array('back_link' => true)
            );
        }

        if (ini_get('allow_url_fopen') && file_get_contents($file)) {
            // Get file contents and decode
            $data = file_get_contents($file);
            $data = json_decode($data);

            // Delete import file
            //unlink( $file );
            // Import the widget data
            // Make results available for display on import/export page
            $this->widget_import_results = $this->import_widgets($data);
        } else {
            echo wp_kses(__('<strong>Error:</strong> Please enable <strong>allow_url_fopen</strong> in your server configuration to continue uploading.', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']);
        }
    }

    /**
     * Import widget JSON data
     *
     * @since 2.2.0
     * @global array $wp_registered_sidebars
     * @param object $data JSON widget data from .wie file
     * @return array Results array
     */
    public function import_widgets($data) {

        global $wp_registered_sidebars;

        // Have valid data?
        // If no data or could not decode
        if (empty($data) || !is_object($data)) {
            wp_die(
                    esc_html__('Widget import data could not be read. Please try a different file.', 'pi_framework'), '', array('back_link' => true)
            );
        }

        // Hook before import
        $data = apply_filters('volcanno_theme_import_widget_data', $data);

        // Get all available widgets site supports
        $available_widgets = $this->available_widgets();

        // Get all existing widget instances
        $widget_instances = array();
        foreach ($available_widgets as $widget_data) {
            $widget_instances[$widget_data['id_base']] = get_option('widget_' . $widget_data['id_base']);
        }

        // Begin results
        $results = array();

        // Loop import data's sidebars
        foreach ($data as $sidebar_id => $widgets) {

            // Skip inactive widgets
            // (should not be in export file)
            if ('wp_inactive_widgets' == $sidebar_id) {
                continue;
            }

            // Check if sidebar is available on this site
            // Otherwise add widgets to inactive, and say so
            if (isset($wp_registered_sidebars[$sidebar_id])) {
                $sidebar_available = true;
                $use_sidebar_id = $sidebar_id;
                $sidebar_message_type = 'success';
                $sidebar_message = '';
            } else {
                $sidebar_available = false;
                $use_sidebar_id = 'wp_inactive_widgets'; // add to inactive if sidebar does not exist in theme
                $sidebar_message_type = 'error';
                $sidebar_message = esc_html__('Sidebar does not exist in theme (using Inactive)', 'pi_framework');
            }

            // Result for sidebar
            $results[$sidebar_id]['name'] = !empty($wp_registered_sidebars[$sidebar_id]['name']) ? $wp_registered_sidebars[$sidebar_id]['name'] : $sidebar_id; // sidebar name if theme supports it; otherwise ID
            $results[$sidebar_id]['message_type'] = $sidebar_message_type;
            $results[$sidebar_id]['message'] = $sidebar_message;
            $results[$sidebar_id]['widgets'] = array();

            // Loop widgets
            foreach ($widgets as $widget_instance_id => $widget) {

                $fail = false;

                // Get id_base (remove -# from end) and instance ID number
                $id_base = preg_replace('/-[0-9]+$/', '', $widget_instance_id);
                $instance_id_number = str_replace($id_base . '-', '', $widget_instance_id);

                // Does site support this widget?
                if (!$fail && !isset($available_widgets[$id_base])) {
                    $fail = true;
                    $widget_message_type = 'error';
                    $widget_message = esc_html__('Site does not support widget', 'pi_framework'); // explain why widget not imported
                }

                // Filter to modify settings before import
                // Do before identical check because changes may make it identical to end result (such as URL replacements)
                $widget = apply_filters('volcanno_theme_import_widget_settings', $widget);

                // Does widget with identical settings already exist in same sidebar?
                if (!$fail && isset($widget_instances[$id_base])) {

                    // Get existing widgets in this sidebar
                    $sidebars_widgets = get_option('sidebars_widgets');
                    $sidebar_widgets = isset($sidebars_widgets[$use_sidebar_id]) ? $sidebars_widgets[$use_sidebar_id] : array(); // check Inactive if that's where will go
                    // Loop widgets with ID base
                    $single_widget_instances = !empty($widget_instances[$id_base]) ? $widget_instances[$id_base] : array();
                    foreach ($single_widget_instances as $check_id => $check_widget) {

                        // Is widget in same sidebar and has identical settings?
                        if (in_array("$id_base-$check_id", $sidebar_widgets) && (array) $widget == $check_widget) {

                            $fail = true;
                            $widget_message_type = 'warning';
                            $widget_message = esc_html__('Widget already exists', 'pi_framework'); // explain why widget not imported

                            break;
                        }
                    }
                }

                // No failure
                if (!$fail) {

                    // Add widget instance
                    $single_widget_instances = get_option('widget_' . $id_base); // all instances for that widget ID base, get fresh every time
                    $single_widget_instances = !empty($single_widget_instances) ? $single_widget_instances : array('_multiwidget' => 1); // start fresh if have to
                    $single_widget_instances[] = (array) $widget; // add it
                    // Get the key it was given
                    end($single_widget_instances);
                    $new_instance_id_number = key($single_widget_instances);

                    // If key is 0, make it 1
                    // When 0, an issue can occur where adding a widget causes data from other widget to load, and the widget doesn't stick (reload wipes it)
                    if ('0' === strval($new_instance_id_number)) {
                        $new_instance_id_number = 1;
                        $single_widget_instances[$new_instance_id_number] = $single_widget_instances[0];
                        unset($single_widget_instances[0]);
                    }

                    // Move _multiwidget to end of array for uniformity
                    if (isset($single_widget_instances['_multiwidget'])) {
                        $multiwidget = $single_widget_instances['_multiwidget'];
                        unset($single_widget_instances['_multiwidget']);
                        $single_widget_instances['_multiwidget'] = $multiwidget;
                    }

                    // Update option with new widget
                    update_option('widget_' . $id_base, $single_widget_instances);

                    // Assign widget instance to sidebar
                    $sidebars_widgets = get_option('sidebars_widgets'); // which sidebars have which widgets, get fresh every time
                    $new_instance_id = $id_base . '-' . $new_instance_id_number; // use ID number from new widget instance
                    $sidebars_widgets[$use_sidebar_id][] = $new_instance_id; // add new instance to sidebar
                    update_option('sidebars_widgets', $sidebars_widgets); // save the amended data
                    // Success message
                    if ($sidebar_available) {
                        $widget_message_type = 'success';
                        $widget_message = esc_html__('Imported', 'pi_framework');
                    } else {
                        $widget_message_type = 'warning';
                        $widget_message = esc_html__('Imported to Inactive', 'pi_framework');
                    }
                }

                // Result for widget instance
                $results[$sidebar_id]['widgets'][$widget_instance_id]['name'] = isset($available_widgets[$id_base]['name']) ? $available_widgets[$id_base]['name'] : $id_base; // widget name or ID if name not available (not supported by site)
                $results[$sidebar_id]['widgets'][$widget_instance_id]['title'] = isset($widget->title) ? $widget->title : esc_html__('No Title', 'pi_framework'); // show "No Title" if widget instance is untitled
                $results[$sidebar_id]['widgets'][$widget_instance_id]['message_type'] = $widget_message_type;
                $results[$sidebar_id]['widgets'][$widget_instance_id]['message'] = $widget_message;
            }
        }

        // Hook after import
        do_action('volcanno_theme_import_widget_after_import');

        // Return results       
        return apply_filters('volcanno_theme_import_widget_results', $results);
    }

    /**
     * Setup settings - set Home and Blog page
     *
     * @since 2.3
     * @return void
     */
    public function setup_settings() {

        // set Home page
        if (get_page_by_title('Home')) {

            // Use a static front page
            $home = get_page_by_title('Home');
            update_option('page_on_front', $home->ID);
            update_option('show_on_front', 'page');
        }

        // set Blog page
        if (get_page_by_title('Blog')) {

            // Set the blog page
            $blog = get_page_by_title('Blog');
            update_option('page_for_posts', $blog->ID);
        }
    }

}
?>