<?php

/**
 * Font Awesome classes
 *
 * @return array
 */
function volcanno_font_awesome_classes() {
    global $volcanno_theme_config;
    $icons = array();

    // check that path to Font Awesome CSS file is defined in theme's configuration
    if (isset($volcanno_theme_config['icon_fonts']) && isset($volcanno_theme_config['icon_fonts']['font_awesome'])) {
        $font_awesome = $volcanno_theme_config['icon_fonts']['font_awesome'];

        $local_file = isset($font_awesome['local']) ? $font_awesome['local'] : false;
        $remote_file = isset($font_awesome['remote']) ? $font_awesome['remote'] : false;

        // parse the file
        if (!empty($local_file) || !empty($remote_file)) {
            $icons = volcanno_parse_icon_font_css($local_file, $remote_file);
        }
    }

    return $icons;
}

/**
 * Parse Icon font CSS file
 *
 * @param string $local path to local CSS file
 * @param string $remote path to remote CSS file
 * @return array
 */
function volcanno_parse_icon_font_css($local, $remote) {

    // get icon list from database
    $icons = get_option('volcanno_font_awesome_list');
    $icons = apply_filters('volcanno_font_awesome_list', $icons);

    // clear value in database
    //$icons = null;

    if (empty($icons)) {

        // try to get local file
        if (ini_get('allow_url_fopen') && file_get_contents($local)) {
            $css = file_get_contents($local);
        } else {
            // fetch data from remote location
            $request = wp_remote_get($remote, array('sslverify' => false));

            // get body response if there wasn't any errors
            if (!is_wp_error($request) || wp_remote_retrieve_response_code($request) === 200) {
                $css = wp_remote_retrieve_body($request);
            }
        }

        // parse the content and store in array
        if (!empty($css)) {
            $pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';

            preg_match_all($pattern, $css, $matches, PREG_SET_ORDER);

            $icons = array();
            foreach ($matches as $match) {
                $icons[$match[1]] = ucfirst(str_ireplace(array('fa-', '-'), array('', ' '), $match[1]));
            }
        } else {
            $icons = array('Icons not parsed');
        }

        update_option('volcanno_font_awesome_list', $icons);
    }

    return $icons;
}

/**
 * Linecons classes
 *
 * @return array
 */
function volcanno_linecons_classes() {
    global $volcanno_theme_config;
    $icons = array();

    // check that path to Font Awesome CSS file is defined in theme's configuration
    if (isset($volcanno_theme_config['icon_fonts']) && isset($volcanno_theme_config['icon_fonts']['linecons'])) {
        $linecons = $volcanno_theme_config['icon_fonts']['linecons'];

        $local_file = isset($linecons['local']) ? $linecons['local'] : false;
        $remote_file = isset($linecons['remote']) ? $linecons['remote'] : false;

        // parse the file
        if (!empty($local_file) || !empty($remote_file)) {
            $icons = volcanno_parse_linecons_css($local_file, $remote_file);
        }
    }

    return $icons;
}

/**
 * Parse Linecons CSS file
 *
 * @param string $local path to local CSS file
 * @param string $remote path to remote CSS file
 * @return array
 */
function volcanno_parse_linecons_css($local, $remote) {

    // get icon list from database
    $icons = get_option('volcanno_linecons_list');
    $icons = apply_filters('volcanno_linecons_list', $icons);

    // clear value in database
    //$icons = null;

    if (empty($icons)) {

        // try to get local file
        if (ini_get('allow_url_fopen') && file_get_contents($local)) {
            $css = file_get_contents($local);
        } else {
            // fetch data from remote location
            $request = wp_remote_get($remote, array('sslverify' => false));

            // get body response if there wasn't any errors
            if (!is_wp_error($request) || wp_remote_retrieve_response_code($request) === 200) {
                $css = wp_remote_retrieve_body($request);
            }
        }

        // parse the content and store in array
        if (!empty($css)) {
            $pattern = '/\.(linecons-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';

            preg_match_all($pattern, $css, $matches, PREG_SET_ORDER);

            $icons = array();
            foreach ($matches as $match) {
                $icons[$match[1]] = $match[1];
            }
        } else {
            $icons = array('Icons not parsed');
        }

        update_option('volcanno_linecons_list', $icons);
    }

    return $icons;
}

function volcanno_get_pixons_names() {
    $prefix = 'pixons-';

    $icons = array(
        $prefix . 'amazon' => $prefix . 'amazon',
        $prefix . 'android' => $prefix . 'android',
        $prefix . 'aol' => $prefix . 'aol',
        $prefix . 'apple' => $prefix . 'apple',
        $prefix . 'behance' => $prefix . 'behance',
        $prefix . 'bing' => $prefix . 'bing',
        $prefix . 'blogger' => $prefix . 'blogger',
        $prefix . 'buzz' => $prefix . 'buzz',
        $prefix . 'delicious' => $prefix . 'delicious',
        $prefix . 'deviantart' => $prefix . 'deviantart',
        $prefix . 'digg' => $prefix . 'digg',
        $prefix . 'dribbble' => $prefix . 'dribbble',
        $prefix . 'dropbox' => $prefix . 'dropbox',
        $prefix . 'drupal' => $prefix . 'drupal',
        $prefix . 'ember' => $prefix . 'ember',
        $prefix . 'envato' => $prefix . 'envato',
        $prefix . 'evernote' => $prefix . 'evernote',
        $prefix . 'facebook-1' => $prefix . 'facebook-1',
        $prefix . 'facebook-2' => $prefix . 'facebook-2',
        $prefix . 'feedburner' => $prefix . 'feedburner',
        $prefix . 'forrst' => $prefix . 'forrst',
        $prefix . 'flickr' => $prefix . 'flickr',
        $prefix . 'foursquare' => $prefix . 'foursquare',
        $prefix . 'github' => $prefix . 'github',
        $prefix . 'github-2' => $prefix . 'github-2',
        $prefix . 'google_plus' => $prefix . 'google_plus',
        $prefix . 'grooveshark' => $prefix . 'grooveshark',
        $prefix . 'html5' => $prefix . 'html5',
        $prefix . 'instagram' => $prefix . 'instagram',
        $prefix . 'lastfm' => $prefix . 'lastfm',
        $prefix . 'linkedin' => $prefix . 'linkedin',
        $prefix . 'metacafe' => $prefix . 'metacafe',
        $prefix . 'mixx' => $prefix . 'mixx',
        $prefix . 'myspace' => $prefix . 'myspace',
        $prefix . 'newsvine' => $prefix . 'newsvine',
        $prefix . 'paypal' => $prefix . 'paypal',
        $prefix . 'picasa' => $prefix . 'picasa',
        $prefix . 'pinterest' => $prefix . 'pinterest',
        $prefix . 'plixi' => $prefix . 'plixi',
        $prefix . 'plurk' => $prefix . 'plurk',
        $prefix . 'posterous' => $prefix . 'posterous',
        $prefix . 'reddit' => $prefix . 'reddit',
        $prefix . 'rss' => $prefix . 'rss',
        $prefix . 'sharethis' => $prefix . 'sharethis',
        $prefix . 'skype' => $prefix . 'skype',
        $prefix . 'soundcloud' => $prefix . 'soundcloud',
        $prefix . 'stumbleupon' => $prefix . 'stumbleupon',
        $prefix . 'technorati' => $prefix . 'technorati',
        $prefix . 'tumblr' => $prefix . 'tumblr',
        $prefix . 'tux' => $prefix . 'tux',
        $prefix . 'twitter-1' => $prefix . 'twitter-1',
        $prefix . 'twitter-2' => $prefix . 'twitter-2',
        $prefix . 'vimeo' => $prefix . 'vimeo',
        $prefix . 'wordpress' => $prefix . 'wordpress',
        $prefix . 'xing' => $prefix . 'xing',
        $prefix . 'yahoo' => $prefix . 'yahoo',
        $prefix . 'yelp' => $prefix . 'yelp',
        $prefix . 'youtube' => $prefix . 'youtube',
        $prefix . 'zerply' => $prefix . 'zerply',
        $prefix . 'zootool' => $prefix . 'zootool'
    );
    ksort($icons);

    return $icons;
}

?>
