<?php
/* ---------------------------------------------------
 * Theme: Mixed - Modern and professional WordPress theme
 * Author: Pixel Industry
 * URL: www.pixel-industry.com
  -------------------------------------------------- */

define('THEME_NAME', "Mixed");
define('TEMPLATEURL', get_template_directory_uri());
define('PI_THEME_DIR', get_template_directory() . '/');

global $volcanno_options, $vlc_is_retina;

/**
 * Main configuration array for theme.
 * 
 * @var array $volcanno_theme_config
 */
global $volcanno_theme_config;

/* -------------------------------------------------------------------- 
 * Array with configurations for current theme
 * -------------------------------------------------------------------- */


$volcanno_theme_config = array(
    'icon_fonts' => array(
        'font_awesome' => array(
            'local' => TEMPLATEURL . "/includes/assets/font-awesome-4.3.0/css/font-awesome.css",
            'remote' => "http://pixel-industry.com/resources/font-awesome-4.3.0/css/font-awesome.css"
        ),
        'pixons' => array(
            'local' => TEMPLATEURL . "/includes/assets/pixons/style.css"
        ),
        'linecons' => array(
            'local' => TEMPLATEURL . "/includes/assets/linecons/linecons.css",
            'remote' => "http://pixel-industry.com/resources/linecons/linecons.css"
        )
    ),
    'retina' => 1,
    'allowed_html_tags' => array(
        'a' => array(
            'href' => array(),
            'title' => array(),
            'class' => array()
        ),
        'br' => array(),
        'em' => array(),
        'strong' => array(),
        'span' => array('class' => array())
    )
);

/* -------------------------------------------------------------------- 
 * Set the content width based on the theme's design and stylesheet.
 * -------------------------------------------------------------------- */

if (!isset($content_width))
    $content_width = 1140;

/* -------------------------------------------------------------------- 
 * Check if required plugins are loaded
 * -------------------------------------------------------------------- */

if (!function_exists('volcanno_plugins_loaded')) {

    function volcanno_plugins_loaded() {
        if (!function_exists('is_plugin_active'))
            require_once ABSPATH . '/wp-admin/includes/plugin.php';

        // check if Content Maker plugin is loaded
        if (is_plugin_active('content-maker/content-maker.php'))
            define('CONTENT_MAKER', true);
        else
            define('CONTENT_MAKER', false);

        // check if MetaBox plugin is loaded
        if (is_plugin_active('meta-box/meta-box.php'))
            define('RWMB_META_BOX', true);
        else
            define('RWMB_META_BOX', false);

        // check if MetaBox plugin is loaded
        if (is_plugin_active('volcanno-custom-post-types/volcanno-custom-post-types.php'))
            define('VOLCANNO_CPTS', true);
        else
            define('VOLCANNO_CPTS', false);

        // check if MetaBox plugin is loaded
        if (is_plugin_active('revslider/revslider.php'))
            define('VOLCANNO_REVSLIDER', true);
        else
            define('VOLCANNO_REVSLIDER', false);

        // check if MetaBox plugin is loaded
        if (is_plugin_active('contact-form-7/wp-contact-form-7.php'))
            define('VOLCANNO_CF7', true);
        else
            define('VOLCANNO_CF7', false);
    }

}

add_action('after_setup_theme', 'volcanno_plugins_loaded', 9);

/**
 * Filter post types configuration where we register
 * post types that are needed in theme
 * 
 * @param array $post_types_config Array with post types
 * @return array Array with configuration
 */
if (!function_exists('volcanno_register_custom_post_types')) {

    function volcanno_register_custom_post_types($post_types_config) {

        $post_types_config = array(
            'pi_portfolio' => array(
                'cpt' => '1',
                'taxonomy' => '1'
            ),
            'pi_gallery' => array(
                'cpt' => '1',
                'taxonomy' => '1'
            )
        );

        return $post_types_config;
    }

}
add_filter('vcpt_register_custom_post_types', 'volcanno_register_custom_post_types');

/**
 * Add class "volcanno-portfolio-not-active" to create/edit page screen if 
 * Custom Post Types plugin isn't active
 * 
 * @global type $pagenow
 * @global type $typenow
 * @param string $classes Body classes to filter
 * @return string All body classes
 */
if (!function_exists('volcanno_admin_body_class')) {

    function volcanno_admin_body_class($classes) {
        global $pagenow, $typenow;

        if (!VOLCANNO_CPTS && is_admin() && ( $pagenow == 'post-new.php' || $pagenow == 'post.php' ) && $typenow == 'page') {
            $classes .= 'volcanno-cpts-not-active';
        }

        return $classes;
    }

}
add_filter('admin_body_class', 'volcanno_admin_body_class');

/* -------------------------------------------------------------------- 
 * Register and enqueue theme styles
 * -------------------------------------------------------------------- */

if (!function_exists('volcanno_theme_styles')) {

    function volcanno_theme_styles() {
        global $volcanno_options;
        $stylesheet_uri = get_stylesheet_uri();

        // check if Content Maker is active and load Bootstrap first
        if (CONTENT_MAKER) {
            wp_enqueue_style('volcanno-style', $stylesheet_uri, array('cma-styles-bootstrap'), '1.0', 'screen');
        } else {
            wp_enqueue_style('bootstrap', TEMPLATEURL . "/css/bootstrap.css", array(), '1.0', 'screen');
            wp_enqueue_style('volcanno-style', $stylesheet_uri, array('bootstrap'), '1.0', 'screen');
            wp_enqueue_style('font-awesome', TEMPLATEURL . '/includes/assets/font-awesome-4.3.0/css/font-awesome.min.css', array(), '1.0', 'screen');
        }

        // check if Content Maker is inactive and load animate.css
        if (!CONTENT_MAKER || (CONTENT_MAKER && !cma_get_settings('elements-animation'))) {
            wp_enqueue_style('animatecss', TEMPLATEURL . '/css/animate.css');
        }

        // registering styles
        wp_enqueue_style('pixons', TEMPLATEURL . '/includes/assets/pixons/style.css', array(), '1.0', 'screen');
        wp_enqueue_style('linecons', TEMPLATEURL . '/includes/assets/linecons/linecons.css', array(), '1.0', 'screen');
        wp_enqueue_style('nivoslider', TEMPLATEURL . "/css/nivo-slider.css", array(), '1.0', 'screen');
        wp_enqueue_style('owl-carousel', TEMPLATEURL . "/includes/assets/owl-carousel/owl.carousel.css", array(), '1.0', 'screen');
        wp_enqueue_style('magnific-popup', TEMPLATEURL . "/css/magnific-popup.css", array(), '1.0', 'screen');
        wp_enqueue_style('volcanno-retina-css', TEMPLATEURL . "/css/retina.css", array(), '1.0', 'screen');
        wp_enqueue_style('jplayer', TEMPLATEURL . '/js/jplayer/skin/pixel-industry/pixel-industry.css', array(), '1.0', 'screen');
        wp_enqueue_style('volcanno-google-fonts', 'http://fonts.googleapis.com/css?family=Raleway:400,300,500,600,700,800,900,200,100%7COpen+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800&amp;subset=latin,cyrillic-ext,greek-ext,greek,vietnamese,latin-ext,cyrillic', array(), null);

        if ($volcanno_options['responsive'] == '1') {
            wp_enqueue_style('volcanno-responsive', TEMPLATEURL . '/css/responsive.css', array('volcanno-style'), '1.0', 'screen');
        }
    }

}

add_action('wp_enqueue_scripts', 'volcanno_theme_styles', 11);

/* -------------------------------------------------------------------- 
 * Load script for custom color styles
 * -------------------------------------------------------------------- */

if (!function_exists('volcanno_load_color_style')) {

    function volcanno_load_color_style() {
        global $volcanno_options;

        // custom color style is selected
        $custom_color_style = $volcanno_options['custom_color_style'];

        // one of predefined color styles are selected
        $predefined_color_style = isset($volcanno_options['predefined_color_style']) ? $volcanno_options['predefined_color_style'] : false;

        // load proper color style
        if (!empty($custom_color_style)) {
            wp_register_style('volcanno-color-style', TEMPLATEURL . '/includes/color-style.php', array('volcanno-style'), '1.0', 'screen');
        } elseif (!empty($predefined_color_style)) {
            wp_register_style('volcanno-color-style', TEMPLATEURL . '/css/' . $predefined_color_style . '.css', array('volcanno-style'), '1.0', 'screen');
        } else {
            wp_register_style('volcanno-color-style', TEMPLATEURL . '/css/default-color.css', array('volcanno-style'), '1.0', 'screen');
        }

        wp_enqueue_style('volcanno-color-style');
    }

}

add_action('wp_enqueue_scripts', 'volcanno_load_color_style', 11);


/* -------------------------------------------------------------------- 
 * Load custom styles.
  -------------------------------------------------------------------- */
if (!function_exists('volcanno_load_custom_styles')) {

    function volcanno_load_custom_styles() {
        global $volcanno_options;

        // custom CSS styles
        $custom_styles = isset($volcanno_options['custom_css']) ? $volcanno_options['custom_css'] : '';
        if (!empty($custom_styles)) {
            $custom_styles = html_entity_decode($custom_styles);
            wp_enqueue_style('volcanno-custom-css', TEMPLATEURL . '/core/libs/custom-styles.php', array('volcanno-style', 'volcanno-color-style'), '1.0', 'screen');
        }
    }

}

add_action('wp_enqueue_scripts', 'volcanno_load_custom_styles', 12);

/* -------------------------------------------------------------------- 
 * Register and enqueue admin syles
 * -------------------------------------------------------------------- */

if (!function_exists('volcanno_load_admin_styles')) {

    function volcanno_load_admin_styles() {
        $current_screen = get_current_screen();

        wp_enqueue_style('pixons', TEMPLATEURL . '/includes/assets/pixons/style.css', array(), '1.0', 'screen');
        wp_enqueue_style('font-awesome', TEMPLATEURL . '/includes/assets/font-awesome-4.3.0/css/font-awesome.min.css', array(), '1.0', 'screen');
        wp_enqueue_style('linecons', TEMPLATEURL . '/includes/assets/linecons/linecons.css', array(), '1.0', 'screen');

        if ($current_screen->id == 'pi_portfolio' || $current_screen->id == 'pi_gallery' || $current_screen->id == 'page') {
            wp_enqueue_style('volcanno-portfolio-formats', TEMPLATEURL . '/css/admin.css', array(), '1.0', 'screen');
        }
    }

}

add_action('admin_enqueue_scripts', 'volcanno_load_admin_styles');

/* -------------------------------------------------------------------- 
 * Register all scripts which are needed for theme  
 * -------------------------------------------------------------------- */

if (!function_exists('volcanno_register_scripts')) {

    function volcanno_register_scripts() {
        if (!is_admin()) {
            global $volcanno_options;

            /* jQuery Modernizr plugin */
            wp_register_script('modernizr', TEMPLATEURL . '/js/jquery.modernizr.custom.min.js', array('jquery'), '1.0', TRUE);
            /* CarouFredSel carousel plugin */
            wp_register_script('owl-carousel', TEMPLATEURL . '/includes/assets/owl-carousel/owl.carousel.min.js', array('jquery'), '1.0', TRUE);
            /* Nivo slider - Image slider */
            wp_register_script('nivoslider', TEMPLATEURL . '/js/jquery.nivo.slider.pack.js', 'jquery', '1.0', TRUE);
            /* jQuery Lightbox plugin */
            wp_register_script('magnific-popup', TEMPLATEURL . '/js/jquery.magnific-popup.min.js', array('jquery'), '1.0', TRUE);
            /* jPlayer - video player */
            wp_register_script('jplayer', TEMPLATEURL . '/js/jplayer/jquery.jplayer.min.js', array('jquery'), '1.0', TRUE);
            /* MatchHeights */
            wp_register_script('match-heights', TEMPLATEURL . '/js/jquery.matchHeight-min.js', array('jquery'), '1.0', TRUE);
            /* jQuery Responsive menu plugin */
            wp_register_script('dl-menu', TEMPLATEURL . '/js/jquery.dlmenu.min.js', array('jquery'), '1.0', TRUE);
            /* jQuery custom scripts and plugins init */
            wp_register_script('isotope', TEMPLATEURL . '/js/jquery.isotope.min.js', array('jquery'), '1.0', TRUE);
            /* jQuery custom scripts and plugins init */
            wp_register_script('volcanno_functions', TEMPLATEURL . '/js/volcanno.functions.js', array('jquery'), '1.0', FALSE);
            /* jQuery custom scripts and plugins init */
            wp_register_script('volcanno_include', TEMPLATEURL . '/js/include.js', array('jquery', 'dl-menu', 'volcanno_functions', 'match-heights'), '1.0', TRUE);
            /* Portfolio scripts */
            wp_register_script('volcanno_portfolio', TEMPLATEURL . '/js/portfolio.js', array('jquery', 'isotope', 'magnific-popup'), '1.0', TRUE);


            /* Enqueue scripts */
            wp_enqueue_script('modernizr');
            wp_enqueue_script('touchswipe');
            wp_enqueue_script('dl-menu');
            wp_enqueue_script('volcanno_include');

            if (is_home() || is_singular('post') || is_archive()) {
                wp_enqueue_script('jplayer');
                wp_enqueue_script('nivoslider');
                wp_enqueue_script('isotope');
            }

            if (is_page_template('portfolio-template.php') || is_page_template('gallery-template.php')) {
                wp_enqueue_script('volcanno_portfolio');
            }

            if (is_singular('pi_portfolio') || is_tax('portfolio-category') || is_singular('pi_gallery') || is_tax('gallery-category')) {
                wp_enqueue_script('owl-carousel');
                wp_enqueue_script('magnific-popup');
                wp_enqueue_script('nivoslider');
                wp_enqueue_script('volcanno_portfolio');
            }

            // check if Content Maker is inactive and load stellar.js script
            if (!CONTENT_MAKER || (CONTENT_MAKER && !cma_get_settings('section-parallax'))) {
                wp_enqueue_script('stellarjs', TEMPLATEURL . '/js/jquery.stellar.min.js', array('jquery', 'volcanno_include'), '1.0', TRUE);
            }

            // pass settings to include.js file
            $static_header = $volcanno_options['static_header'];
            $retina = $volcanno_options['retina'];
            $portfolio_lightbox_current = '0';
            $portfolio_single_lightbox_current = '0';

            // portfolio lightbox config
            $lightbox_options = RWMB_META_BOX ? rwmb_meta('pg_portfolio_gallery_lightbox_options', '', get_the_ID()) : false;
            $lightbox_current = RWMB_META_BOX ? rwmb_meta('pg_portfolio_gallery_project_images', '', get_the_ID()) : false;

            // portfolio single lightbox config
            if (isset($volcanno_options['portfolio_related_posts_use_lightbox']) && $volcanno_options['portfolio_related_posts_use_lightbox'] == '1' && isset($volcanno_options['portfolio_related_posts_customization'])) {
                if ($volcanno_options['portfolio_related_posts_customization']['lightbox_current_project'] == '1') {
                    $portfolio_single_lightbox_current = '1';
                }
            }

            // output config object
            wp_localize_script('volcanno_include', 'VolcannoConfig', array(
                'cmaActive' => CONTENT_MAKER ? '1' : '0',
                'staticHeader' => $static_header,
                'retina' => $retina,
                'portfolioLightboxOptions' => $lightbox_options,
                'portfolioLightboxCurrent' => $lightbox_current,
                'portfolioSingleLightboxProject' => $portfolio_single_lightbox_current
            ));
        }
    }

}

add_action('wp_enqueue_scripts', 'volcanno_register_scripts');

/* --------------------------------------------------
 * Load necesarry scripts for proper theme work.
 * -------------------------------------------------- */

if (!function_exists('volcanno_theme_setup')) {

    function volcanno_theme_setup() {

        // Add default posts and comments RSS feed links to <head>.
        add_theme_support('automatic-feed-links');

        // title tag
        add_theme_support('title-tag');

        // Registering Main menu
        register_nav_menu('primary', 'Primary Menu');

        // Registering Responsive menu
        register_nav_menu('responsive', 'Responsive Menu');

        // Registering footer menu
        register_nav_menu('footer', 'Footer Menu');

        // Add support for a variety of post formats
        add_theme_support('post-formats', array('video', 'quote', 'audio', 'gallery', 'link'));

        // Add support for Shortcodes in Widgets
        add_filter('widget_text', 'do_shortcode');

        // This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
        add_theme_support('post-thumbnails', array('post', 'team_members'));

        // Make theme available for translation
        load_theme_textdomain('pi_framework', PI_THEME_DIR . 'languages');
        $locale = get_locale();
        $locale_file = PI_THEME_DIR . "languages/$locale.php";
        if (is_readable($locale_file))
            require_once $locale_file;
    }

}

add_action('after_setup_theme', 'volcanno_theme_setup');

/* -------------------------------------------------------------------- 
 * Load necesarry scripts.
  -------------------------------------------------------------------- */

if (!function_exists('volcanno_include_core_scripts')) {

    function volcanno_include_core_scripts() {
        // including all scripts required for theme proper work
        require_once get_template_directory() . '/core/core-includes.php';
    }

}

add_action('after_setup_theme', 'volcanno_include_core_scripts', 11);

/* -------------------------------------------------------------------------------
 * Sets the post excerpt length to 40 words.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
  ------------------------------------------------------------------------------- */
if (!function_exists('volcanno_excerpt_length')) {

    function volcanno_excerpt_length($length) {
        return 40;
    }

}
add_filter('excerpt_length', 'volcanno_excerpt_length');

/* -------------------------------------------------------------------
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
  ------------------------------------------------------------------- */
if (!function_exists('volcanno_page_menu_args')) {

    function volcanno_page_menu_args($args) {
        $args['show_home'] = true;
        return $args;
    }

}

add_filter('wp_page_menu_args', 'volcanno_page_menu_args');

/* ----------------------------------------
 * Tags widget customizations
  ---------------------------------------- */
if (!function_exists('volcanno_tag_cloud_args')) {

    function volcanno_tag_cloud_args($args) {
        $args['smallest'] = 11;
        $args['largest'] = 11;
        $args['unit'] = "px";
        return $args;
    }

}
add_filter('widget_tag_cloud_args', 'volcanno_tag_cloud_args');

/* ----------------------------------------
 * Echo logo image HTML
  ---------------------------------------- */
if (!function_exists('volcanno_get_logo_html')) {

    function volcanno_get_logo_html($args = array()) {
        global $volcanno_options, $vlc_is_retina;

        $website_name = esc_attr(get_bloginfo('name'));
        $logo_width = '';
        $styles = '';

        if ($vlc_is_retina && !empty($volcanno_options['retina_logo']['url'])) {
            $logo = $volcanno_options['retina_logo']['url'];
            $logo_width = $volcanno_options['logo']['width'];
        } else if (!empty($volcanno_options['logo']['url'])) {
            $logo = $volcanno_options['logo']['url'];
            $logo_width = $volcanno_options['logo']['width'];
        } else {
            $logo = TEMPLATEURL . "/img/logo.png";
            $logo_width = "138";
        }

        if (!empty($args) && $args['float']) {
            $float = $args['float'];
            $styles = "style='float: {$float};'";
        }
        
        $logo = esc_url($logo);

        $logo_img = "<img src='{$logo}' alt='{$website_name}' width='{$logo_width}' {$styles}/>";

        return $logo_img;
    }

}

/* -------------------------------------------------
 * Register our sidebars and widgetized areas. 
 * Also register the default Epherma widget.
  ------------------------------------------------- */
if (!function_exists('volcanno_widgets_init')) {

    function volcanno_widgets_init() {
        global $wpdb;

        register_sidebar(array(
            'name' => esc_html__('Main Sidebar', 'pi_framework'),
            'id' => 'volcanno-sidebar-1',
            'description' => esc_html__('Blog page widget area', 'pi_framework'),
            'before_widget' => '<li id="%1$s" class="widget %2$s clearfix">',
            'after_widget' => "</li>",
            'before_title' => '<div class="title"><h3>',
            'after_title' => '</h3></div>',
        ));

        register_sidebar(array(
            'name' => esc_html__('Footer Area One', 'pi_framework'),
            'id' => 'volcanno-sidebar-2',
            'description' => esc_html__('An optional widget area for your site footer', 'pi_framework'),
            'before_widget' => '<li id="%1$s" class="widget %2$s">',
            'after_widget' => "</li>",
            'before_title' => '<div class="title"><h3>',
            'after_title' => '</h3></div>'
        ));

        register_sidebar(array(
            'name' => esc_html__('Footer Area Two', 'pi_framework'),
            'id' => 'volcanno-sidebar-3',
            'description' => esc_html__('An optional widget area for your site footer', 'pi_framework'),
            'before_widget' => '<li id="%1$s" class="widget %2$s">',
            'after_widget' => "</li>",
            'before_title' => '<div class="title"><h3>',
            'after_title' => '</h3></div>'
        ));

        register_sidebar(array(
            'name' => esc_html__('Footer Area Three', 'pi_framework'),
            'id' => 'volcanno-sidebar-4',
            'description' => esc_html__('An optional widget area for your site footer', 'pi_framework'),
            'before_widget' => '<li id="%1$s" class="widget %2$s">',
            'after_widget' => "</li>",
            'before_title' => '<div class="title"><h3>',
            'after_title' => '</h3></div>'
        ));

        register_sidebar(array(
            'name' => esc_html__('Footer Area Four', 'pi_framework'),
            'id' => 'volcanno-sidebar-5',
            'description' => esc_html__('An optional widget area for your site footer', 'pi_framework'),
            'before_widget' => '<li id="%1$s" class="widget %2$s">',
            'after_widget' => "</li>",
            'before_title' => '<div class="title"><h3>',
            'after_title' => '</h3></div>'
        ));

        // create sidebar for pages with left or right sidebar
        $query = $wpdb->prepare("SELECT ID FROM {$wpdb->posts} AS posts, {$wpdb->postmeta} AS meta WHERE meta.post_id = posts.ID AND meta.meta_key = %s AND meta.meta_value IN (%s, %s)", 'pg_sidebar', 'left', 'right');
        $post_ids = $wpdb->get_results($query);

        foreach ((array) $post_ids as $id) {
            $post = get_post(intval($id->ID));

            $sidebar_title = $post->post_title;
            $sidebar_id = "volcanno-page-sidebar-" . $post->ID;
            register_sidebar(array(
                'name' => $sidebar_title,
                'id' => $sidebar_id,
                'description' => esc_html__('An optional widget area for page ', 'pi_framework') . $sidebar_title,
                'before_widget' => '<li id="%1$s" class="widget %2$s clearfix">',
                'after_widget' => "</li>",
                'before_title' => '<div class="title"><h3>',
                'after_title' => '</h3></div>'
            ));
        }
    }

}
add_action('widgets_init', 'volcanno_widgets_init');

/* -----------------------------------------
 * Template for comments and pingbacks.
  ----------------------------------------- */

if (!function_exists('volcanno_render_comment')) {

    function volcanno_render_comment($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type) {
            case 'pingback' :
            case 'trackback' :
                ?>
                <li class="post pingback">
                    <p>
                        <?php esc_html_e('Pingback', 'pi_framework'); ?> <?php comment_author_link(); ?><?php edit_comment_link(esc_html__('Edit', 'pi_framework'), '<span class="edit-link">', '</span>'); ?>
                    </p>
                    <?php
                    break;
                default :
                    ?>
                <li id="li-comment-<?php comment_ID(); ?>">
                    <article id="comment-<?php comment_ID(); ?>" class="comment">
                        <div class="avatar-container">                            
                            <?php
                            $avatar_size = 87;
                            echo get_avatar($comment, $avatar_size, false, get_comment_author());
                            ?>                            
                        </div>
                        <ul class="comment-meta">
                            <li>
                                <a href="<?php get_comment_author_link(); ?>" class="author"><?php comment_author(); ?></a>
                            </li>
                            <li class="date">
                                <?php
                                echo get_comment_date() . " at ";
                                comment_time();
                                ?>  
                            </li>                            
                        </ul>

                        <div class="comment-body">
                            <?php
                            comment_text();
                            comment_reply_link(array_merge($args, array('reply_text' => esc_html__('Reply', 'pi_framework'), 'depth' => $depth, 'max_depth' => $args['max_depth'])));
                            ?>
                        </div> 
                    </article><!-- #comment-## -->
                    <?php
                    break;
            }
        }

    }

    /* -----------------------------------------
     * Comment Form styling
      ----------------------------------------- */

    if (!function_exists('volcanno_get_comment_form')) {

        function volcanno_get_comment_form($fields) {

            // get current commenter data
            $commenter = wp_get_current_commenter();

            // check if field is required
            $req = get_option('require_name_email');
            $aria_req = ( $req ? " aria-required='true' required" : '' );

            // change fields style
            $fields['fields']['author'] = '<fieldset class="name-container"><label for="comment-name">' . esc_html__('Name:', 'pi_framework') . ($req ? ' <span class="text-color">*</span>' : '') . '</label>' .
                    '<span class="comment-name-container comment-input-container"><input type="text" name="author" class="name" id="comment-name" value="' . esc_attr($commenter['comment_author']) . '" size="22" tabindex="1"' . $aria_req . '/></span></fieldset>';

            $fields['fields']['email'] = '<fieldset class="email-container"><label for="comment-email">' . esc_html__('E-Mail:', 'pi_framework') . ($req ? ' <span class="text-color">*</span>' : '') . '</label>' .
                    '<span class="comment-email-container comment-input-container"><input type="email" name="email" class="email" id="comment-email" value="' . esc_attr($commenter['comment_author_email']) . '" size="22" tabindex="2" ' . $aria_req . '/></span></fieldset>';

            $fields['fields']['url'] = '';

            $fields['comment_field'] = '<fieldset class="message"><label for="comment-message">' . esc_html__('Message:', 'pi_framework') . ($req ? ' <span class="text-color">*</span>' : '') . '</label><span class="comment-message-container comment-input-container"><textarea name="comment" class="comment-text" id="comment-message" rows="8" tabindex="4" aria-required="true" required></textarea></span></fieldset>';

            $fields['comment_notes_before'] = '';
            $fields['comment_notes_after'] = '<p class="reguired-fields">' . esc_html__('Required fields are marked ', 'pi_framework') . '<span class="text-color">*</span></p>';
            $fields['cancel_reply_link'] = ' - ' . esc_html__('Cancel reply', 'pi_framework');
            $fields['title_reply'] = esc_html__('Leave a comment', 'pi_framework');
            $fields['id_submit'] = 'comment-reply';
            $fields['label_submit'] = esc_html__('Submit', 'pi_framework');

            return $fields;
        }

    }

    add_filter('comment_form_defaults', 'volcanno_get_comment_form');

    /* -----------------------------------------
     * Paginate function for Blog and Portfolio
      ----------------------------------------- */
    if (!function_exists('volcanno_pagination')) {

        function volcanno_pagination($location) {
            global $wp_query, $volcanno_options, $wp_rewrite;

            $pages = '';
            $pagination = '';
            $max = $wp_query->max_num_pages;

            // if variable paged isn't set
            if (!$current = get_query_var('paged'))
                $current = 1;

            // set parameters
            $args = array(
                'base' => str_replace(999999999, '%#%', get_pagenum_link(999999999)),
                'format' => '',
                'total' => $max,
                'current' => $current,
                'show_all' => true,
                'type' => 'array',
                'prev_text' => '&larr;',
                'next_text' => '&rarr;',
                'prev_next' => false,
                'mid_size' => 3,
                'end_size' => 1
            );

            if ($location == 'portfolio') {
                $args['base'] = @add_query_arg('page', '%#%');

                // check if permalinks are used
                if ($wp_rewrite->using_permalinks())
                    $args['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');
                if (!empty($wp_query->query_vars['s']))
                    $args['add_args'] = array('s' => get_query_var('s'));
            }

            $previous_label = esc_html__('&#60; Previous', 'pi_framework');
            $next_label = esc_html__('Next &#62;', 'pi_framework');

            // previous and next links html
            $prev_page_link = $current == 1 ? "" : "<li><a class='fa fa-angle-double-left' href='" . get_pagenum_link($current - 1) . "'></a></li>";
            $next_page_link = $current == $max ? "" : "<li><a class='fa fa-angle-double-right' href='" . get_pagenum_link($current + 1) . "'></a></li>";

            // get page link
            $pagination_links = paginate_links($args);

            // loop through pages
            if (!empty($pagination_links)) {
                foreach ($pagination_links as $index => $link) {
                    $link = str_replace('</span>', '</a>', $link);
                    $link = str_replace('<span', '<a', $link);

                    $pagination .= "<li " . (($index + 1) == $current ? "class='active'>" : ">") . $link . "</li>";
                }
            }

            // if there is more then one page send html to browser
            if ($max > 1) {
                if ($location == 'portfolio' || $location == 'blog_timeline') {
                    $container = 'div';
                } else {
                    $container = 'li';
                }

                $pagination_html = "<{$container} class='pagination'>
                        <ul>
                        {$prev_page_link}
                        {$pagination}
                        {$next_page_link}
                        </ul>
                      </{$container}>";

                if ($location == 'portfolio') {
                    echo "<div class='row'><div class='col-md-12'>" . $pagination_html . "</div></div>";
                } else {
                    echo balanceTags($pagination_html);
                }
            }
        }

    }

    /* --------------------------------------------------------------
     * Portfolio taxonomy archive.
     * Set posts_per_page variable based on value from Theme options.
     * -------------------------------------------------------------- */

    if (!function_exists('volcanno_portfolio_set_posts_per_page')) {

        function volcanno_portfolio_set_posts_per_page($query) {
            global $volcanno_options;

            if (!is_admin() && $query->is_tax() && ( $query->is_archive() )) {
                $taxonomy_vars = $query->query_vars;
                if (isset($taxonomy_vars['portfolio-category']))
                    $tax = 'portfolio';

                if (isset($taxonomy_vars['gallery-category']))
                    $tax = 'gallery';

                if (!empty($tax)) {
                    if ($tax == 'portfolio') {
                        $posts_per_page = $volcanno_options['portfolio_category_pagination'];
                    } else if ($tax == 'gallery') {
                        $posts_per_page = $volcanno_options['gallery_category_pagination'];
                    }

                    $query->set('posts_per_page', $posts_per_page);
                    $query->set('post_type', "pi_" . $tax);
                }
            }

            return $query;
        }

    }

    add_action('pre_get_posts', 'volcanno_portfolio_set_posts_per_page');

    /* -----------------------------------------
     * Filter that returns Blog image size
      ----------------------------------------- */
    if (!function_exists('volcanno_get_blog_image_size')) {

        function volcanno_get_blog_image_size($vlc_blog_style) {

            // set image width and height based on blog style
            switch ($vlc_blog_style) {
                case 'blog-post-small':
                    $img_width = 300;
                    $img_height = 333;
                    break;
                case 'blog-post-large':
                    $img_width = 748;
                    $img_height = 308;
                    break;
                case 'blog-post-masonry-sidebar':
                    $img_width = 408;
                    $img_height = 453;
                    break;
                case 'blog-post-masonry-full':
                    $img_width = 360;
                    $img_height = 400;
                    break;
                case 'blog-post-timeline':
                    $img_width = 520;
                    $img_height = 300;
                    break;
                default:
                    $img_width = 748;
                    $img_height = 308;
                    break;
            }

            return array('width' => $img_width, 'height' => $img_height);
        }

    }

    add_filter('volcanno_blog_image_width', 'volcanno_get_blog_image_size');

    /**
     *
     * Echo post author html
     *
     */
    if (!function_exists('volcanno_post_author_html')) {

        function volcanno_post_author_html() {
            global $volcanno_options;

            if ($volcanno_options['blog_single_show_author'] == '1'):
                $about_the_author = $volcanno_options['blog_single_author_section_title'];
                $avatar_size = 90;
                $post_author_id = get_the_author_meta('ID');
                $post_author_bio = get_the_author_meta('description');
                $post_author_name = get_the_author_meta('display_name');
                $post_author_website = get_the_author_meta('user_url');
                ?>
                <!-- .post-author start -->
                <article class="blog-single-author">
                    <div class="avatar-container">
                        <?php echo get_avatar($post_author_id, $avatar_size); ?>
                    </div>

                    <div class="text-container">
                        <h4><?php echo esc_html($post_author_name) ?></h4>

                        <p><?php echo esc_html($post_author_bio) ?> <a href="<?php echo esc_url($post_author_website) ?>"><strong> <?php echo esc_url($post_author_website) ?></strong></a>
                        </p>
                    </div>
                </article><!-- post-author end -->
                <?php
            endif;
        }

    }

    add_action('volcanno_post_author_html', 'volcanno_post_author_html');

    /**
     *
     * Intercept Simple Share Buttons Adder output.
     *
     */
    if (!function_exists('volcanno_remove_ssba_from_content')) {

        function volcanno_remove_ssba_from_content($content, $using_shortcode) {

            if (!$using_shortcode && (is_page() || is_singular('pi_portfolio'))) {
                $content = "<section class='page-content'>"
                        . "<section class='container'>"
                        . "<div class='row'>"
                        . "<div class='col-md-12'>"
                        . $content
                        . "</div></seection></section>";
            }

            return $content;
        }

    }
    if (shortcode_exists('ssba')) {
        add_filter('ssba_html_output', 'volcanno_remove_ssba_from_content', 10, 2);
    }

    /**
     * Add themes to Max Mega Menu plugin
     * 
     * @param type $themes
     * @return array
     */
    function volcanno_add_megamenu_custom_theme($themes) {
        $themes['mixed'] = array(
            'title' => esc_html__("Mixed", "pi_framework"),
            'container_background_from' => 'transparent',
            'container_background_to' => 'transparent',
            'container_padding_left' => '0px',
            'container_padding_right' => '0px',
            'container_padding_top' => '0px',
            'container_padding_bottom' => '0px',
            'container_border_radius_top_left' => '0px',
            'container_border_radius_top_right' => '0px',
            'container_border_radius_bottom_left' => '0px',
            'container_border_radius_bottom_right' => '0px',
            'arrow_up' => 'dash-f142',
            'arrow_down' => 'dash-f140',
            'arrow_left' => 'dash-f141',
            'arrow_right' => 'dash-f139',
            'menu_item_align' => 'left',
            'menu_item_background_from' => 'transparent',
            'menu_item_background_to' => 'transparent',
            'menu_item_background_hover_from' => 'transparent',
            'menu_item_background_hover_to' => 'transparent',
            'menu_item_spacing' => '0px',
            'menu_item_link_font' => 'inherit',
            'menu_item_link_font_size' => '12px',
            'menu_item_link_height' => '67px',
            'menu_item_link_color' => '#252525',
            'menu_item_link_weight' => '600',
            'menu_item_link_text_transform' => 'uppercase',
            'menu_item_link_text_decoration' => 'none',
            'menu_item_link_color_hover' => '#117dc2',
            'menu_item_link_weight_hover' => '600',
            'menu_item_link_text_decoration_hover' => 'none',
            'menu_item_link_padding_left' => '15px',
            'menu_item_link_padding_right' => '15px',
            'menu_item_link_padding_top' => '10px',
            'menu_item_link_padding_bottom' => '10px',
            'menu_item_link_border_radius_top_left' => '0px',
            'menu_item_link_border_radius_top_right' => '0px',
            'menu_item_link_border_radius_bottom_left' => '0px',
            'menu_item_link_border_radius_bottom_right' => '0px',
            'menu_item_highlight_current' => 'off',
            'menu_item_divider' => 'off',
            'menu_item_divider_color' => 'rgba(255, 255, 255, 0.1)',
            'menu_item_divider_glow_opacity' => '0.1',
            'panel_background_from' => '#31393f',
            'panel_background_to' => '#31393f',
            'panel_width' => '100%',
            'panel_border_color' => '#fff',
            'panel_border_left' => '0px',
            'panel_border_right' => '0px',
            'panel_border_top' => '0px',
            'panel_border_bottom' => '0px',
            'panel_border_radius_top_left' => '0px',
            'panel_border_radius_top_right' => '0px',
            'panel_border_radius_bottom_left' => '0px',
            'panel_border_radius_bottom_right' => '0px',
            'panel_header_color' => '#117dc2',
            'panel_header_text_transform' => 'uppercase',
            'panel_header_font' => 'Raleway',
            'panel_header_font_size' => '10px',
            'panel_header_font_weight' => 'bold',
            'panel_header_text_decoration' => 'none',
            'panel_header_padding_top' => '10px',
            'panel_header_padding_right' => '0px',
            'panel_header_padding_bottom' => '5px',
            'panel_header_padding_left' => '0px',
            'panel_padding_left' => '0px',
            'panel_padding_right' => '0px',
            'panel_padding_top' => '0px',
            'panel_padding_bottom' => '0px',
            'panel_widget_padding_left' => '15px',
            'panel_widget_padding_right' => '15px',
            'panel_widget_padding_top' => '15px',
            'panel_widget_padding_bottom' => '15px',
            'panel_font_size' => '12px',
            'panel_font_color' => '#ddd',
            'panel_font_family' => 'Raleway',
            'flyout_width' => '150px',
            'flyout_border_color' => '#ffffff',
            'flyout_border_left' => '0px',
            'flyout_border_right' => '0px',
            'flyout_border_top' => '0px',
            'flyout_border_bottom' => '0px',
            'flyout_border_radius_top_left' => '0px',
            'flyout_border_radius_top_right' => '0px',
            'flyout_border_radius_bottom_left' => '0px',
            'flyout_border_radius_bottom_right' => '0px',
            'flyout_link_padding_left' => '10px',
            'flyout_link_padding_right' => '10px',
            'flyout_link_padding_top' => '0px',
            'flyout_link_padding_bottom' => '0px',
            'flyout_link_weight' => '600',
            'flyout_link_weight_hover' => '600',
            'flyout_link_height' => '35px',
            'flyout_link_text_decoration' => 'none',
            'flyout_link_text_decoration_hover' => 'none',
            'flyout_background_from' => '#31393f',
            'flyout_background_to' => '#31393f',
            'flyout_background_hover_from' => '#31393f',
            'flyout_background_hover_to' => '#31393f',
            'flyout_link_size' => '11px',
            'flyout_link_color' => '#ddd',
            'flyout_link_color_hover' => '#117dc2',
            'flyout_link_family' => 'Raleway',
            'flyout_link_text_transform' => 'normal',
            'responsive_breakpoint' => '600px',
            'responsive_text' => '',
            'line_height' => '1.42857143',
            'z_index' => '999',
            'shadow' => 'off',
            'custom_css' => '
#{$wrap} #{$menu} {
    /** Custom styles should be added below this line **/
}
#{$wrap} { 
    clear: both;
}'
        );

        return $themes;
    }

    add_filter('megamenu_themes', 'volcanno_add_megamenu_custom_theme');

    /**
     * Edit Tinymce settings i.e. add custom classes for Tables in Editor
     * 
     * @param array $settings Tinymce settings
     * @return array
     */
    function volcanno_add_tinymce_tables($settings) {
        $new_styles = array(
            array(
                'title' => 'None',
                'value' => ''
            ),
            array(
                'title' => 'Striped',
                'value' => 'table-striped',
            ),
            array(
                'title' => 'Bordered',
                'value' => 'table-bordered',
            ),
            array(
                'title' => 'Hover',
                'value' => 'table-hover',
            )
        );
        $settings['table_class_list'] = json_encode($new_styles);
        return $settings;
    }

    add_filter('tiny_mce_before_init', 'volcanno_add_tinymce_tables');

    /**
     * Set blog style to "Large" for Search results page
     * 
     * @param string $style Blog style
     * @return string
     */
    function volcanno_search_page_blog_style($style) {

        // set Large blog style
        if (is_search()) {
            $style = 'blog-post-large';
        }

        return $style;
    }

    add_filter('volcanno_blog_style', 'volcanno_search_page_blog_style');
    
    ?>