<!DOCTYPE html>
<!--[if IE 6]>
<html id="ie6" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 7]>
<html id="ie7" <?php language_attributes(); ?>>
<![endif]-->
<!--[if IE 8]>
<html id="ie8" <?php language_attributes(); ?>>
<![endif]-->
<!--[if !(IE 6) | !(IE 7) | !(IE 8)  ]><!-->
<html <?php language_attributes(); ?>>
    <!--<![endif]-->
    <head>
        <meta charset="<?php bloginfo('charset'); ?>" />

        <?php global $volcanno_options, $vlc_is_retina ?>

        <?php if ($volcanno_options['responsive'] == '1'): ?>
            <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1" />
        <?php endif; ?>

        <?php
        if (!function_exists('_wp_render_title_tag')) {

            function volcanno_render_title() {
                ?>
                <title><?php wp_title('|', true, 'right'); ?></title>
                <?php
            }

            add_action('wp_head', 'volcanno_render_title');
        }
        ?>
        <link rel="profile" href="http://gmpg.org/xfn/11" />
        <link rel="pingback" href="<?php echo esc_url(get_bloginfo('pingback_url')); ?>" />

        <?php
        /* We add some JavaScript to pages with the comment form
         * to support sites with threaded comments (when in use).
         */
        if (is_singular() && get_option('thread_comments'))
            wp_enqueue_script('comment-reply');

        /*  Important wp_head() hook */
        wp_head();
        ?>
    </head>
    <?php
    global $volcanno_theme_config;

    // website layout layout
    $website_layout = "layout-" . $volcanno_options['website_layout'];
    $website_layout = apply_filters('volcanno_website_layout', $website_layout);

    // add homepage class
    $homepage = is_front_page() ? 'homepage' : '';

    // custom body classes
    $pi_body_classes = array($website_layout, $homepage);

    // get header style
    $header_style = apply_filters('volcanno_header_style', $volcanno_options['header_style']);

    // get header color
    $header_color = apply_filters('volcanno_header_color', $volcanno_options['header_color']);

    // check if search is used
    $header_search = $volcanno_options['header_search'] == '0' ? 'search-hidden' : '';

    if ($header_style == 'standard-top-bar') {
        $header_class = 'header-type-1';
        $header_wrapper_class = '';
    } else if ($header_style == 'standard-simple') {
        $header_class = 'header-type-1';
        $header_wrapper_class = 'header-simple';
    } else if ($header_style == 'bottom-top-bar') {
        $header_class = 'header-type-2 bottom-top-bar';
        $header_wrapper_class = 'header-wrapper-2';
    } else if ($header_style == 'bottom-simple') {
        $header_class = 'header-type-2 bottom-simple';
        $header_wrapper_class = 'header-wrapper-2 header-simple';
    } else if ($header_style == 'centered-top-bar') {
        $header_class = 'header-type-2 centered';
        $header_wrapper_class = 'header-wrapper-2';
    } else if ($header_style == 'centered-simple') {
        $header_class = 'header-type-2 centered';
        $header_wrapper_class = 'header-wrapper-2 header-simple';
    } else if ($header_style == 'transparent') {
        $header_class = 'header-type-1';
        $header_wrapper_class = 'header-transparent header-simple';
    } else {
        $header_class = 'header-type-1';
        $header_wrapper_class = '';
    }

    if ($volcanno_options['static_header'] == '0') {
        $header_wrapper_class .= ' not-static';
    }

    /**
     * Renders logo HTML.
     * 
     * @return type string
     */
    function volcanno_generate_logo_html() {
        ob_start();
        ?>
        <!-- .logo start -->
        <div class="logo">
            <a href="<?php echo esc_url(home_url()); ?>">
                <?php
                echo volcanno_get_logo_html();
                ?>
            </a>
        </div><!-- logo end -->
        <?php
        return ob_get_clean();
    }

    /**
     * Renders search HTML.
     * 
     * @return type string
     */
    function volcanno_generate_search_html() {
        ob_start();
        ?>
        <!-- #search-box start -->
        <div id="search">
            <form action="<?php echo esc_url(home_url('/')); ?>" method="get">
                <input class="search-submit" type="submit" />
                <input id="m_search" name="s" type="text" placeholder="<?php esc_html_e('Type and hit enter...', 'pi_framework') ?>" onkeydown="if (event.keyCode == 13) {
                                this.form.submit();
                                return false;
                            }"/>                        
            </form>
        </div><!-- #search-box end -->
        <?php
        return ob_get_clean();
    }

    /**
     * Renders main menu in header.
     * 
     * @return type string
     */
    function volcanno_generate_menu_html() {
        ob_start();

        wp_nav_menu(
                array(
                    'theme_location' => 'primary',
                    'container' => false,
                    'items_wrap' => '<ul id="%1$s" class="nav navbar-nav pi-nav %2$s">%3$s</ul>',
                    'walker' => new Volcanno_Theme_Menu_Walker(),
                    'fallback_cb' => false
                )
        );

        return ob_get_clean();
    }

    /**
     * Renders responsive menu in header. 
     * 
     * @return type string
     */
    function volcanno_generate_responsive_menu_html() {
        ob_start();
        ?>
        <!-- responsive navigation start -->
        <div id="dl-menu" class='dl-menuwrapper'>
            <button class="dl-trigger"><?php esc_html_e('Open Menu', 'pi_framework') ?></button>
            <?php
            wp_nav_menu(
                    array(
                        'theme_location' => 'responsive',
                        'container' => false,
                        'items_wrap' => '<ul id="%1$s" class="%2$s dl-menu">%3$s</ul>',
                        'walker' => new Volcanno_Theme_Responsive_Menu_Walker(),
                        'fallback_cb' => false,
                        'responsive_menu' => '1' //argument added to distinguish regular menu with responsive
                    )
            );
            ?> <!-- responsive navigation end -->
        </div>  
        <?php
        return ob_get_clean();
    }

    /**
     * Renders contact section in header.
     * 
     * @global type $volcanno_options
     * @global type $volcanno_theme_config
     * @return type string
     */
    function volcanno_generate_contact_html() {
        global $volcanno_options, $volcanno_theme_config;

        ob_start();
        ?>
        <ul id="quick-links">
            <?php
            foreach ($volcanno_options['header_contact']['icon'] as $index => $icon) {
                ?>
                <li>
                    <i class="<?php echo esc_html($icon) ?>"></i>
                    <span><?php echo wp_kses($volcanno_options['header_contact']['text'][$index], $volcanno_theme_config['allowed_html_tags']) ?></span>
                </li>
            <?php } ?>
        </ul><!-- .contact-info end -->
        <?php
        return ob_get_clean();
    }

    /**
     * Renders social icons section in header.
     * 
     * @global type $volcanno_options
     * @return type string
     */
    function volcanno_generate_social_html() {
        global $volcanno_options;

        ob_start();
        ?>
        <!--- .social-links start -->
        <ul id="social-links">
            <?php
            foreach ($volcanno_options['header_social_icons']['icon'] as $index => $icon) {
                ?>
                <li>
                    <a href="<?php echo esc_url($volcanno_options['header_social_icons']['text'][$index]) ?>" class="<?php echo sanitize_html_class($icon) ?>"></a>
                </li>
            <?php } ?>
        </ul><!-- .social-links end -->
        <?php
        return ob_get_clean();
    }
    ?>
    <body <?php body_class($pi_body_classes); ?>>

        <?php do_action('volcanno_body_start'); ?>

        <?php if ($website_layout == 'layout-boxed'): ?>
            <!-- .page-wrapper start -->
            <div id="page-wrapper" class="clearfix">
            <?php endif; ?>
            <!-- #header-wrapper start -->
            <section id="header-wrapper" class="clearfix <?php echo esc_attr($header_wrapper_class), " ", sanitize_html_class($header_search) ?>">

                <header id="header" class="<?php echo esc_attr($header_class), " ", sanitize_html_class($header_color) ?>">

                    <?php if ($header_style == 'standard-top-bar' || $header_style == 'bottom-top-bar' || $header_style == 'centered-top-bar') { ?>
                        <!-- #top-bar-wrapper start -->
                        <div id="top-bar-wrapper" class="clearfix">

                            <!-- .top-bar start -->
                            <div id="top-bar" class="clearfix">

                                <?php
                                if (isset($volcanno_options['header_contact']) && is_array($volcanno_options['header_contact']) && !empty($volcanno_options['header_contact']['icon'][0])):
                                    echo volcanno_generate_contact_html();
                                endif;
                                ?>

                                <?php
                                if (isset($volcanno_options['header_social_icons']) && is_array($volcanno_options['header_social_icons']) && !empty($volcanno_options['header_social_icons']['icon'][0])):
                                    echo volcanno_generate_social_html();
                                endif;
                                ?>

                            </div><!-- .top-bar end -->
                        </div><!-- #top-bar-wrapper end -->
                    <?php } ?>

                    <!-- Main navigation and logo container -->
                    <div class="header-inner">
                        <!-- .container start -->
                        <div class="container">

                            <?php if ($header_style == 'standard-top-bar' || $header_style == 'standard-simple' || $header_style == 'transparent'): ?>
                                <!-- .main-nav start -->
                                <div class="main-nav">
                                <?php endif; ?>
                                <!-- .row start -->
                                <div class="row">
                                    <div class="col-md-12">

                                        <?php if ($header_style == 'bottom-simple' || $header_style == 'bottom-top-bar'): ?>
                                            <?php echo volcanno_generate_logo_html(); ?>

                                            <div class="header-info-widgets">
                                                <ul>
                                                    <?php
                                                    foreach ($volcanno_options['menu_contact_text']['icon'] as $index => $icon) {
                                                        ?>
                                                        <li>
                                                            <div class="icon-container">
                                                                <i class="<?php echo esc_html($icon) ?>"></i>
                                                            </div>

                                                            <div class="text-container">                                                
                                                                <span class="big"><?php echo wp_kses($volcanno_options['menu_contact_text']['text'][$index], $volcanno_theme_config['allowed_html_tags']) ?></span>
                                                            </div><!-- .text-container end -->
                                                        </li>
                                                    <?php } ?>
                                                </ul>
                                            </div><!-- .header-info-widgets end -->
                                        <?php endif; ?>

                                        <?php if ($header_style == 'centered-top-bar' || $header_style == 'centered-simple'): ?>
                                            <?php echo volcanno_generate_logo_html(); ?>
                                        <?php endif; ?>

                                        <?php if ($header_style == 'standard-top-bar' || $header_style == 'standard-simple' || $header_style == 'transparent'): ?>

                                            <!-- .navbar.pi-mega start -->
                                            <nav class="navbar navbar-default nav-left pi-mega" role="navigation">									
                                                <!-- .navbar-header start -->
                                                <div class="navbar-header">
                                                    <?php echo volcanno_generate_logo_html(); ?>
                                                </div>

                                                <!-- Collect the nav links, forms, and other content for toggling -->
                                                <div class="collapse navbar-collapse">
                                                    <?php
                                                    echo volcanno_generate_menu_html();
                                                    echo volcanno_generate_responsive_menu_html();
                                                    ?>
                                                    <?php
                                                    if ($volcanno_options['header_search'] == '1'):
                                                        echo volcanno_generate_search_html();
                                                    endif;
                                                    ?>
                                                </div><!-- .navbar.navbar-collapse end --> 
                                            </nav><!-- .navbar.pi-mega end -->

                                        <?php endif; ?>
                                    </div><!-- .col-md-12 end -->
                                </div><!-- .row end -->  
                                <?php if ($header_style == 'standard-top-bar' || $header_style == 'standard-simple' || $header_style == 'transparent'): ?>
                                </div><!-- .main-nav end -->
                            <?php endif; ?>
                        </div><!-- .container end -->

                        <?php if ($header_style == 'bottom-top-bar' || $header_style == 'bottom-simple' || $header_style == 'centered-top-bar' || $header_style == 'centered-simple'): ?>
                            <div class="container-fluid">
                                <!-- .main-nav start -->
                                <div class="main-nav">
                                    <!-- .row start -->
                                    <div class="row">
                                        <div class="col-md-12">
                                            <!-- .navbar.pi-mega start -->
                                            <nav class="navbar navbar-default nav-left pi-mega" role="navigation">
                                                <!-- Collect the nav links, forms, and other content for toggling -->
                                                <div class="collapse navbar-collapse">
                                                    <?php
                                                    echo volcanno_generate_menu_html();
                                                    echo volcanno_generate_responsive_menu_html();
                                                    ?>

                                                    <?php
                                                    if ($volcanno_options['header_search'] == '1'):
                                                        echo volcanno_generate_search_html();
                                                    endif;
                                                    ?>
                                                </div>
                                            </nav>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>                        

                    </div><!-- .header-inner end -->
                </header>
            </section><!-- #header-wrapper end -->
