<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Accordion")) {

    class CMA_Shortcodes_Accordion extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Accordion', 'pi_framework');
            $settings['description'] = esc_html__('Simple UI component.', 'pi_framework');
            $settings['shortcode'] = 'cma_accordion';
            $settings['nested'] = array('cma_accordion_item');
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-accordion', CMA_CONTENT_URL . 'accordion/js/accordion.js', array('jquery'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            $html = '';
            $i = 1;
            $icon_class = '';
            $type_classes = '';

            extract(shortcode_atts(array(
                'type' => 'default',
                'items' => '',
                'active' => '1',
                'style' => 'default'
                            ), $atts, 'cma_accordion'));

            if ($type != 'faq' && $style == 'icons')
                $icon_class = 'icons';

            if ($type == 'simple')
                $type_classes = "default simple";

            if ($type == 'faq')
                $type_classes = "simple faq-2";

            $html .= "<article class='accordion default {$type_classes} {$icon_class}'>";

            foreach ($items as $index => $item) {

                $icon_html = '';
                $icon = '';
                $icon_class = '';
                $item_content = do_shortcode($item['content']);
                if ($item_content == strip_tags($item_content, '<strong><a>')) {
                    $item_content = wpautop($item_content);
                }

                if ($type != 'faq' && $style == 'icons') {

                    if (!empty($item['icon'])) {
                        $icon = $item['icon'];
                    } else {
                        $icon = "fa fa-plus";
                    }
                    $icon_html = "<div class='icon-container'><i class='{$icon}'></i></div>";
                }

                if ($active == $i) {
                    $active_item = 'active';
                } else {
                    $active_item = '';
                }

                $html .= "<div class='title {$active_item}'>{$icon_html}<a title='{$item['title']}' href='#tab-{$index}{$i} '>{$item['title']}</a></div>";
                $html .= "<div class='content'>{$item_content}</div>";

                $i++;
            }

            $html .= '</article>';

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select accordion type.', 'pi_framework'),
                    'options' => array(
                        'default' => esc_html__('Default', 'pi_framework'),
                        'simple' => esc_html__('Simple', 'pi_framework'),
                        'faq' => esc_html__('FAQ', 'pi_framework'),
                    ),
                    'default' => 'default'
                ),
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Use icons or default plus icon.', 'pi_framework'),
                    'options' => array(
                        'default' => esc_html__('Default', 'pi_framework'),
                        'icons' => esc_html__('Icons', 'pi_framework')
                    ),
                    'default' => 'default',
                    'condition' => array('type', '!=', 'faq')
                ),
                'active' => array(
                    'type' => 'number',
                    'title' => esc_html__('Active item', 'pi_framework'),
                    'description' => esc_html__('Enter index of item that you want to be active e.g 2.', 'pi_framework'),
                    'default' => '1'
                ),
                'items' => array(
                    'type' => 'group',
                    'title' => esc_html__('Items', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'title' => array(
                            'type' => 'text',
                            'title' => esc_html__('Title', 'pi_framework'),
                            'description' => esc_html__('Item title.', 'pi_framework')
                        ),
                        'content' => array(
                            'type' => 'textarea',
                            'title' => esc_html__('Content', 'pi_framework'),
                            'description' => esc_html__('Add item content. Using HTML in content will automatically disable adding text in paragraph tag.', 'pi_framework')
                        ),
                        'icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon', 'pi_framework'),
                            'description' => esc_html__('Add button icon or leave empty for default plus icon.', 'pi_framework'),
                            'condition' => array('style', '=', 'icons')
                        ),
                    )
                )
            );
        }

    }

}
?>
