<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Blockquote")) {

    class CMA_Shortcodes_Blockquote extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Blockquote', 'pi_framework');
            $settings['description'] = esc_html__('Section with text that is quoted from another source.', 'pi_framework');
            $settings['shortcode'] = 'cma_blockquote';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;

            $bkg_style = '';
            $classes = '';

            extract(shortcode_atts(array(
                'type' => 'blockquote-style-1',
                'style' => 'default',
                'text' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse eget erat feugiat, bibendum libero eu, semper velit.',
                'author' => 'Blockquote Author',
                'bkg_color' => '',
                'dark_bkg' => '0'
                            ), $atts, 'cma_blockquote'));

            if (!empty($bkg_color)) {
                $bkg_style = "style='background-color: {$bkg_color};'";
                $classes .= ' custom-background';

                if ($dark_bkg == '1') {
                    $classes .= ' dark';
                }
            }

            $text = wp_kses_post($text);
            $author = wp_kses($author, $volcanno_theme_config['allowed_html_tags']);
            
            $html = "<blockquote class='{$type} {$style} {$classes}' {$bkg_style}><p>{$text}<cite>{$author}</cite></p></blockquote>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select element type.', 'pi_framework'),
                    'options' => array(
                        'blockquote-style-1' => esc_html__('Left border', 'pi_framework'),
                        'blockquote-style-2' => esc_html__('Background color', 'pi_framework')
                    ),
                    'default' => 'blockquote-style-1'
                ),
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select element style.', 'pi_framework'),
                    'options' => array(
                        'default' => esc_html__('Default (light blue)', 'pi_framework'),
                        'gradient' => esc_html__('Gradient', 'pi_framework'),
                        'theme-color' => esc_html__('Theme color style', 'pi_framework'),
                        'custom-color' => esc_html__('Custom color', 'pi_framework')
                    ),
                    'default' => 'default',
                    'condition' => array('type', '==', 'blockquote-style-2')
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Enter blockquote text here.', 'pi_framework')
                ),
                'author' => array(
                    'type' => 'text',
                    'title' => esc_html__('Author', 'pi_framework'),
                    'description' => esc_html__('Enter blockquote author.', 'pi_framework')
                ),
                'bkg_color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Background color', 'pi_framework'),
                    'description' => esc_html__('Set background color.', 'pi_framework'),
                    'condition' => array('style', '==', 'custom-color')
                ),
                'dark_bkg' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Dark background', 'pi_framework'),
                    'description' => esc_html__('Check this when you select dark color for background. Text will be changed to white for better contrast.', 'pi_framework')
                ),
            );
        }

    }

}
?>
