<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Blog")) {

    class CMA_Shortcodes_Blog extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Blog', 'pi_framework');
            $settings['description'] = esc_html__('Latest news from your Blog/News section.', 'pi_framework');
            $settings['shortcode'] = 'cma_blog';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }
        
        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-nivo-slider', CMA_CONTENT_URL . 'blog/js/blog.js', array('jquery', 'nivoslider', 'jplayer', 'isotope'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            global $vlc_is_retina;

            $html_content = '';
            $date_comments_html = '';
            $author_html = '';
            $date_visibility = '';

            extract(shortcode_atts(array(
                'type' => 'classic',
                'number' => '3',
                'id' => '',
                'date_comments' => '1',
                'author' => '1',
                'categories' => '0'
                            ), $atts, 'cma_blog'));

            if (!empty($id)) {
                $ids = explode(',', $id);

                $args = array(
                    'orderby' => 'post__in',
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'post__in' => $ids
                );

                //$recent_posts = get_posts($args);
            } else if (!empty($categories)) {

                $args = array(
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'category' => $categories
                );

                //$recent_posts = get_posts($args);
            } else {
                $args = array(
                    'posts_per_page' => $number,
                    'orderby' => 'post_date',
                    'order' => 'DESC',
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'cat' => $categories
                );

                //$recent_posts = wp_get_recent_posts($args, 'OBJECT');
            }

            // The Query
            $wp_query = new WP_Query($args);

            // The Loop
            while ($wp_query->have_posts()) : $wp_query->the_post();
                global $post, $vlc_blog_style;

                $image_class = '';
                $vlc_blog_style = 'blog-post-masonry-sidebar';

                // post url
                $post_permalink = get_permalink($post->ID);

                // post content
                if (!empty($post->post_excerpt)) {
                    $post_content = $post->post_excerpt;
                } else {
                    $post_content = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $post->post_content);
                    $post_content = strip_tags($post_content);
                    $post_content = volcanno_substr($post_content, 100, 3);
                }

                // post thumbnail
                $thumbnail = get_post_thumbnail_id($post->ID);
                $image_url = wp_get_attachment_image_src($thumbnail, 'full');

                $params = array("width" => 360, "height" => 166);
                if ($vlc_is_retina) {
                    $params = array("width" => 720, "height" => 332);
                }
                $featured_image = bfi_thumb($image_url[0], $params);

                $post_title_attr = esc_attr($post->post_title);

                if ($featured_image) {
                    $post_image_html = "<a href='{$post_permalink}'>
                                    <img src='{$featured_image}' alt='{$post_title_attr}' />
                                </a>";
                } else {
                    $post_image_html = '';
                    $image_class = 'no-image';
                }

                $post_format = get_post_format($post->ID);
                if (!$post_format) {
                    $post_icon = 'icon-image';
                } elseif ($post_format == 'video') {
                    $post_icon = 'icon-film';
                } elseif ($post_format == 'audio') {
                    $post_icon = 'icon-headphones';
                } elseif ($post_format == 'quote') {
                    $post_icon = 'icon-quote-left';
                } elseif ($post_format == 'gallery') {
                    $post_icon = 'icon-images';
                } elseif ($post_format == 'link') {
                    $post_icon = 'icon-link';
                } else {
                    $post_icon = 'icon-image';
                }

                //post meta
                $date_format = get_option('date_format');
                $post_date = get_the_time('M d', $post);

                // post author
                $post_author_name = get_the_author_meta('display_name', $post->post_author);
                $post_author_url = get_author_posts_url($post->post_author);

                // filter the number of comments
                $comments_number = get_comments_number($post->ID);

                // author html
                if ($author == '1')
                    $author_html = "<li class='icon-user'>
                                    <a href='{$post_author_url}'>{$post_author_name}</a>
                                </li>";

                // date and comments html
                if ($date_comments == '1')
                    $date_comments_html = "<a href='{$post_permalink}' class='comment-number'>
                                    <span class='date'>{$post_date}</span>
                                    <i class='fa fa-comments-o'></i>{$comments_number}
                                </a>";

                // two types of blog
                if ($type == 'classic') {

                    $html_content .= "<div class='col-md-4'>
                        <div class='blog-post-box'>
                            <div class='post-media'>
                                {$post_image_html}
                            </div>

                            <div class='comment-container'>
                                {$date_comments_html}
                            </div>

                            <div class='post-body'>
                                <a href='{$post_permalink}'><h3>{$post->post_title}</h3></a>
                                <p>{$post_content}</p>
                            </div>
                        </div>
                    </div>";
                } elseif ($type == 'style-2') {
                    // format date and month
                    $post_date_day = get_the_time('d', $post);
                    $post_date_month = mb_strtoupper(get_the_time('M', $post));

                    // comments formatting
                    if ($comments_number > 1)
                        $output = str_replace('%', number_format_i18n($comments_number), esc_html__('% Comments', 'pi_framework'));
                    elseif ($comments_number == 0)
                        $output = esc_html__('No Comments', 'pi_framework');
                    else // must be one
                        $output = esc_html__('1 Comment', 'pi_framework');

                    $comments_num = apply_filters('comments_number', $output, $comments_number);

                    $html_content .= " <li>
                                        <div class='date'>
                                            <span class='day'>{$post_date_day}</span>
                                            <span class='month'>{$post_date_month}</span>
                                        </div>

                                        <div class='body'>
                                            <a href='{$post_permalink}'><h3>{$post->post_title}</h3></a>
                                            <a href='{$post_permalink}'><span class='comment-number'>{$comments_num}</span></a>

                                            <p>{$post_content}</p>
                                        </div>
                                    </li>";
                } elseif ($type == 'masonry') {
                    $format = get_post_format();

                    ob_start();
                    get_template_part('content', $format);
                    $html_content .= ob_get_clean();
                }
            endwhile;

            if ($type == 'classic') {
                $html = "<div class='row'>{$html_content}</div>";
            } elseif ($type == 'style-2') {
                $html = "<div class='rpw_posts_widget style-2'><ul>{$html_content}</ul></div>";
            } elseif ($type == 'masonry') {
                $html = "<ul class='blog-posts isotope masonry-full'>{$html_content}</ul>";
            }

            wp_reset_postdata();

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select blog type.', 'pi_framework'),
                    'options' => array(
                        'classic' => esc_html__('Classic with large images', 'pi_framework'),
                        'style-2' => esc_html__('Simple (widget style)', 'pi_framework'),
                        'masonry' => esc_html__('Masonry', 'pi_framework')
                    ),
                    'default' => 'classic'
                ),
                'number' => array(
                    'type' => 'number',
                    'title' => esc_html__('Number', 'pi_framework'),
                    'description' => esc_html__('Number of blog posts to fetch.', 'pi_framework'),
                    'options' => array(
                        'min' => '1'
                    ),
                    'default' => '3'
                ),
                'id' => array(
                    'type' => 'text',
                    'title' => esc_html__('ID\'s', 'pi_framework'),
                    'description' => esc_html__('ID\'s of blog posts (comma separated).', 'pi_framework'),
                    'placeholder' => '1,2,3'
                ),
                'categories' => array(
                    'type' => 'text',
                    'title' => esc_html__('Categories', 'pi_framework'),
                    'description' => esc_html__('ID\'s of categories (comma separated).', 'pi_framework'),
                    'placeholder' => '1,2,3'
                ),
                'date_comments' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Show date and Comments', 'pi_framework'),
                    'description' => esc_html__('Check to show date and comments of the post.', 'pi_framework'),
                    'default' => '1'
                ),
                'author' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Show author', 'pi_framework'),
                    'description' => esc_html__('Check to show author of the post.', 'pi_framework'),
                    'default' => '1'
                )
            );
        }

    }

}
?>
