<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Buttons")) {

    class CMA_Shortcodes_Buttons extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Buttons', 'pi_framework');
            $settings['description'] = esc_html__('Buttons of multiple types, sizes and colors.', 'pi_framework');
            $settings['shortcode'] = 'cma_buttons';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            $btn_color = '';
            $btn_target = '';
            $classes = 'btn';

            extract(shortcode_atts(array(
                'type' => 'empty',
                'size' => 'medium',
                'position' => 'float-right',
                'icon' => '',
                'color' => '',
                'color_empty' => 'black',
                'text' => 'Button',
                'link' => '',
                'target' => '',
                            ), $atts, 'cma_buttons'));

            $link = esc_url($link);

            // button icon
            if (!empty($icon)) {
                $icon = "<i class='{$icon}'></i>";
                $classes .= ' icon-animated';
            }

            // open in new window
            if ($target == '1') {
                $btn_target = 'target="_BLANK"';
            }

            // button style
            if ($type == 'empty') {
                $classes .= ' empty';
                if (!empty($color_empty)) {                    
                    $classes .= " {$color_empty}";
                }
            } else {
                if (!empty($color)) {
                    $btn_color = "style='background: {$color};'";
                    $classes .= ' custom-color';
                }
            }

            // button size
            $classes .= ' btn-' . $size;

            // button position
            $classes .= ' ' . $position;
            
            $text = esc_html($text);

            $html = "<a href='{$link}' class='{$classes}' {$btn_target} {$btn_color}><span>{$icon} {$text}</span></a><div class='clearfix'></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select button type', 'pi_framework'),
                    'options' => array(
                        'empty' => esc_html__('Empty', 'pi_framework'),
                        'default' => esc_html__('Filled', 'pi_framework')
                    ),
                    'default' => 'empty'
                ),
                'size' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Size', 'pi_framework'),
                    'description' => esc_html__('Select button size', 'pi_framework'),
                    'options' => array(
                        'small' => esc_html__('Small', 'pi_framework'),
                        'medium' => esc_html__('Medium', 'pi_framework'),
                        'big' => esc_html__('Big', 'pi_framework'),
                    ),
                    'default' => 'medium'
                ),
                'position' => array(
                    'type' => 'select',
                    'title' => esc_html__('Position', 'pi_framework'),
                    'description' => esc_html__('Select button position', 'pi_framework'),
                    'options' => array(
                        'float-left' => 'Left',
                        'btn-centered' => 'Centered',
                        'float-right' => 'Right'
                    ),
                    'default' => 'float-right'
                ),
                'icon' => array(
                    'type' => 'icon_picker',
                    'title' => esc_html__('Icon', 'pi_framework'),
                    'description' => esc_html__('Add button icon.', 'pi_framework')
                ),
                'color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Color', 'pi_framework'),
                    'description' => esc_html__('Select button color from color wheel.', 'pi_framework'),
                    'default' => '',
                    'condition' => array('type', '=', 'default')
                ),
                'color_empty' => array(
                    'type' => 'select',
                    'title' => esc_html__('Color', 'pi_framework'),
                    'description' => esc_html__('Select predefined button color.', 'pi_framework'),
                    'options' => array(
                        'black' => 'Black',
                        'white' => 'White'
                    ),
                    'default' => 'black',
                    'condition' => array('type', '=', 'empty')
                ),
                'text' => array(
                    'type' => 'text',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Button text.', 'pi_framework'),
                    'placeholder' => 'Button'
                ),
                'link' => array(
                    'type' => 'text',
                    'title' => esc_html__('Link', 'pi_framework'),
                    'description' => esc_html__('Button link.', 'pi_framework'),
                    'placeholder' => 'www.google.com'
                ),
                'target' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Target', 'pi_framework'),
                    'description' => esc_html__('Open URL in new window.', 'pi_framework')
                ),
            );
        }

    }

}
?>
