<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Gallery")) {

    class CMA_Shortcodes_Gallery extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Lightbox Gallery', 'pi_framework');
            $settings['description'] = esc_html__('Simple gallery with lightbox preview.', 'pi_framework');
            $settings['shortcode'] = 'cma_gallery';
            $settings['nested'] = false;
            $settings['selected_option'] = 'grid'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-gallery', CMA_CONTENT_URL . 'gallery/js/gallery.js', array('jquery', 'magnific-popup'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $html_images = '';
            $classes = '';

            extract(shortcode_atts(array(
                'images' => '',
                'grid' => '3',
                'padding' => '1'
                            ), $atts, 'cma_gallery'));

            // split values into array
            $images = explode(',', $images);

            foreach ($images as $index => $image) {                
                
                //get first image
                $image_url = wp_get_attachment_image_src($image, 'full');

                if (empty($image_url))
                    continue;

                // crop the image
                $params = array('width' => 380);
                if ($vlc_is_retina) {
                    $params = array('width' => 760);
                }
                $cropped_image = bfi_thumb($image_url[0], $params);
                $cropped_image = esc_url($cropped_image);

                $html_images .= "<figure class='gallery-item'>
                                <div class='gallery-img zoom-hover'>
                                    <img src='{$cropped_image}' alt='gallery image'/>

                                    <div class='mask-style-1'>
                                        <div class='mask'></div>

                                        <div class='zoom'>
                                            <a href='{$image_url[0]}' class='triggerZoom'></a>
                                        </div>
                                    </div>
                                </div>
                            </figure>";
            }

            if($padding == '1'){
                $classes = 'gallery-padding';
            }
            
            $html = "<div class='lightbox-gallery gallery-{$grid} {$classes}'>{$html_images}</div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'images' => array(
                    'type' => 'image',
                    'title' => esc_html__('Images', 'pi_framework'),
                    'description' => esc_html__('Upload slider images.', 'pi_framework')
                ),
                'grid' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Grid size', 'pi_framework'),
                    'description' => esc_html__('Number of images per row.', 'pi_framework'),                    
                    'options' => array(
                        'three-col' => '3 images',
                        'four-col' => '4 images',
                        'six-col' => '6 images'
                    ),
                    'default' => 'three-col'
                ),
                'padding' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Padding', 'pi_framework'),
                    'description' => esc_html__('Add padding between images.', 'pi_framework'),
                    'default' => '1'
                )
            );
        }

    }

}
?>
