<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Google_Maps")) {

    class CMA_Shortcodes_Google_Maps extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Google Maps', 'pi_framework');
            $settings['description'] = esc_html__('Creates Google Map with location of your choice.', 'pi_framework');
            $settings['shortcode'] = 'cma_google_maps';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* Google Maps script */
            wp_enqueue_script('cma-scripts-googlemaps-api', 'http://maps.google.com/maps/api/js?sensor=true', array('jquery'), '1.0', TRUE);
            /* jQuery plugin for Google Maps */
            wp_enqueue_script('cma-scripts-googlemaps-plugin', CMA_CONTENT_URL . 'gmaps/js/jquery.ui.map.full.min.js', array('jquery', 'cma-scripts-googlemaps-api'), '1.0', TRUE);
            /* Script for Google Maps */
            wp_enqueue_script('cma-scripts-googlemaps', CMA_CONTENT_URL . 'gmaps/js/google-maps.js', array('jquery', 'cma-scripts-googlemaps-api', 'cma-scripts-googlemaps-plugin'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            $style = '';
            $custom_marker = '';
            $html = '';

            extract(shortcode_atts(array(
                'type' => 'roadmap',
                'latitude' => "40.74843",
                'longitude' => '-73.985655',
                'zoom' => '13',
                'ui' => '1',
                'scroll' => '1',
                'grayscale' => '0',
                'height' => '',
                'custom_market_position' => '0',
                'marker_latitude' => '40.74843',
                'marker_longitude' => '-73.985655',
                'call_to_action' => '0',
                'text' => 'Need help finding our office? Locate us on map'
                            ), (array) $atts, 'cma_google_maps'));

            if (!empty($height)) {
                $style = "style='height: {$height}px;'";
            }

            if ($custom_market_position == '1') {
                $custom_marker = " data-marker-lat='{$marker_latitude}' data-marker-long='{$marker_longitude}'";
            }
            
            $text = esc_html($text);

            if ($call_to_action == '1') {
                $html .= "<section class='call-to-action contact mb-80'>
                            <a href='#'>
                                <h2>{$text}</h2>
                                <i class='fa fa-angle-down triggerAnimation animated infinite pulse' data-animate='pulse'></i>
                            </a>
                        </section>";
            }

            $html .= "<div class='map-canvas' data-type='{$type}' data-long='{$longitude}' data-lat='{$latitude}' data-zoom='{$zoom}' data-default-ui='{$ui}' data-scroll-wheel='{$scroll}' data-grayscale='{$grayscale}' {$custom_marker} {$style}></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select Map type.', 'pi_framework'),
                    'options' => array(
                        'roadmap' => 'Road Map',
                        'terrain' => 'Terrain',
                        'satellite' => 'Satellite'
                    ),
                    'default' => 'roadmap'
                ),
                'latitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Latitude', 'pi_framework'),
                    'description' => esc_html__('Location Latitude for map.', 'pi_framework'),
                    'placeholder' => '46.305746'
                ),
                'longitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Longitude', 'pi_framework'),
                    'description' => esc_html__('Location Longitude for map.', 'pi_framework'),
                    'placeholder' => '16.336607'
                ),
                'zoom' => array(
                    'type' => 'number',
                    'title' => esc_html__('Zoom', 'pi_framework'),
                    'description' => esc_html__('Zoom parameter.', 'pi_framework'),
                    'default' => '13'
                ),
                'ui' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('User Interface', 'pi_framework'),
                    'description' => esc_html__('User Interface disable/enable.', 'pi_framework'),
                    'default' => '1'
                ),
                'scroll' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Zoom scrolling', 'pi_framework'),
                    'description' => esc_html__('Disable zoom when scrolling over map.', 'pi_framework'),
                    'default' => '0'
                ),
                'grayscale' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Grayscale', 'pi_framework'),
                    'description' => esc_html__('Make Map grayscale.', 'pi_framework'),
                    'default' => '0'
                ),
                'height' => array(
                    'type' => 'number',
                    'title' => esc_html__('Height', 'pi_framework'),
                    'description' => esc_html__('Enter custom map height (default 500px).', 'pi_framework'),
                    'placeholder' => '500'
                ),
                'custom_market_position' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Custom marker position', 'pi_framework'),
                    'description' => esc_html__('Change default market position (center of the map).', 'pi_framework'),
                    'default' => '0'
                ),
                'marker_latitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Marker Latitude', 'pi_framework'),
                    'description' => esc_html__('Custom marker latitude.', 'pi_framework'),
                    'placeholder' => '46.305746',
                    'condition' => array('custom_market_position', '==', '1')
                ),
                'marker_longitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Marker Longitude', 'pi_framework'),
                    'description' => esc_html__('Custom marker longitude.', 'pi_framework'),
                    'placeholder' => '16.336607',
                    'condition' => array('custom_market_position', '==', '1')
                ),
                'call_to_action' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Call to Action', 'pi_framework'),
                    'description' => esc_html__('Call to action above map.', 'pi_framework'),
                    'default' => '0'
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Text for Call to Action.', 'pi_framework'),
                    'default' => 'Need help finding our office? Locate us on map',
                    'condition' => array('call_to_action', '==', '1')
                ),
            );
        }

    }

}
?>
