(jQuery)(function ($) {

    /* ================ GOOGLE MAPS ================ */
    $('.map-canvas').each(function () {
        // init
        var map, marker, markerPosition;
        var mapTypeId = google.maps.MapTypeId.ROADMAP;

        // get options from html data attribute
        var mapType = $(this).data('type');
        var longitude = $(this).data('long');
        var latitude = $(this).data('lat');
        var zoom = parseInt($(this).data('zoom'));
        var defaultUi = $(this).data('default-ui') == '1';
        var scrollWheel = $(this).data('scroll-wheel') == '1';
        var grayscale = $(this).data('grayscale') == '1';
        var customMarkerLat = $(this).data('marker-lat');
        var customMarkerLong = $(this).data('marker-long');

        // map type
        if (mapType == 'roadmap') {
            mapTypeId = google.maps.MapTypeId.ROADMAP;
        } else if (mapType == 'terrain') {
            mapTypeId = google.maps.MapTypeId.TERRAIN;
        } else if (mapType == 'satellite') {
            mapTypeId = google.maps.MapTypeId.SATELLITE;
        }

        // latitude and longitude
        var mapCenter = new google.maps.LatLng(latitude, longitude);

        if (customMarkerLat && customMarkerLong) {
            markerPosition = new google.maps.LatLng(customMarkerLat, customMarkerLong);
        } else {
            markerPosition = mapCenter;
        }

        // map options
        var mapOptions = {
            // SET THE CENTER
            center: mapCenter,
            // SET THE MAP STYLE & ZOOM LEVEL
            mapTypeId: mapTypeId,
            zoom: zoom,
            // SET THE BACKGROUND COLOUR
            backgroundColor: "#eeeeee",
            panControl: true,
            zoomControl: true,
            mapTypeControl: false,
            scaleControl: true,
            streetViewControl: true,
            overviewMapControl: true,
            scrollwheel: scrollWheel,
            disableDefaultUI: defaultUi,
            zoomControlOptions: {
                style: google.maps.ZoomControlStyle.SMALL
            }

        };

        map = new google.maps.Map(this, mapOptions);

        marker = new google.maps.Marker({
            position: markerPosition,
            map: map
        });// END GOOGLE MAP STYLING

        if (grayscale) {
            //MAP BLACK AND WHITE STYLE
            var style = [
                {"featureType": "road",
                    "elementType":
                            "labels.icon",
                    "stylers": [
                        {"saturation": 1},
                        {"gamma": 1},
                        {"visibility": "on"},
                        {"hue": "#e6ff00"}
                    ]
                },
                {"elementType": "geometry", "stylers": [
                        {"saturation": -100}
                    ]
                }
            ];

            // SET THE MAP TYPE
            var mapType = new google.maps.StyledMapType(style, {name: "Grayscale"});
            map.mapTypes.set('grey', mapType);
            map.setMapTypeId('grey');
        }
    });

    $('.call-to-action.contact').on("click", 'a', function (e) {
        e.preventDefault();
        $(this).parent().next('.map-canvas').slideToggle("slow");
    });
});

