<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Heading")) {

    class CMA_Shortcodes_Heading extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Heading', 'pi_framework');
            $settings['description'] = esc_html__('Two types of section titles.', 'pi_framework');
            $settings['shortcode'] = 'cma_heading';
            $settings['nested'] = false;
            $settings['selected_option'] = 'title'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;

            extract(shortcode_atts(array(
                'type' => 'with_subtitle',
                'subtitle' => '',
                'title' => 'Heading text',
                'text_size' => 'h3'
                            ), $atts, 'cma_heading'));

            $title = wp_kses( $title, $volcanno_theme_config['allowed_html_tags'] );            
            $subtitle = wp_kses( $subtitle, $volcanno_theme_config['allowed_html_tags'] );

            if ($type == 'with_subtitle' || $type == 'with_subtitle_left') {
                $position = ($type == 'with_subtitle') ? 'center' : 'left';

                $html = "<section class='fancy-heading {$position}'>
                    <span class='heading-top'>{$subtitle}</span>
					<{$text_size}>{$title}</{$text_size}>
                   
                </section>";
            } else if ($type == 'simple' || $type == 'simple_left') {
                $position = ($type == 'simple') ? 'center' : 'left';

                $html = "<section class='simple-heading {$position}'><{$text_size}>{$title}</{$text_size}></section>";
            } else if ($type == 'intro' || $type == 'intro_left') {
                $position = ($type == 'intro') ? 'center' : 'left';

                $html = "<section class='intro-title {$position}'><{$text_size}>{$title}</{$text_size}></section>";
            } else if ($type == 'fancy' || $type == 'fancy_left') {
                $position = ($type == 'fancy') ? 'center' : 'left';

                $html = "<section class='fancy-heading style-2 {$position}'><{$text_size}>{$title}</{$text_size}></section>";
            } else if ($type == 'color_bkg') {

                $html = "<div class='section-title-container'><div class='section-title'>
                            <h3>{$subtitle}</h3>
                            <h1>{$title}</h1>
                            </div>
                        </div>";
            } else {
                $position = ($type == 'with_subtitle_left') ? 'center' : 'left';

                $html = "<section class='fancy-heading style-2 {$position}'><{$text_size}>{$title}</{$text_size}></section>";
            }

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select heading type.', 'pi_framework'),
                    'options' => array(
                        'with_subtitle' => esc_html__('Title with subtitle', 'pi_framework'),
                        'with_subtitle_left' => esc_html__('Title with subtitle - left', 'pi_framework'),
                        'simple' => esc_html__('Simple', 'pi_framework'),
                        'simple_left' => esc_html__('Simple - left', 'pi_framework'),
                        'fancy' => esc_html__('Fancy', 'pi_framework'),
                        'fancy_left' => esc_html__('Fancy - left', 'pi_framework'),
                        'intro' => esc_html__('Intro heading', 'pi_framework'),
                        'intro_left' => esc_html__('Intro - left', 'pi_framework'),
                        'color_bkg' => esc_html__('Title with colored background', 'pi_framework')
                    ),
                    'default' => 'with_subtitle'
                ),
                'subtitle' => array(
                    'type' => 'text',
                    'title' => esc_html__('Above title', 'pi_framework'),
                    'description' => esc_html__('Enter text above title.', 'pi_framework'),
                    'placeholder' => 'Small text',
                    'condition' => array('type', '==', 'with_subtitle|with_subtitle_left|color_bkg')
                ),
                'title' => array(
                    'type' => 'text',
                    'title' => esc_html__('Title', 'pi_framework'),
                    'description' => esc_html__('Enter heading title.', 'pi_framework'),
                    'placeholder' => 'Title'
                ),
                'text_size' => array(
                    'type' => 'select',
                    'title' => esc_html__('Large text size', 'pi_framework'),
                    'description' => esc_html__('Select text size.', 'pi_framework'),
                    'options' => array(
                        'h1' => 'H1',
                        'h2' => 'H2',
                        'h3' => 'H3',
                        'h4' => 'H4',
                        'h5' => 'H5',
                        'h6' => 'H6'
                    ),
                    'default' => 'h3'
                )
            );
        }

    }

}
?>
