<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

class CMA_Shortcodes_History extends Content_Maker_Shortcodes {

    function shortcode_block_info() {
        $settings['title'] = esc_html__('History', 'pi_framework');
        $settings['description'] = esc_html__('Large history tabs with timeline..', 'pi_framework');
        $settings['shortcode'] = 'cma_history';
        $settings['nested'] = false;
        $settings['selected_option'] = 'events|year'; // enter field ID - show this field's value on element on grid - easier to find desired element

        $this->shortcode_settings = $settings;
    }

    function shortcode_html($atts = array(), $content = null) {
        global $volcanno_theme_config;
        
        $html = '';
        $i = 1;
        $randomID = rand(1, 999);

        extract(shortcode_atts(array(
            'events' => ''
                        ), $atts, 'cma_history'));

        $html .= "<ul class='history-list clearfix'>";

        // reset counter
        $i = 1;
        // crop the image
        $params = array('width' => 170, 'height' => 170);

        // content
        foreach ($events as $event) {
            $image_html = '';

            // image
            if (!empty($event['image'])) {

                $image = explode(',', $event['image']);
                $text_position = !empty($event['text_position']) ? $event['text_position'] : 'right';

                //get first image
                $image_url = wp_get_attachment_image_src($image[0], 'full');
                $cropped_image = bfi_thumb($image_url[0], $params);
                $image_html = "<img src='{$cropped_image}' alt='history-imag'/>";
            }

            $year = !empty($events['year']) ? $events['year'] : date("Y");
            $title = !empty($event['title']) ? $event['title'] : 'Event in company\'s history.';
            $title = wp_kses($title, $volcanno_theme_config['allowed_html_tags']);
            
            $description = !empty($event['description']) ? $event['description'] : 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin tellus justo, blandit ac orci et, consequat imperdiet velit. ';

            if ($text_position == 'right') {
                $html .= "<li class='history-list-item right'>
                            <div class='history-text'>
                                <h3>{$title}</h3>

                                <p>{$description}</p>
                            </div>
                            
                            <div class='year-img-container'>
                                <div class='year'>
                                    <p>{$year}</p>
                                </div>

                                {$image_html}
                            </div>

                            
                        </li>";
            } else {
                $html .= "<li class='history-list-item'>
                            <div class='year-img-container'>
                                <div class='year'>
                                    <p>{$year}</p>
                                </div>

                                {$image_html}
                            </div>
                            <div class='history-text'>
                                <h3>{$title}</h3>

                                <p>{$description}</p>
                            </div>
                            
                        </li>";
            }
        }

        $html .= "</ul>";

        return $html;
    }

    function shortcode_options_fields() {

        $this->shortcode_options = array(
            'events' => array(
                'type' => 'group',
                'title' => esc_html__('Events', 'pi_framework'),
                'max' => '',
                'options' => array(
                    'year' => array(
                        'type' => 'number',
                        'title' => esc_html__('Year', 'pi_framework'),
                        'description' => esc_html__('Enter year of this event.', 'pi_framework'),
                        'default' => '2014'
                    ),
                    'title' => array(
                        'type' => 'text',
                        'title' => esc_html__('Title', 'pi_framework'),
                        'description' => esc_html__('Enter event name of some short title.', 'pi_framework')
                    ),
                    'description' => array(
                        'type' => 'textarea',
                        'title' => esc_html__('Description', 'pi_framework'),
                        'description' => esc_html__('Enter event description.', 'pi_framework'),
                        'default' => ''
                    ),
                    'image' => array(
                        'type' => 'image',
                        'title' => esc_html__('Image', 'pi_framework'),
                        'description' => esc_html__('Upload image that will appear in current tab (optional).', 'pi_framework')
                    ),
                    'text_position' => array(
                        'type' => 'radio',
                        'title' => esc_html__('Text Position', 'pi_framework'),
                        'description' => esc_html__('Select where will text float.', 'pi_framework'),
                        'options' => array(
                            'left' => esc_html__('Left', 'pi_framework'),
                            'right' => esc_html__('Right', 'pi_framework')
                        ),
                        'default' => 'right'
                    ),
                )
            )
        );
    }

}

?>
