<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("CMA_Shortcodes_Image_Carousel")) {

    class CMA_Shortcodes_Image_Carousel extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Image Carousel', 'pi_framework');
            $settings['description'] = esc_html__('Simple image carousel.', 'pi_framework');
            $settings['shortcode'] = 'cma_image_carousel';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-image-carousel', CMA_CONTENT_URL . 'image_carousel/js/image_carousel.js', array('jquery', 'owl-carousel'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $html_images = '';
            $nav_html = '';

            extract(shortcode_atts(array(
                'type' => 'basic',
                'images' => '',
                'navigation' => '1',
                'navigation_type' => 'bullets',
                'auto_scroll' => '0',
                'timeout' => '3000',
                'image_link' => '',
                'target' => '0'
                            ), $atts, 'cma_image_carousel'));

            // carosel images
            if ($type == 'basic') {
                $images = explode(',', $images);
            } else if ($type == 'link' && !empty($image_link)) {
                $images = wp_list_pluck($image_link, 'image');
            }

            if ($navigation_type == 'bullets') {
                $nav_class = 'dots-carousel';
            } else if ($navigation_type == 'right') {
                $nav_class = 'owl-carousel-navigation';
            } else if ($navigation_type == 'bottom') {
                $nav_class = 'owl-buttons';
            }

            foreach ($images as $index => $image) {
                $image = trim($image, ',');

                //get first image
                $image_url = wp_get_attachment_image_src($image, 'full');

                if (empty($image_url))
                    continue;

                // crop the image
                $params = array('width' => 230);
                if ($vlc_is_retina) {
                    $params = array('width' => 460);
                }
                $cropped_image = bfi_thumb($image_url[0], $params);

                if ($type == 'basic') {
                    $html_images .= "<div class='owl-item'><img src='{$cropped_image}' alt='image'/></div>";
                } else if ($type == 'link') {
                    $link = $image_link[$index]['url'];

                    $link = esc_url($link);

                    if ($target == '1') {
                        $target_attribute = 'target="_BLANK"';
                    } else {
                        $target_attribute = '';
                    }

                    $html_images .= "<div class='owl-item'><a href='{$link}' {$target_attribute}><img src='{$cropped_image}' alt='image'/></a></div>";
                }
            }

            $html = "<div class='carousel-container'><div class='image-carousel owl-carousel {$nav_class}' data-play='{$auto_scroll}' data-timeout='{$timeout}' data-navigation='{$navigation}' data-nav-type='{$navigation_type}'>{$html_images}</div></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Carousel type', 'pi_framework'),
                    'description' => esc_html__('Choose between two types of carousel.', 'pi_framework'),
                    'options' => array(
                        'basic' => 'Basic',
                        'link' => 'Image as link'
                    ),
                    'default' => 'basic'
                ),
                'images' => array(
                    'type' => 'image',
                    'title' => esc_html__('Images', 'pi_framework'),
                    'description' => esc_html__('Upload carousel images.', 'pi_framework'),
                    'condition' => array('type', '==', 'basic')
                ),
                'navigation' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Show navigation', 'pi_framework'),
                    'description' => esc_html__('Check this to show navigation.', 'pi_framework'),
                    'default' => '1'
                ),
                'navigation_type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Navigation type', 'pi_framework'),
                    'description' => esc_html__('Choose between there types of navigation.', 'pi_framework'),
                    'options' => array(
                        'bullets' => 'Bullets',
                        'right' => 'Right',
                        'bottom' => 'Bottom'
                    ),
                    'default' => 'bullets',
                    'condition' => array('navigation', '==', '1')
                ),
                'auto_scroll' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Auto Scroll', 'pi_framework'),
                    'description' => esc_html__('Set carousel to auto scroll.', 'pi_framework'),
                    'default' => '0'
                ),
                'timeout' => array(
                    'type' => 'number',
                    'title' => esc_html__('Scroll Timeout', 'pi_framework'),
                    'description' => esc_html__('Enter scrolling timeout.', 'pi_framework'),
                    'default' => '3000',
                    'options' => array(
                        'step' => 10
                    )
                ),
                'target' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('New window', 'pi_framework'),
                    'description' => esc_html__('Open url in new window.', 'pi_framework'),
                    'default' => '0',
                    'condition' => array('type', '==', 'link')
                ),
                'image_link' => array(
                    'type' => 'group',
                    'title' => 'Images',
                    'max' => '',
                    'options' => array(
                        'image' => array(
                            'type' => 'image',
                            'title' => esc_html__('Image', 'pi_framework'),
                            'description' => esc_html__('Upload carousel image.', 'pi_framework'),
                            'condition' => array('type', '==', 'link')
                        ),
                        'url' => array(
                            'type' => 'text',
                            'title' => esc_html__('URL', 'pi_framework'),
                            'description' => esc_html__('Enter image URL.', 'pi_framework'),
                            'condition' => array('type', '==', 'link')
                        ),
                    )
                )
            );
        }

    }

}
?>
