<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("CMA_Shortcodes_Image_Tooltip")) {

    class CMA_Shortcodes_Image_Tooltip extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Image Tooltip', 'pi_framework');
            $settings['description'] = esc_html__('Simple image with tooltip on hover.', 'pi_framework');
            $settings['shortcode'] = 'cma_image_tooltip';
            $settings['nested'] = false;
            $settings['selected_option'] = 'items|text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $html_images = '';
            $nav_html = '';
            $clients_bkg = '';

            extract(shortcode_atts(array(
                'background' => '0',
                'items' => ''
                            ), $atts, 'cma_image_tooltip'));

            if($background == '1'){
                $clients_bkg = 'clients-bkg';
            }
            
            $html = "<ul class='clients-list {$clients_bkg}'>";

            foreach ($items as $index => $item) {
                $image = explode(',', $item['image']);

                $url = esc_url($item['url']);

                $tooltip = esc_attr($item['text']);

                //get first image
                $image_url = wp_get_attachment_image_src($image[0], 'full');

                // crop the image
                $params = array('width' => 350, 'height' => 179);
                if ($vlc_is_retina) {
                    $params = array('width' => 700, 'height' => 358);
                }
                $cropped_image = bfi_thumb($image_url[0], $params);

                $html .= "<li class='client-item'>
                                <a href='{$url}' class='hint--top' data-hint='{$tooltip}'>
                                    <img src='{$image_url[0]}' alt='client'/>
                                </a>
                            </li>";
            }

            $html .= "</ul>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'background' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Background', 'pi_framework'),
                    'description' => esc_html__('Check to add white transparent background behind image.', 'pi_framework')
                ),
                'items' => array(
                    'type' => 'group',
                    'title' => 'Items',
                    'max' => '',
                    'options' => array(
                        'image' => array(
                            'type' => 'image',
                            'title' => esc_html__('Image', 'pi_framework'),
                            'description' => esc_html__('Upload carousel image.', 'pi_framework')
                        ),
                        'url' => array(
                            'type' => 'text',
                            'title' => esc_html__('URL', 'pi_framework'),
                            'description' => esc_html__('Enter image URL.', 'pi_framework')
                        ),
                        'text' => array(
                            'type' => 'text',
                            'title' => esc_html__('Tooltip Text', 'pi_framework'),
                            'description' => esc_html__('Enter tooltip text.', 'pi_framework')
                        ),
                    )
                ),
            );
        }

    }

}
?>
