<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Large_Icons_List")) {

    class CMA_Shortcodes_Large_Icons_List extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Large Icons Lists', 'pi_framework');
            $settings['description'] = esc_html__('Basic HTML list element with large icons.', 'pi_framework');
            $settings['shortcode'] = 'cma_large_icons_list';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;
            
            $animation_class = '';
            $color_style = '';
            $item_icon = 'fa fa-paint-brush';
            $html = '';

            extract(shortcode_atts(array(
                'type' => 'theme',
                'style' => 'simple',
                'animation' => '0',
                'items' => ''
                            ), $atts, 'cma_large_icons_list'));

            if ($animation == '1') {
                $animation_class = 'animated triggerAnimation';
            }

            foreach ($items as $index => $item) {
                if (!empty($item['item_icon_linecons'])) {
                    $item_icon = $item['item_icon_linecons'];
                } else if (!empty($item['item_icon'])) {
                    $item_icon = $item['item_icon'];
                }

                if ($type == 'custom_color') {
                    if (!empty($item['color']))
                        $color_style = "style='background-color: {$item['color']};'";
                }
                
                $text = wp_kses($item['text'], $volcanno_theme_config['allowed_html_tags']);
                
                if ($style == 'simple') {
                    $html .= "<li>
                                <div class='icon {$animation_class}' data-animate='zoomIn' {$color_style}>
                                    <i class='{$item_icon}'></i>
                                </div>
                                <p>{$text}</p>
                              
                            </li>";
                } else if ($style == 'with_text') {
                    $small_text = wp_kses($item['small_text'], $volcanno_theme_config['allowed_html_tags']);
                    
                    $html .= "<li>
                                <div class='icon-container {$animation_class}' data-animate='zoomIn' {$color_style}>
                                    <i class='fa fa-li {$item_icon}'></i>
                                </div>
                                <div class='li-content'>
                                    <h5>{$text}</h5>
                                    <p>{$small_text}</p>
                                </div>                                
                            </li>";
                }
            }

            if ($style == 'simple') {
                $html = "<ul class='list-icons-merged {$type}'>{$html}</ul>";
            } else if ($style == 'with_text') {
                $html = "<ul class='fa-ul large-icons {$type}'>{$html}</ul>";
            }

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select list type.', 'pi_framework'),
                    'options' => array(
                        'theme-color-icons' => esc_html__('Theme color', 'pi_framework'),
                        'minimal' => esc_html__('Gradient', 'pi_framework'),
                        'black' => esc_html__('Black', 'pi_framework'),
                        'custom_color' => esc_html__('Custom color', 'pi_framework')
                    ),
                    'default' => 'theme-color-icons'
                ),
                'animation' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Animation', 'pi_framework'),
                    'description' => esc_html__('Enable list items animation.', 'pi_framework')
                ),
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select list style.', 'pi_framework'),
                    'options' => array(
                        'simple' => esc_html__('Simple', 'pi_framework'),
                        'with_text' => esc_html__('With paragraph text', 'pi_framework'),
                    ),
                    'default' => 'simple'
                ),
                'items' => array(
                    'type' => 'group',
                    'title' => esc_html__('Items', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'text' => array(
                            'type' => 'text',
                            'title' => esc_html__('Text', 'pi_framework'),
                            'description' => esc_html__('List item text.', 'pi_framework')
                        ),
                        'small_text' => array(
                            'type' => 'text',
                            'title' => esc_html__('Small text', 'pi_framework'),
                            'description' => esc_html__('Small text under main item text.', 'pi_framework'),
                            'condition' => array('style', '==', 'with_text')
                        ),
                        'item_icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon - Font Awesome', 'pi_framework'),
                            'description' => esc_html__('Add Font Awesome icon to list item. Set icon only for first item if you want same color for all.', 'pi_framework')
                        ),
                        'item_icon_linecons' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon - Linecons', 'pi_framework'),
                            'description' => esc_html__('Add Linecons icon to list item. Set icon only for first item if you want same color for all.', 'pi_framework'),
                            'options' => volcanno_linecons_classes()
                        ),
                        'color' => array(
                            'type' => 'color_picker',
                            'title' => esc_html__('Color', 'pi_framework'),
                            'description' => esc_html__('Set icon background color. Set color only for first item if you want same color for all.', 'pi_framework'),
                            'default' => '#117dc2',
                            'condition' => array('type', '==', 'custom_color')
                        ),
                    )
                )
            );
        }

    }

}
?>
