<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Lists")) {

    class CMA_Shortcodes_Lists extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Classic List', 'pi_framework');
            $settings['description'] = esc_html__('Basic HTML list element.', 'pi_framework');
            $settings['shortcode'] = 'cma_lists';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;
            
            $html_items = '';
            $classes = '';

            extract(shortcode_atts(array(
                'type' => 'numbered',
                'border' => '0',
                'animated' => '0',
                'text_link' => '0',
                'items' => ''
                            ), $atts, 'cma_lists'));

            if ($border == '1') {
                $classes .= 'list-border';
            }

            if ($animated == '1') {
                $classes .= ' list-animated';
            }

            foreach ($items as $index => $item) {
                if ($text_link == '1') {
                    $link = esc_url($item['link']);
                    $text = wp_kses(
                            $item['text'], array(
                        'br' => array(),
                        'em' => array(),
                        'strong' => array(),
                        'span' => array('class' => array())
                            )
                    );

                    $html_items .= "<li><a href='{$link}'>{$text}</a></li>";
                } else {
                    $text = wp_kses($item['text'], $volcanno_theme_config['allowed_html_tags']);

                    $html_items .= "<li>{$text}</li>";
                }
            }

            if ($type == 'numbered') {
                $html = "<ol class='{$classes}'>{$html_items}</ol>";
            } else if ($type == 'bullets') {
                $html = "<ul class='{$classes}'>{$html_items}</ul>";
            } else if ($type == 'blank') {
                $html = "<ul class='listy-style-none {$classes}'>{$html_items}</ul>";
            }

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select list type.', 'pi_framework'),
                    'options' => array(
                        'numbered' => esc_html__('Numbered', 'pi_framework'),
                        'bullets' => esc_html__('Bullets', 'pi_framework'),
                        'blank' => esc_html__('Blank', 'pi_framework')
                    ),
                    'default' => 'numbered'
                ),
                'border' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Border bottom', 'pi_framework'),
                    'description' => esc_html__('Show bottom border.', 'pi_framework')
                ),
                'animated' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Animated', 'pi_framework'),
                    'description' => esc_html__('Enable to show animation on item hover.', 'pi_framework')
                ),
                'text_link' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Text link', 'pi_framework'),
                    'description' => esc_html__('Use text as link', 'pi_framework')
                ),
                'items' => array(
                    'type' => 'group',
                    'title' => esc_html__('Items', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'text' => array(
                            'type' => 'text',
                            'title' => esc_html__('Text', 'pi_framework'),
                            'description' => esc_html__('List item text.', 'pi_framework')
                        ),
                        'link' => array(
                            'type' => 'text',
                            'title' => esc_html__('URL', 'pi_framework'),
                            'description' => esc_html__('Enter URL.', 'pi_framework'),
                            'condition' => array('text_link', '==', '1')
                        ),
                    )
                )
            );
        }

    }

}
?>
