<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Note")) {

    class CMA_Shortcodes_Note extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Note', 'pi_framework');
            $settings['description'] = esc_html__('Section where you can introduce yourself.', 'pi_framework');
            $settings['shortcode'] = 'cma_note';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;
            
            $target_html = '';
            $bkg_style = '';

            extract(shortcode_atts(array(
                'background' => '',
                'text_size' => 'h2',
                'text' => 'Note text goes here.',
                'small_text' => '',
                'text_color' => '',
                'button' => '',
                'button_text' => 'Button',
                'button_url' => '',
                'target' => '',
                'btn_type' => 'empty',
                'btn_icon' => '',
                'btn_custom_color' => ''
                            ), $atts, 'cma_note'));

            $button_url = esc_url($button_url);

            if ($target == '1') {
                $target_html = 'target="_BLANK"';
            }

            if (!empty($btn_icon)) {
                $btn_icon = "<i class='{$btn_icon}'></i>";
            }

            if (!empty($btn_custom_color)) {
                $btn_custom_color = "style='background-color: {$btn_custom_color}'";
            }

            if (!empty($text_color)) {
                $text_color = "style='color: {$text_color}'";
            }

            $text = wp_kses($text, $volcanno_theme_config['allowed_html_tags']);

            $small_text = esc_html($small_text);
            $small_text = (!empty($small_text)) ? "<p {$text_color}>{$small_text}</p>" : "";
            
            $button_text = esc_html($button_text);

            $button_html = ($button == '1') ? "<br/><a class='btn btn-default btn-{$btn_type}' href='{$button_url}' {$btn_custom_color} {$target_html}>{$btn_icon} {$button_text}</a>" : '';
            $html = "<div class='note' {$bkg_style}>"
                    . "<{$text_size} {$text_color}>{$text}</{$text_size}>"
                    . $small_text
                    . "{$button_html}"
                    . "</div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Large Text', 'pi_framework'),
                    'description' => esc_html__('Note text - large bold text.', 'pi_framework')
                ),
                'text_size' => array(
                    'type' => 'select',
                    'title' => esc_html__('Large text size', 'pi_framework'),
                    'description' => esc_html__('Select text size.', 'pi_framework'),
                    'options' => array(
                        'h1' => 'H1',
                        'h2' => 'H2',
                        'h3' => 'H3'
                    ),
                    'default' => 'h2'
                ),
                'small_text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Small Text', 'pi_framework'),
                    'description' => esc_html__('Small text below.', 'pi_framework')
                ),
                'text_color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Text Color', 'pi_framework'),
                    'description' => esc_html__('Select custom text color.', 'pi_framework')
                ),
                'button' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Show button', 'pi_framework'),
                    'description' => esc_html__('Check to show button.', 'pi_framework'),
                    'default' => '1'
                ),
                'btn_type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Button Type', 'pi_framework'),
                    'description' => esc_html__('Select button type.', 'pi_framework'),
                    'options' => array(
                        'empty' => esc_html__('Empty', 'pi_framework'),
                        'filled' => esc_html__('Filled', 'pi_framework')
                    ),
                    'default' => 'empty',
                    'condition' => array('button', '==', '1')
                ),
                'btn_icon' => array(
                    'type' => 'icon_picker',
                    'title' => esc_html__('Button Icon', 'pi_framework'),
                    'description' => esc_html__('Add button icon.', 'pi_framework'),
                    'condition' => array('button', '==', '1')
                ),
                'btn_custom_color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Button Custom Color', 'pi_framework'),
                    'description' => esc_html__('Select button custom color.', 'pi_framework'),
                    'condition' => array('button', '==', '1')
                ),
                'button_text' => array(
                    'type' => 'text',
                    'title' => esc_html__('Button Text', 'pi_framework'),
                    'description' => esc_html__('Enter button text.', 'pi_framework'),
                    'placeholder' => 'Button',
                    'condition' => array('button', '==', '1')
                ),
                'button_url' => array(
                    'type' => 'text',
                    'title' => esc_html__('Button URL', 'pi_framework'),
                    'description' => esc_html__('Enter button URL.', 'pi_framework'),
                    'placeholder' => 'http://',
                    'condition' => array('button', '==', '1')
                ),
                'target' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Button target', 'pi_framework'),
                    'description' => esc_html__('Open link in new window/tab', 'pi_framework'),
                    'default' => '0',
                    'condition' => array('button', '==', '1')
                ),
            );
        }

    }

}
?>
