<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Notifications")) {

    class CMA_Shortcodes_Notifications extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Notification', 'pi_framework');
            $settings['description'] = esc_html__('Simple UI component.', 'pi_framework');
            $settings['shortcode'] = 'cma_notifications';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-notifications', CMA_CONTENT_URL . 'notifications/js/notifications.js', array('jquery'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;

            $close_button = '';
            $icon = 'fa-lightbulb-o';

            extract(shortcode_atts(array(
                'type' => 'infobox',
                'style' => 'default',
                'text' => '',
                'close' => '0'
                            ), $atts, 'cma_notifications'));

            if ($close == '1') {
                $close_button = '<span class="close"></span>';
            }
            
            $text = wp_kses($text, $volcanno_theme_config['allowed_html_tags']);

            if ($style == 'default') {

                if ($type == 'error-box') {
                    $type = 'errorbox';
                    $icon = 'fa-close';
                } else if ($type == 'success-box') {
                    $type = 'successbox';
                    $icon = 'fa-check';
                } else if ($type == 'warning-box') {
                    $type = 'warningbox';
                    $icon = 'fa-warning';
                }

                $html = "<div class='information-boxes {$type}-default'>
                        {$close_button}

                        <div class='icon-container'>
                            <i class='fa {$icon}'></i>
                        </div>

                        <div class='notification-container'>
                            <p>{$text}</p>
                        </div>
                    </div>";
            } else {
                $html = "<div class='information-boxes {$type}'>
                            {$close_button}
                            <p>{$text}</p>
                        </div>";
            }


            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'select',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select notification type.', 'pi_framework'),
                    'options' => array(
                        'infobox' => esc_html__('Information', 'pi_framework'),
                        'error-box' => esc_html__('Error', 'pi_framework'),
                        'success-box' => esc_html__('Success', 'pi_framework'),
                        'warning-box' => esc_html__('Warning', 'pi_framework')
                    ),
                    'default' => 'infobox'
                ),
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select notification style.', 'pi_framework'),
                    'options' => array(
                        'default' => esc_html__('Default', 'pi_framework'),
                        'simple' => esc_html__('Simple', 'pi_framework')
                    ),
                    'default' => 'default'
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Notification text.', 'pi_framework')
                ),
                'close' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Allow closing', 'pi_framework'),
                    'description' => esc_html__('Allow closing notification.', 'pi_framework'),
                    'default' => '0'
                )
            );
        }

    }

}
?>
