<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Progress_Bar_Linear")) {

    class CMA_Shortcodes_Progress_Bar_Linear extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Linear Progress Bars', 'pi_framework');
            $settings['description'] = esc_html__('Linear Progress bar can be used for showcasing skills.', 'pi_framework');
            $settings['shortcode'] = 'cma_progress_bar_linear';
            $settings['nested'] = false;
            $settings['selected_option'] = 'bars|title'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-progress-bar-linear-script', CMA_CONTENT_URL . 'progress_bar_linear/js/easypiechart.js', array('jquery'), '1.0', TRUE);
            /* init */
            wp_enqueue_script('cma-scripts-progress-bar-linear-init', CMA_CONTENT_URL . 'progress_bar_linear/js/progress_bar_linear.js', array('jquery', 'cma-scripts-progress-bar-linear-script'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            $color_style = '';

            extract(shortcode_atts(array(
                'track_color' => '#f6f6f6',
                'bars' => ''
                            ), $atts, 'cma_progress_bar_linear'));

            $html = "<div class='skills-bar'><ul class='skills'>";

            foreach ($bars as $index => $bar) {
                $icon_html = !empty($bar['icon']) ? "<i class='{$bar['icon']}'></i>" : '';

                if (!empty($bar['single_bar_color'])) {
                    $color = $bar['single_bar_color'];
                    $color_style = "style='background-color: {$color};'";
                }

                $title = esc_html($bar['title']);
                $percentage = intval($bar['percentage']);

                $html .= "<li>
                            <span class='percentage-{$percentage}' {$color_style}></span>
                            <p>{$icon_html}{$title} {$percentage}%</p>
                        </li>";
            }
            $html .= "</ul></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'track_color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Track Color', 'pi_framework'),
                    'description' => esc_html__('Set color for filled part of chart.', 'pi_framework')
                ),
                'bars' => array(
                    'type' => 'group',
                    'title' => esc_html__('Bars', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'title' => array(
                            'type' => 'text',
                            'title' => esc_html__('Title', 'pi_framework'),
                            'description' => esc_html__('Skill title.', 'pi_framework')
                        ),
                        'percentage' => array(
                            'type' => 'number',
                            'title' => esc_html__('Percentage', 'pi_framework'),
                            'description' => esc_html__('Set skill percentage (1-100%).', 'pi_framework'),
                            'options' => array(
                                'min' => 0,
                                'max' => 100,
                                'step' => 10
                            ),
                            'default' => '50'
                        ),
                        'icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon', 'pi_framework'),
                            'description' => esc_html__('Add button icon.', 'pi_framework')
                        ),
                        'single_bar_color' => array(
                            'type' => 'color_picker',
                            'title' => esc_html__('Bar Color', 'pi_framework'),
                            'description' => esc_html__('Set color for background color. Leave empty for default blue color.', 'pi_framework')
                        ),
                    )
                )
            );
        }

    }

}
?>
