<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Social_Photo_Stream")) {

    class CMA_Shortcodes_Social_Photo_Stream extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Social Photo Stream', 'pi_framework');
            $settings['description'] = esc_html__('Images from social network profiles.', 'pi_framework');
            $settings['shortcode'] = 'cma_social_photo_stream';
            $settings['nested'] = false;
            $settings['selected_option'] = 'network'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-cma-social-photo-stream-script', CMA_CONTENT_URL . 'social_photo_stream/js/socialstream.jquery.js', array('jquery'), '1.0', TRUE);
            /* init */
            wp_enqueue_script('cma-scripts-cma-social-photo-stream-init', CMA_CONTENT_URL . 'social_photo_stream/js/social_photo_stream.js', array('jquery', 'cma-scripts-cma-social-photo-stream-script'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            extract(shortcode_atts(array(
                'network' => 'dribbble',
                'username' => 'pixel_industry',
                'limit' => '10',
                'api_key' => ''
                            ), $atts, 'cma_social_photo_stream'));

            $network = sanitize_text_field($network);
            $username = sanitize_text_field($username);
            $limit = intval($limit);
            $api_key = strip_tags($api_key);

            $html = "<div class='widget social-feed' data-network='{$network}' data-username='{$username}' data-limit='{$limit}' data-api='{$api_key}'></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'network' => array(
                    'type' => 'select',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select social network.', 'pi_framework'),
                    'options' => array(
                        'deviantart' => 'DeviantArt',
                        'dribbble' => 'Dribbble',
                        'flickr' => 'Flickr',
                        'instagram' => 'Instagram',
                        'newsfeed' => 'Newsfeed (RSS)',
                        'picasa' => 'Picasa',
                        'pinterest' => 'Pinterest',
                        'youtube' => 'Youtube',
                    ),
                    'default' => 'deviantart'
                ),
                'username' => array(
                    'type' => 'text',
                    'title' => esc_html__('Username / Channel', 'pi_framework'),
                    'description' => esc_html__('Social network username.', 'pi_framework')
                ),
                'limit' => array(
                    'type' => 'number',
                    'title' => esc_html__('Limit', 'pi_framework'),
                    'description' => esc_html__('Number of images to fetch.', 'pi_framework'),
                    'default' => '10',
                    'options' => array(
                        'min' => 1
                    )
                ),
                'api_key' => array(
                    'type' => 'text',
                    'title' => esc_html__('API key', 'pi_framework'),
                    'description' => esc_html__('Enter API key if required (Youtube).', 'pi_framework'),
                    'condition' => array('network', '==', 'youtube')
                ),
            );
        }

    }

}
?>
