<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Stats")) {

    class CMA_Shortcodes_Stats extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Stats', 'pi_framework');
            $settings['description'] = esc_html__('Animated statistics.', 'pi_framework');
            $settings['shortcode'] = 'cma_stats';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* jQuery Countdown timer */
            wp_register_script('cma-scripts-countdown', CMA_CONTENT_URL . 'stats/js/jquery.countTo.js', array('jquery'), '1.0', TRUE);
            /* script */
            wp_enqueue_script('cma-scripts-stats', CMA_CONTENT_URL . 'stats/js/stats.js', array('jquery', 'cma-scripts-countdown', 'cma-waypoints'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            extract(shortcode_atts(array(
                'style' => 'simple',
                'text_color' => 'default-color',
                'text' => 'Stats text',
                'number' => '3000',
                'icon' => 'fa-envelope-o',
                            ), $atts, 'cma_stats'));

            // clean and split string
            $number = trim($number);
            $splited = preg_split("/[{}]+/", $number, -1, PREG_SPLIT_NO_EMPTY);
            $text = esc_html($text);
            
            // check how many items array holds
            if(is_array($splited) && count($splited) > 1){
                $first_part = $splited[0];
                $first_part_brackets = "{" . $splited[0] . "}";
                
                // check if first part is static or dynamic
                if(strpos($number, $first_part) == 0){
                    $static = $splited[1];
                    $dynamic = $splited[0];
                    
                    $timer = "<span class='timer number' data-to='{$dynamic}' data-speed='1500'>{$dynamic}</span>" . $static;
                }else if(strpos($number, $first_part_brackets) == 0){
                    $static = $splited[0];
                    $dynamic = $splited[1];
                    
                    $timer = $static . "<span class='timer number' data-to='{$dynamic}' data-speed='1500'>{$dynamic}</span>";
                }
            }else{
                $timer = "<span class='timer number' data-to='{$number}' data-speed='1500'>{$number}</span>";
            }
            
            if($style == 'small-icons'){
                $html = "<div class='numbers-counter {$style}'>                            
                            <div class='timer-container'>
                                {$timer}
                            </div>
                            <div class='counter-info clearfix'>
                                <i class='fa {$icon}'></i>
                                <h5>{$text}</h5>
                            </div>
                        </div>";
            }else{
                $html = "<div class='numbers-counter {$style} {$text_color}'>
                            <i class='fa {$icon}'></i>
                            <div class='timer-container'>
                                {$timer}
                            </div>
                            <h5>{$text}</h5>
                        </div>";
            }
            

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select element style.', 'pi_framework'),
                    'options' => array(
                        'simple' => esc_html__('Simple', 'pi_framework'),
                        'box' => esc_html__('Box', 'pi_framework'),
                        'small-icons' => esc_html__('Small icons', 'pi_framework')
                    ),
                    'default' => 'simple'
                ),
                'text_color' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Text Color', 'pi_framework'),
                    'description' => esc_html__('Select text color.', 'pi_framework'),
                    'options' => array(
                        'default-color' => esc_html__('Default', 'pi_framework'),
                        'theme-color' => esc_html__('Theme color', 'pi_framework')
                    ),
                    'default' => 'default-color',
                    'condition' => array('style', '!=', 'small-icons')
                ),
                'text' => array(
                    'type' => 'text',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Enter item title/text.', 'pi_framework'),
                    'placeholder' => 'Stats text'
                ),
                'number' => array(
                    'type' => 'text',
                    'title' => esc_html__('Number', 'pi_framework'),
                    'description' => esc_html__('Enter number/count. Use {} for static text e.g. 567{K} or {$}7000', 'pi_framework'),
                    'placeholder' => '3000'
                ),
                'icon' => array(
                    'type' => 'icon_picker',
                    'title' => esc_html__('Icon', 'pi_framework'),
                    'description' => esc_html__('Set element icon.', 'pi_framework')
                ),
            );
        }

    }

}
?>
