<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Styled_Image")) {

    class CMA_Shortcodes_Styled_Image extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Styled Image', 'pi_framework');
            $settings['description'] = esc_html__('Add styled image to your content.', 'pi_framework');
            $settings['shortcode'] = 'cma_styled_image';
            $settings['nested'] = 0;
            $settings['selected_option'] = 'shape'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina, $volcanno_theme_config;

            $attachment_data = '';
            $classes = '';
            $link_html = '';
            $link_target = '';

            extract(shortcode_atts(array(
                'id' => '',
                'shape' => 'round',
                'style' => 'normal',
                'text' => '',
                'link' => '',
                'target' => '',
                'shadow' => 'none',
                            ), $atts, 'cma_styled_image'));

            // image style
            if ($style == 'border') {
                $classes = 'img-bordered subtle-hover';
            } else if ($style == 'image_as_link') {
                $classes = 'caption-hover';
            } else if ($style == 'zoom') {
                $classes = 'zoom-hover';
            }

            // image shadow
            if ($shadow != 'none') {
                $classes .= " img-shadow{$shadow}";
            }

            if ($style == 'image_as_link' && !empty($text) && !empty($link)) {
                $link = esc_url($link);
                $text = esc_html($text);

                // open url in new window
                if ($target == '1') {
                    $link_target = 'target="_BLANK"';
                }

                $link_html = "<div class='caption'>
                                <a href='{$link}' class='img-caption' {$link_target}>{$text}</a>
                            </div>";
            }

            if (!empty($id)) {
                $ids = explode(',', $id);
                $ids = array_filter($ids);

                $image_src = wp_get_attachment_image_src($ids[0], 'full');

                // crop the image
                $params = array('width' => 720);
                if ($vlc_is_retina) {
                    $params = array('width' => 1440);
                }

                $cropped_image = bfi_thumb($image_src[0], $params);

                $attachment = cma_get_attachment($ids[0]);
                $title = empty($attachment['caption']) ? $attachment['title'] : $attachment['caption'];
                $title = wp_kses($title, $volcanno_theme_config['allowed_html_tags']);
                
                $alt = empty($attachment['alt']) ? $attachment['title'] : $attachment['alt'];
                $alt = esc_attr($alt);

                $attachment_data = "<div class='img-{$shape} {$classes}'><img src='{$cropped_image}' title='{$title}' alt='{$alt}' width='{$image_src[1]}' height='{$image_src[2]}'/>{$link_html}</div>";
            }

            return $attachment_data;
        }

        function shortcode_options_fields() {

            $image_sizes['full'] = 'Full Size';

            foreach (get_intermediate_image_sizes() as $value) {
                $image_sizes[$value] = ucfirst($value);
            }

            $this->shortcode_options = array(
                'id' => array(
                    'type' => 'image',
                    'title' => esc_html__('Images', 'pi_framework'),
                    'description' => esc_html__('Upload image. Only one image is permitted, other will be ignored.', 'pi_framework')
                ),
                'shape' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Shape', 'pi_framework'),
                    'description' => esc_html__('Select image shape.', 'pi_framework'),
                    'options' => array(
                        'circled' => 'Round',
                        'rounded' => 'Square with round border',
                        'square' => 'Square'
                    ),
                    'default' => 'circled'
                ),
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Shape', 'pi_framework'),
                    'description' => esc_html__('Select image shape.', 'pi_framework'),
                    'options' => array(
                        'normal' => 'Normal',
                        'border' => 'Bordered',
                        'image_as_link' => 'Image as link',
                        'zoom' => 'Zoom effect'
                    ),
                    'default' => 'normal'
                ),
                'text' => array(
                    'type' => 'text',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Enter image caption.', 'pi_framework'),
                    'condition' => array('style', '==', 'image_as_link')
                ),
                'link' => array(
                    'type' => 'text',
                    'title' => esc_html__('Link', 'pi_framework'),
                    'description' => esc_html__('Enter caption url.', 'pi_framework'),
                    'condition' => array('style', '==', 'image_as_link')
                ),
                'target' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Target', 'pi_framework'),
                    'description' => esc_html__('Open URL in new window.', 'pi_framework'),
                    'condition' => array('style', '==', 'image_as_link')
                ),
                'shadow' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Shadow', 'pi_framework'),
                    'description' => esc_html__('Select image shadow type.', 'pi_framework'),
                    'options' => array(
                        'none' => 'None',
                        '01' => 'Bottom Corners',
                        '02' => 'Bottom Right',
                        '03' => 'Top',
                        '04' => 'Glow'
                    ),
                    'default' => 'none',
                    'condition' => array('shape', '==', 'square')
                ),
            );
        }

    }

}
?>
