<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Tabs")) {

    class CMA_Shortcodes_Tabs extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Tabs', 'pi_framework');
            $settings['description'] = esc_html__('Simple UI component.', 'pi_framework');
            $settings['shortcode'] = 'cma_tabs';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-tabs', CMA_CONTENT_URL . 'tabs/js/tabs.js', array('jquery'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;

            $html_titles = '';
            $html_content = '';
            $html = '';
            $i = 1;
            $gradient = '';

            extract(shortcode_atts(array(
                'type' => 'horizontal',
                'gradient' => '0',
                'tabs' => '',
                'active' => '1'
                            ), $atts, 'cma_tabs'));

            $randomID = rand(1, 999);
            
            if($gradient == '1'){
                $gradient = 'tabs-gradient';
            }

            foreach ($tabs as $index => $tab) {

                $tab_content = do_shortcode($tab['content']);

                if ((int) $active == $i) {
                    $active_tab = 'active';
                } else {
                    $active_tab = '';
                }

                $tab_icon = !empty($tab['icon']) ? "<i class='" . $tab['icon'] . "'></i>" : '';
                $tab_title = wp_kses($tab['title'], $volcanno_theme_config['allowed_html_tags']);

                $html_titles .= "<li class='{$active_tab}'><a title='{$tab_title}' href='#tab-{$randomID}-{$i} '>{$tab_icon}{$tab_title}</a></li>";

                $tab_content = wpautop($tab_content);
                $html_content .= "<div class='tab-content {$active_tab}' id='tab-{$randomID}-{$i}'>{$tab_content}</div>";

                $i++;
            }

            if ($type == 'vertical') {
                $html .= "<div class='tabs-container'><ul class='tabs vertical {$gradient}' id='tabs-{$randomID}'>{$html_titles}</ul>";
                $html .= "<section class='tab-content-wrap vertical'>{$html_content}</section></div>";
            } else {
                $html .= "<div class='tabs-container'><ul class='tabs {$gradient}' id='tabs-{$randomID}'>{$html_titles}</ul>";
                $html .= "<section class='tab-content-wrap'>{$html_content}</section></div>";
            }

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select tab type.', 'pi_framework'),
                    'options' => array(
                        'horizontal' => esc_html__('Horizontal', 'pi_framework'),
                        'vertical' => esc_html__('Vertical', 'pi_framework')
                    ),
                    'default' => 'horizontal'
                ),
                'gradient' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Gradient', 'pi_framework'),
                    'description' => esc_html__('Enable gradient on tab background.', 'pi_framework'),
                    'default' => '0'
                ),
                'active' => array(
                    'type' => 'number',
                    'title' => esc_html__('Active tab', 'pi_framework'),
                    'description' => esc_html__('Enter index of tab that you want to be active e.g 2.', 'pi_framework'),
                    'default' => '1',
                    'options' => array(
                        'min' => 1
                    )
                ),
                'tabs' => array(
                    'type' => 'group',
                    'title' => 'Tabs',
                    'max' => '',
                    'options' => array(
                        'title' => array(
                            'type' => 'text',
                            'title' => esc_html__('Title', 'pi_framework'),
                            'description' => esc_html__('Tab title.', 'pi_framework')
                        ),
                        'content' => array(
                            'type' => 'textarea',
                            'title' => esc_html__('Content', 'pi_framework'),
                            'description' => esc_html__('Add tab content.', 'pi_framework')
                        ),
                        'icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon', 'pi_framework'),
                            'description' => esc_html__('Add tab icon.', 'pi_framework')
                        ),
                    )
                )
            );
        }

    }

}
?>
