<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Team_Member")) {

    class CMA_Shortcodes_Team_Member extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Team Member (single)', 'pi_framework');
            $settings['description'] = esc_html__('Your company team member (single member).', 'pi_framework');
            $settings['shortcode'] = 'cma_team_member';
            $settings['nested'] = false;
            $settings['selected_option'] = 'name'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $html_members = '';
            $social_html = '';

            extract(shortcode_atts(array(
                'style' => '',
                'name' => '',
                'position' => '',
                'text' => '',
                'image' => '',
                'url' => '',
                'social' => '',
                            ), $atts, 'cma_team_member'));

            // team member image
            $image = explode(',', $image);

            //get first image
            $image_url = wp_get_attachment_image_src($image[0], 'full');

            // crop the image
            $params = array('width' => 270, 'height' => 300);
            if ($vlc_is_retina) {
                $params = array('width' => 540, 'height' => 600);
            }
            $member_image = bfi_thumb($image_url[0], $params);
            $member_image = "<img src='{$member_image}' alt='{$name}'/>";

            // text cut if it's too long
            $text = volcanno_substr($text, 150, 3);

            // team member page
            if (!empty($url)) {
                $url = esc_url($url);

                $hover_link = "<a href='{$url}' class='mask'></a>";
                $image_link = "<a href='{$url}'>
                                    {$member_image}
                                </a>";
            } else {
                $hover_link = "";
                $image_link = $member_image;
            }
            
            $name = esc_html($name);
            $position = esc_html($position);

            if (!empty($social) && is_array($social)) {
                // social network icons
                $social_html = "<ul class='member-social clearfix'>";
                foreach ($social as $network) {
                    $social_url = $network['url'];
                    $social_url = esc_url($social_url);
                    $person_name = explode(" ", $name);
                    
                    $social_text = sprintf(esc_html__('Link with %s', 'pi_framework'), $person_name[0]);

                    if ($style == 'simple-2') {
                        $social_html .= "<li>
                                        <div class='icon'>
                                                <i class='{$network['icon']}'></i>
                                        </div>
                                        <a href='{$social_url}'>{$social_text}</a>
                                    </li>";
                    } else if ($style == 'team-horizontal') {
                        $social_html .= "<li>
                                        <a href='{$social_url}' class='{$network['icon']}'></a>
                                    </li>";
                    }
                }
                $social_html .= "</ul>";
            }

            if ($style == 'simple-2') {
                $html = "<div class='team-member'>
                            <figure>
                                $image_link

                                <figcaption>
                                        <p class='member-name'>{$name}</p>
                                        <p class='member-position'>{$position}</p>
                                </figcaption>
                            </figure>

                            {$social_html}
                    </div>";
            } else if ($style == 'simple-1') {
                $html = "<div class='team-member simple-1'>
                            <figure>
                                $image_link

                                <figcaption>
                                        <p class='member-name'>{$name}</p>
                                        <p class='member-position'>{$position}</p>
                                </figcaption>
                            </figure>
                    </div>";
            } else if ($style == 'team-horizontal') {
                $html = "<div class='team-horizontal'>
                            <div class='team-member'>
                                $image_link

                                <div class='team-member-details'>
                                    <p class='member-name'>{$name}</p>
                                    <p class='member-position'>{$position}</p>

                                    <p>{$text}</p>

                                    {$social_html}
                                </div>                                  
                            </div>
                        </div>";
            }


            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'style' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select team member style.', 'pi_framework'),
                    'options' => array(
                        'simple-1' => 'Simple',
                        'simple-2' => 'Simple with Social icons',
                        'team-horizontal' => 'Horizontal',
                    )
                ),
                'name' => array(
                    'type' => 'text',
                    'title' => esc_html__('Name', 'pi_framework'),
                    'description' => esc_html__('Team member name.', 'pi_framework')
                ),
                'position' => array(
                    'type' => 'text',
                    'title' => esc_html__('Job position', 'pi_framework'),
                    'description' => esc_html__('Enter job position.', 'pi_framework')
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Write something about employee.', 'pi_framework'),
                    'condition' => array('style', '==', 'team-horizontal')
                ),
                'image' => array(
                    'type' => 'image',
                    'title' => esc_html__('Image', 'pi_framework'),
                    'description' => esc_html__('Please upload team member image', 'pi_framework')
                ),
                'url' => array(
                    'type' => 'text',
                    'title' => esc_html__('Page URL', 'pi_framework'),
                    'description' => esc_html__('Link to Team member personal page (leave empty to disable link).', 'pi_framework')
                ),
                'social' => array(
                    'type' => 'group',
                    'title' => esc_html__('Team members', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon', 'pi_framework'),
                            'description' => esc_html__('Team member social network.', 'pi_framework'),
                            "options" => volcanno_get_pixons_names()
                        ),
                        'url' => array(
                            'type' => 'text',
                            'title' => esc_html__('URL', 'pi_framework'),
                            'description' => esc_html__('Social network URL.', 'pi_framework'),
                            'default' => 'http://'
                        )
                    ),
                    'condition' => array('style', '!=', 'simple-1')
                )
            );
        }

    }

}
?>
