<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Team_Member_Grid")) {

    class CMA_Shortcodes_Team_Member_Grid extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Team Member (grid)', 'pi_framework');
            $settings['description'] = esc_html__('Grid with all team members.', 'pi_framework');
            $settings['shortcode'] = 'cma_team_members_grid';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element            

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;
            $html = '';

            $html_members = '';

            extract(shortcode_atts(array(
                'team_members' => ''
                            ), $atts, 'cma_team_members_grid'));


            foreach ($team_members as $member) {
                // team member image
                //get first image
                $image_url = wp_get_attachment_image_src($member['image'], 'full');

                // crop the image
                $params = array('width' => 270, 'height' => 300);
                if ($vlc_is_retina) {
                    $params = array('width' => 540, 'height' => 600);
                }
                $member_image = bfi_thumb($image_url[0], $params);
                $alt = esc_attr($member['name']);
                $member_name = esc_html($member['name']);
                $member_position = esc_html($member['position']);
                $member_image = "<img src='{$member_image}' alt='{$alt}'/>";

                // team member page
                if (!empty($member["url"])) {
                    $url = esc_url($member["url"]);
                    $mask_link = "<a href='{$url}'><div class='mask'></div></a>";
                } else {
                    $mask_link = "<div class='mask'></div>";
                }

                $html .= "<li class='team-member'>
                            <figure>
                                {$member_image}
                                <figcaption>
                                    <p class='member-name'>{$member_name}</p>
                                    <p class='member-position'>{$member_position}</p>
                                </figcaption>
                            </figure>
                               
                           {$mask_link}
                        </li>";
            }

            $html = "<ul class='team-hover clearfix'>{$html}</ul>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'team_members' => array(
                    'type' => 'group',
                    'title' => esc_html__('Team members', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'name' => array(
                            'type' => 'text',
                            'title' => esc_html__('Name', 'pi_framework'),
                            'description' => esc_html__('Team member name.', 'pi_framework')
                        ),
                        'position' => array(
                            'type' => 'text',
                            'title' => esc_html__('Job position', 'pi_framework'),
                            'description' => esc_html__('Enter job position.', 'pi_framework')
                        ),
                        'image' => array(
                            'type' => 'image',
                            'title' => esc_html__('Image', 'pi_framework'),
                            'description' => esc_html__('Please upload team member image', 'pi_framework')
                        ),
                        'url' => array(
                            'type' => 'text',
                            'title' => esc_html__('Page URL', 'pi_framework'),
                            'description' => esc_html__('Link to Team member personal page (leave empty to disable link).', 'pi_framework')
                        )
                    )
                ),
            );
        }

    }

}
?>
