<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Testimonials")) {

    class CMA_Shortcodes_Testimonials extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Testimonials', 'pi_framework');
            $settings['description'] = esc_html__('Simple testimonials with picture.', 'pi_framework');
            $settings['shortcode'] = 'cma_testimonials';
            $settings['nested'] = false;
            $settings['selected_option'] = 'author'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* scripts */
            wp_enqueue_script('cma-scripts-testimonials', CMA_CONTENT_URL . 'testimonials/js/testimonials.js', array('jquery'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina, $volcanno_theme_config;

            $image_left = '';
            $image_right = '';
            $date_html = '';
            $author_image = '';
            $html = '';

            extract(shortcode_atts(array(
                'type' => 'testimonial-image-left-pulled',
                'text' => 'Some text goes here',
                'date' => '',
                'author' => '',
                'position' => '',
                'image' => ''
                            ), $atts, 'cma_testimonials'));

            // get image if available
            if (($type != 'testimonial-icon' || $type != 'testimonial-simple') && !empty($image)) {

                // array of images
                $image = explode(',', $image);

                //get first image
                $image_url = wp_get_attachment_image_src($image[0], 'full');

                // crop image
                $params = array('width' => 97, 'height' => 97);
                if ($vlc_is_retina) {
                    $params = array('width' => 194, 'height' => 194);
                }

                // crop image and create HTML
                $author_image = bfi_thumb($image_url[0], $params);
                $alt = esc_attr($author);
                $author_image = "<img src='{$author_image}' alt='{$alt}'/>";
            }

            $text = wp_kses( $text, $volcanno_theme_config['allowed_html_tags'] );
            
            $author = esc_html($author);
            $position = esc_html($position);

            if ($type == 'testimonial-image-left-pulled' || $type == 'testimonial-image-top' || $type == 'testimonial-image-left' || $type == 'testimonial-image-left-circled') {
                if ($type == 'testimonial-image-left-pulled' && !empty($date)) {
                    $date_html = "<span class='date'>{$date}</span>";
                }

                $html = "<div class='testimonial {$type}'>
                            <div class='img-container'>
                                {$author_image}
                            </div>

                            <div class='testimonial-container'>
                                {$date_html}
                                <p>{$text}</p>

                                <span class='author'>{$author}, <strong>{$position}</strong></span>
                            </div>
                        </div>";
            } else if ($type == 'testimonial-image-bottom') {
                $html = "<div class='testimonial {$type}'>                            

                            <div class='testimonial-container'>
                                {$date_html}
                                <p>{$text}</p>                                
                            </div>
                            
                            <div class='testimonial-author-container'>
                                <div class='img-container'>
                                    {$author_image}
                                </div>
                                <span class='author'>{$author}</span>
                                <strong class='author-company'>{$position}</strong>
                            </div>
                        </div>";
            } else if ($type == 'testimonial-icon') {
                $html = "<div class='testimonial {$type}'>
                            <div class='testimonial-container'>
                                <p>{$text}</p>                                
                            </div>
                            <div class='author'>
                                    <span>{$author}, <strong>{$position}</strong></span>
                                </div>
                        </div>";
            } else if ($type == 'testimonial-simple') {
                $html = "<div class='testimonial {$type}'>
                            <p>{$text}</p>
                            <div class='author'>
                                <span>{$author}, <strong>{$position}</strong></span>
                            </div>
                        </div>";
            }


            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select testimoanial type.', 'pi_framework'),
                    'options' => array(
                        'testimonial-image-left-pulled' => esc_html__('Image Left Pulled', 'pi_framework'),
                        'testimonial-image-top' => esc_html__('Image Top', 'pi_framework'),
                        'testimonial-image-left' => esc_html__('Image Left', 'pi_framework'),
                        'testimonial-image-left-circled' => esc_html__('Image Circled', 'pi_framework'),
                        'testimonial-image-bottom' => esc_html__('Image Bottom', 'pi_framework'),
                        'testimonial-icon' => esc_html__('Icon', 'pi_framework'),
                        'testimonial-simple' => esc_html__('Simple', 'pi_framework')
                    ),
                    'default' => 'testimonial-image-left-pulled'
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Testimonial text.', 'pi_framework')
                ),
                'date' => array(
                    'type' => 'text',
                    'title' => esc_html__('Date', 'pi_framework'),
                    'description' => esc_html__('Enter date that will appear above text.', 'pi_framework'),
                    'condition' => array('type', '==', 'testimonial-image-left-pulled')
                ),
                'author' => array(
                    'type' => 'text',
                    'title' => esc_html__('Author', 'pi_framework'),
                    'description' => esc_html__('Testimonial author name.', 'pi_framework')
                ),
                'position' => array(
                    'type' => 'text',
                    'title' => esc_html__('Position', 'pi_framework'),
                    'description' => esc_html__('Testimonial author position.', 'pi_framework')
                ),
                'image' => array(
                    'type' => 'image',
                    'title' => esc_html__('Image', 'pi_framework'),
                    'description' => esc_html__('Testimonial author image.', 'pi_framework'),
                    'condition' => array('type', '!=', 'testimonial-icon|testimonial-simple')
                )
            );
        }

    }

}
?>
