<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Testimonials_Carousel")) {

    class CMA_Shortcodes_Testimonials_Carousel extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Testimonials Carousel', 'pi_framework');
            $settings['description'] = esc_html__('Simple testimonials carousel with picture.', 'pi_framework');
            $settings['shortcode'] = 'cma_testimonials_carousel';
            $settings['nested'] = false;
            $settings['selected_option'] = 'testimonials|author'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* scripts */
            wp_enqueue_script('cma-scripts-testimonials-carousel', CMA_CONTENT_URL . 'testimonials_carousel/js/testimonials_carousel.js', array('jquery', 'owl-carousel'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina, $volcanno_theme_config;

            $i = 1;
            $testimonials_html = '';
            $nav_class = '';

            extract(shortcode_atts(array(
                'type' => 'testimonial-image-left',
                'testimonials' => '',
                'auto_scroll' => '0',
                'timeout' => '3000',
                'nav' => 'dots'
                            ), $atts, 'cma_testimonials_carousel'));

            if ($nav == 'nav')
                $nav_class = 'owl-carousel-navigation';

            $testimonials_html .= "<div class='carousel-container'><div class='testimonials-carousel owl-carousel {$nav_class}' data-play='{$auto_scroll}' data-timeout='{$timeout}' data-navigation='{$nav}'>";

            foreach ($testimonials as $index => $testimonial) {
                $author_image = '';
                $date = '';

                // execute any shortcode that might be in text
                $content = wp_kses(do_shortcode($testimonial['text']), $volcanno_theme_config['allowed_html_tags']);

                // get image if available
                $images = $testimonial['image'];
                if (!empty($images)) {
                    // array of images
                    $image = explode(',', $images);

                    //get first image
                    $image_url = wp_get_attachment_image_src($image[0], 'full');

                    // crop image
                    $params = array('width' => 97, 'height' => 97);
                    if ($vlc_is_retina) {
                        $params = array('width' => 194, 'height' => 194);
                    }
                    $author_image = bfi_thumb($image_url[0], $params);
                    $alt = esc_attr($testimonial['author']);
                    $author_image = "<img src='{$author_image}' alt='{$alt}'>";
                }
                
                $author = esc_html($testimonial['author']);
                $position = esc_html($testimonial['position']);

                // carousel testimonial
                if ($type == 'testimonial-simple') {
                    $testimonials_html .= "<div class='owl-item'>
                                    <div class='testimonial {$type}'>
                                        <p>{$content}</p>
                                        <div class='author'><span>{$author}, <strong>{$position}</strong></span></div>
                                    </div>
                                </div>";
                } else {
                    if (!empty($testimonial['date'])) {
                        $date = "<span class='date'>" . $testimonial['date'] . "</span>";
                    }

                    $testimonials_html .= "<div class='owl-item'>
                                    <div class='testimonial {$type}'>
                                        <div class='img-container'>
                                            {$author_image}
                                        </div>

                                        <div class='testimonial-container'>
                                            {$date}
                                            <p>{$content}</p>

                                            <span class='author'>{$author}, <strong>{$position}</strong></span>
                                        </div>
                                    </div>
                                </div>";
                }
            }

            $testimonials_html .= "</div></div>";

            return $testimonials_html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Testimonial type', 'pi_framework'),
                    'description' => esc_html__('Select testimoanials type.', 'pi_framework'),
                    'default' => 'testimonial-image-left',
                    'options' => array(
                        'testimonial-simple' => 'Simple',
                        'testimonial-image-left' => 'Simple - Image Left',
                        'testimonial-image-left-pulled' => 'With background and Bullets'
                    )
                ),
                'auto_scroll' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Auto Scroll', 'pi_framework'),
                    'description' => esc_html__('Set testimonial to auto scroll.', 'pi_framework'),
                    'default' => '0'
                ),
                'timeout' => array(
                    'type' => 'number',
                    'title' => esc_html__('Scroll Timeout', 'pi_framework'),
                    'description' => esc_html__('Enter scrolling timeout.', 'pi_framework'),
                    'default' => '3000',
                    'options' => array(
                        'step' => 10
                    )
                ),
                'nav' => array(
                    'type' => 'select',
                    'title' => esc_html__('Navigation', 'pi_framework'),
                    'description' => esc_html__('Select navigation type', 'pi_framework'),
                    'default' => '3000',
                    'options' => array(
                        'none' => 'None',
                        'nav' => 'Prev & Next',
                        'dots' => 'Dots'
                    )
                ),
                'testimonials' => array(
                    'type' => 'group',
                    'title' => esc_html__('Testimonials', 'pi_framework'),
                    'max' => '',
                    'options' => array(
                        'author' => array(
                            'type' => 'text',
                            'title' => esc_html__('Author', 'pi_framework'),
                            'description' => esc_html__('Testimonial author name.', 'pi_framework')
                        ),
                        'position' => array(
                            'type' => 'text',
                            'title' => esc_html__('Position', 'pi_framework'),
                            'description' => esc_html__('Testimonial author position.', 'pi_framework')
                        ),
                        'image' => array(
                            'type' => 'image',
                            'title' => esc_html__('Image', 'pi_framework'),
                            'description' => esc_html__('Testimonial author image.', 'pi_framework'),
                            'condition' => array('type', '!=', 'testimonial-simple')
                        ),
                        'text' => array(
                            'type' => 'textarea',
                            'title' => esc_html__('Text', 'pi_framework'),
                            'description' => esc_html__('Testimonial text.', 'pi_framework')
                        ),
                        'date' => array(
                            'type' => 'text',
                            'title' => esc_html__('Date', 'pi_framework'),
                            'description' => esc_html__('Testimonial date.', 'pi_framework'),
                            'condition' => array('type', '!=', 'testimonial-simple')
                        ),
                    )
                )
            );
        }

    }

}
?>
