<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Text_Rotators")) {

    class CMA_Shortcodes_Text_Rotators extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Text Rotators', 'pi_framework');
            $settings['description'] = esc_html__('Script that will rotate word or part of text in paragraph.', 'pi_framework');
            $settings['shortcode'] = 'cma_text_rotator';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* jQuery Countdown timer */
            wp_register_script('cma-scripts-text-rotators-script', CMA_CONTENT_URL . 'text_rotators/js/morphext.min.js', array('jquery'), '1.0', TRUE);
            /* script */
            wp_enqueue_script('cma-scripts-text-rotators-init', CMA_CONTENT_URL . 'text_rotators/js/text_rotators.js', array('jquery', 'cma-scripts-text-rotators-script'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {

            $bkg_style = '';
            $classes = '';
            $replacement_html = '';

            extract(shortcode_atts(array(
                'type' => 'bounceIn',
                'background' => '',
                'border' => '0',
                'text' => '',
                'wrapper' => 'h2',
                            ), $atts, 'cma_text_rotator'));

            if (!empty($background)) {
                if ($border == '1') {
                    $bkg_style = "style='border-color: {$background};'";
                } else {
                    $bkg_style = "style='background-color: {$background};'";
                    $classes .= ' custom-background';
                }
            } else {
                if ($border == '1') {
                    $classes .= ' theme-color-border';
                } else {
                    $classes .= ' theme-bkg';
                }
            }

            // clean and split string
            $text = trim($text);
            $splited = preg_split("/[{}]+/", $text, -1, PREG_SPLIT_NO_EMPTY);

            // check how many items array holds
            if (is_array($splited) && count($splited) > 1) {
                foreach ($splited as $value) {
                    $full_string = "{" . $value . "}";
                    if (strpos($text, $full_string) !== FALSE) {
                        if ($border == '1') {
                            $classes .= ' bordered';
                        }

                        $replacement_html = "<span class='rotator {$classes}' {$bkg_style}>" . $value . "</span>";
                        $text = str_replace($full_string, $replacement_html, $text);
                    }
                }
            }

            $html = "<{$wrapper} data-animation='{$type}'>{$text}</{$wrapper}>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Enter text and wrap text that should rotate with {} e.g {first, second, third}', 'pi_framework'),
                    'placeholder' => esc_html__('Sample text with word that rotates. Really {cool, nice, amazing}.', 'pi_framework'),
                ),
                'type' => array(
                    'type' => 'select',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select element type.', 'pi_framework'),
                    'options' => array(
                        'bounceIn' => esc_html__('Bounce In', 'pi_framework'),
                        'fadeInUp' => esc_html__('Fade In Up', 'pi_framework'),
                        'fadeInDown' => esc_html__('Fade In Down', 'pi_framework'),
                        'flipInX' => esc_html__('Flip In-X', 'pi_framework'),
                        'pulse' => esc_html__('Pulse', 'pi_framework'),
                        'fadeIn' => esc_html__('Fade In', 'pi_framework'),
                        'zoomIn' => esc_html__('Zoom In', 'pi_framework')
                    ),
                    'default' => 'bounceIn'
                ),
                'background' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Background color', 'pi_framework'),
                    'description' => esc_html__('Set background color.', 'pi_framework')
                ),
                'border' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Border', 'pi_framework'),
                    'description' => esc_html__('Show only border instead full background.', 'pi_framework')
                ),
                'wrapper' => array(
                    'type' => 'select',
                    'title' => esc_html__('Wrapper', 'pi_framework'),
                    'description' => esc_html__('Select how to wrap content.', 'pi_framework'),
                    'options' => array(
                        'h1' => esc_html__('H1', 'pi_framework'),
                        'h2' => esc_html__('H2', 'pi_framework'),
                        'h3' => esc_html__('H3', 'pi_framework'),
                        'h4' => esc_html__('H4', 'pi_framework'),
                        'h5' => esc_html__('H5', 'pi_framework'),
                        'h6' => esc_html__('H6', 'pi_framework'),
                        'p' => esc_html__('Paragraph', 'pi_framework'),
                    ),
                    'default' => 'h2'
                )
            );
        }

    }

}
?>
