<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Timeline")) {

    class CMA_Shortcodes_Timeline extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Timeline', 'pi_framework');
            $settings['description'] = esc_html__('Describe your company history.', 'pi_framework');
            $settings['shortcode'] = 'cma_timeline';
            $settings['nested'] = false;
            $settings['selected_option'] = 'date'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-timeline', CMA_CONTENT_URL . 'timeline/js/timeline.js', array('jquery', 'nivoslider'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $html = '';
            $sorted_posts = array();
            $post_media = '';

            extract(shortcode_atts(array(
                'fetch_by' => 'date',
                'id' => '',
                'date' => '',
                'categories' => '',
                'read_more' => ''
                            ), $atts, 'cma_timeline'));

            if ($fetch_by == 'id' && !empty($id)) {
                $ids = explode(',', $id);

                $args = array(
                    'orderby' => 'post__in',
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'post__in' => $ids
                );

                $recent_posts = get_posts($args);
            } else if ($fetch_by == 'date' && !empty($date)) {
                $dates = explode(',', $date);

                foreach ($dates as $single_date) {
                    $single_date = trim($single_date);
                    $single_date = explode('/', $single_date);
                    $date_query[] = array(
                        'year' => $single_date[1],
                        'month' => $single_date[0]
                    );
                }
                $date_query['relation'] = 'OR';


                $args = array(
                    'posts_per_page' => '-1',
                    'orderby' => 'date',
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'date_query' => $date_query
                );

                $recent_posts = get_posts($args);
            } else if ($fetch_by == 'category' && !empty($categories)) {
                $args = array(
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'category' => $categories
                );

                $recent_posts = get_posts($args);
            } else {
                $args = array(
                    'orderby' => 'post_date',
                    'order' => 'DESC',
                    'post_type' => 'post',
                    'post_status' => 'publish',
                    'cat' => $categories
                );

                $recent_posts = wp_get_recent_posts($args, 'OBJECT');
            }

            // sort posts by year and month
            foreach ($recent_posts as $post) {
                $month = date("M", strtotime($post->post_date));
                $year = date("Y", strtotime($post->post_date));
                $sorted_posts[$year][$month][] = $post;
            }


            $html = "<div class='post-timeline clearfix'>";

            foreach ($sorted_posts as $year => $months) {
                foreach ($months as $month => $posts) {
                    $html .= "<div class='post-timeline-date'><span>{$month} {$year}</span></div>";

                    foreach ($posts as $post_index => $post) {

                        // post permalink
                        $post_permalink = get_permalink($post->ID);

                        if (get_post_format($post->ID) == 'gallery') {

                            $gallery_image = '';
                            $caption = '';
                            $captions_html = '';
                            $gallery_images = rwmb_meta('pt_gallery_images', 'type=image&size=full', $post->ID);

                            // generate image HTML
                            foreach ($gallery_images as $image) {

                                $params = array("width" => 520, "height" => 300);
                                if ($vlc_is_retina) {
                                    $params = array("width" => 1040, "height" => 600);
                                }
                                $featured_image = bfi_thumb($image['url'], $params);

                                if (!empty($image->caption)) {
                                    $caption = "title='#slider-caption-{$image->ID}'";
                                    $captions_html .= "<div id='slider-caption-{ $image->ID}' class='nivo-caption'>
                                                            <h3>{$image->caption}</h3>
                                                        </div>";
                                }

                                $gallery_image .= "<img src='{$featured_image}' alt='{$image['title']}' {$caption}/>";
                            }

                            $post_media = "<div class='post-media'>
                                    <div class='nivo-wrapper'>
                                        <div class='nivoSlider'>
                                            {$gallery_image}
                                        </div>
                                        
                                        {$captions_html}
                                    </div>                               
                                </div>";
                        } else {

                            // post thumbnail
                            if (has_post_thumbnail($post->ID)) {

                                $thumbnail = get_post_thumbnail_id($post->ID);
                                $image_url = wp_get_attachment_image_src($thumbnail, 'full');

                                $params = array("width" => 520, "height" => 300);
                                if ($vlc_is_retina) {
                                    $params = array("width" => 1040, "height" => 600);
                                }
                                $featured_image = bfi_thumb($image_url[0], $params);
                            } else {
                                $featured_image = TEMPLATEURL . "/img/placeholder.jpg";
                            }

                            $post_media = "<div class='post-media'>
                                    <a href='{$post_permalink}'>
                                        <img src='{$featured_image}' alt='{$post->post_title}'/>
                                    </a>
                                </div>";
                        }



                        // format date
                        $date_format = get_option('date_format');
                        $post_date = get_the_date($date_format, $post);

                        // get post categories
                        $cats = array();
                        $post_categories = wp_get_post_categories($post->ID);
                        foreach ($post_categories as $c) {
                            $cat = get_category($c);
                            $cats[] = $cat->name;
                        }
                        $categories_string = join(", ", $cats);

                        // post content
                        if (!empty($post->post_excerpt)) {
                            $post_content = $post->post_excerpt;
                        } else {
                            $post_content = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $post->post_content);
                            $post_content = strip_tags($post_content);
                            $post_content = volcanno_substr($post_content, 200, 3);
                        }

                        // read more button
                        if (!empty($read_more)) {
                            $read_more = esc_html($read_more);
                            $read_more_html = "<a class='read-more' href='{$post_permalink}'>{$read_more}</a>";
                        }

                        if ($post_index % 2 == 1) {
                            $position = 'post-timeline-left';
                        } else {
                            $position = 'post-timeline-right';
                        }

                        $html .= "<div class='post-timeline-item {$position}'>
                                    {$post_media}

                                    <article class='post-body'>
                                        <a href='{$post_permalink}'>
                                            <h2>{$post->post_title}</h2>
                                        </a>

                                        <ul class='post-meta'>
                                            <li class='fa fa-calendar-o'><span>{$post_date}</span></li>
                                            <li class='fa fa-camera-retro'><span>{$categories_string}</span></li>
                                        </ul>

                                        <p>{$post_content}</p>

                                        {$read_more_html}
                                    </article>
                            </div>";
                    }
                }
            }

            $html .= "</div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'fetch_by' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Fetch posts by', 'pi_framework'),
                    'description' => esc_html__('Select how would you like to fetch posts.', 'pi_framework'),
                    'options' => array(
                        'id' => esc_html__('ID', 'pi_framework'),
                        'date' => esc_html__('Date', 'pi_framework'),
                        'category' => esc_html__('Category', 'pi_framework')
                    ),
                    'default' => 'date'
                ),
                'id' => array(
                    'type' => 'text',
                    'title' => esc_html__('ID\'s', 'pi_framework'),
                    'description' => esc_html__('Enter comma separated post IDs.', 'pi_framework'),
                    'condition' => array('fetch_by', '==', 'id')
                ),
                'date' => array(
                    'type' => 'text',
                    'title' => esc_html__('Dates', 'pi_framework'),
                    'description' => esc_html__('Enter months you want to be fetched. Format: 04/2014, 11/2014 ...', 'pi_framework'),
                    'condition' => array('fetch_by', '==', 'date'),
                    'placeholder' => '04/2014, 11/2014'
                ),
                'categories' => array(
                    'type' => 'text',
                    'title' => esc_html__('Categories', 'pi_framework'),
                    'description' => esc_html__('Enter post categories that will be used to fetch posts (slug or ID).', 'pi_framework'),
                    'condition' => array('fetch_by', '==', 'category')
                ),
                'read_more' => array(
                    'type' => 'text',
                    'title' => esc_html__('Read More', 'pi_framework'),
                    'description' => esc_html__('Enter text for link to single post. Default: Read More', 'pi_framework'),
                    'default' => esc_html__('Read more', 'pi_framework'),
                )
            );
        }

    }

}
?>
