<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Tooltips")) {

    class CMA_Shortcodes_Tooltips extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Tooltips', 'pi_framework');
            $settings['description'] = esc_html__('Add tooltip to part of text.', 'pi_framework');
            $settings['shortcode'] = 'cma_tooltips';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_stylesheets() {
            /* Hint CSS stylesheet */
            wp_enqueue_style('cma-style-tooltip', CMA_CONTENT_URL . 'tooltips/css/hint.min.css', array(), '1.0', 'screen');
        }

        function shortcode_html($atts = array(), $content = null) {

            $bkg_style = '';
            $classes = '';
            $replacement_html = '';
            

            extract(shortcode_atts(array(
                'text' => 'This is default {tooltip|Tooltip text.} text.',
                'position' => 'top',
                'style' => 'black'
                            ), $atts, 'cma_tooltips'));

            // clean and split string
            $text = trim($text);
            $text = esc_html($text);
            $splited = preg_split("/[{}]+/", $text, -1, PREG_SPLIT_NO_EMPTY);

            // check how many items array holds
            if (is_array($splited) && count($splited) > 1) {
                foreach ($splited as $value) {
                    $full_string = "{" . $value . "}";
                    if (strpos($text, $full_string) !== FALSE) {
                        $tooltip = explode("|", $value);

                        $replacement_html = "<strong class='hint--{$position} hint--{$style}' data-hint='{$tooltip[1]}'>" . $tooltip[0] . "</strong> ";
                        $text = str_replace($full_string, $replacement_html, $text);
                    }
                }
            }

            $html = $text;

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Enter text and use this format for tooltip: This word has {tooltip|This is tooltip text.}', 'pi_framework'),
                    'placeholder' => esc_html__('This word has {tooltip|This is tooltip text.}', 'pi_framework'),
                ),
                'position' => array(
                    'type' => 'select',
                    'title' => esc_html__('Position', 'pi_framework'),
                    'description' => esc_html__('Select position of tooltip in relation to text.', 'pi_framework'),
                    'options' => array(
                        'top' => esc_html__('Top', 'pi_framework'),
                        'bottom' => esc_html__('Bottom', 'pi_framework'),
                        'left' => esc_html__('Left', 'pi_framework'),
                        'right' => esc_html__('Right', 'pi_framework')
                    ),
                    'default' => 'top'
                ),
                'style' => array(
                    'type' => 'select',
                    'title' => esc_html__('Style', 'pi_framework'),
                    'description' => esc_html__('Select tooltip style.', 'pi_framework'),
                    'options' => array(
                        'black' => esc_html__('Black', 'pi_framework'),
                        'error' => esc_html__('Error', 'pi_framework'),
                        'warning' => esc_html__('Warning', 'pi_framework'),
                        'info' => esc_html__('Info', 'pi_framework'),
                        'success' => esc_html__('Success', 'pi_framework'),
                        'theme-color' => esc_html__('Theme Color', 'pi_framework')
                    ),
                    'default' => 'black'
                )
            );
        }

    }

}
?>
