<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Work_Flow")) {

    class CMA_Shortcodes_Work_Flow extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Work Flow', 'pi_framework');
            $settings['description'] = esc_html__('You can describe how you develop your product.', 'pi_framework');
            $settings['shortcode'] = 'cma_work_flow';
            $settings['nested'] = false;
            $settings['selected_option'] = 'title'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* script */
            wp_enqueue_script('cma-scripts-work-flow-script', CMA_CONTENT_URL . 'work_flow/js/jquery.matchHeight-min.js', array('jquery'), '1.0', TRUE);
            /* init */
            wp_enqueue_script('cma-scripts-work-flow-init', CMA_CONTENT_URL . 'work_flow/js/work_flow.js', array('jquery', 'cma-scripts-work-flow-script'), '1.0', TRUE);
        }

        function shortcode_html($atts = array(), $content = null) {
            global $volcanno_theme_config;

            $html = '';
            $count_class = '';

            extract(shortcode_atts(array(
                'type' => 'process-perspective',
                'icon' => 'fa-star-o',
                'title' => 'Work Flow',
                'text' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean est eros, viverra at dolor nec, laoreet rhoncus felis. Maecenas hendrerit posuere luctus.',
                'work_flow' => ''
                            ), $atts, 'cma_work_flow'));

            $title = wp_kses($title, $volcanno_theme_config['allowed_html_tags']);
            $text = wp_kses($text, $volcanno_theme_config['allowed_html_tags']);

            if ($type == 'process-perspective') {
                $html = "<div class='{$type}'>
                            <div class='icon'>
                                <div class='circle-up'>
                                    <i class='fa {$icon}'></i>
                                </div>
                                <div class='circle-inner'></div>
                            </div>

                            <h4>{$title}</h4>

                            <p>{$text}</p>
                        </div>";
            } else {
                if (count($work_flow) == 2) {
                    $count_class = 'pbc-two-cols';
                } else if (count($work_flow) == 3) {
                    $count_class = 'pbc-three-cols';
                } else if (count($work_flow) == 4) {
                    $count_class = 'pbc-four-cols';
                }

                foreach ($work_flow as $index => $single) {
                    if ($index == 5)
                        break;

                    $single_title = $title = wp_kses($single['title'], $volcanno_theme_config['allowed_html_tags']);
                    $single_text = $title = wp_kses($single['text'], $volcanno_theme_config['allowed_html_tags']);

                    $html .= "<div class='{$type} {$count_class}'>
                            <div class='process-box box-{$index}'>
                                <i class='fa {$single['icon']}'></i>

                                <h4>{$single_title}</h4>

                                <p>{$single_text}</p>
                            </div>
                        </div>";
                }
            }


            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'pi_framework'),
                    'description' => esc_html__('Select tab type.', 'pi_framework'),
                    'options' => array(
                        'process-perspective' => esc_html__('Simple', 'pi_framework'),
                        'process-box-container' => esc_html__('Boxed (2-4 boxes allowed)', 'pi_framework')
                    ),
                    'default' => 'process-perspective'
                ),
                'icon' => array(
                    'type' => 'icon_picker',
                    'title' => esc_html__('Icon', 'pi_framework'),
                    'description' => esc_html__('Select icon.', 'pi_framework'),
                    'default' => '',
                    'condition' => array('type', '==', 'process-perspective')
                ),
                'title' => array(
                    'type' => 'text',
                    'title' => esc_html__('Title', 'pi_framework'),
                    'description' => esc_html__('Please enter title.', 'pi_framework'),
                    'condition' => array('type', '==', 'process-perspective')
                ),
                'text' => array(
                    'type' => 'textarea',
                    'title' => esc_html__('Text', 'pi_framework'),
                    'description' => esc_html__('Please enter description.', 'pi_framework'),
                    'condition' => array('type', '==', 'process-perspective')
                ),
                'work_flow' => array(
                    'type' => 'group',
                    'title' => 'Work Flow',
                    'max' => '',
                    'options' => array(
                        'icon' => array(
                            'type' => 'icon_picker',
                            'title' => esc_html__('Icon', 'pi_framework'),
                            'description' => esc_html__('Select icon.', 'pi_framework'),
                            'default' => ''
                        ),
                        'title' => array(
                            'type' => 'text',
                            'title' => esc_html__('Title', 'pi_framework'),
                            'description' => esc_html__('Please enter title.', 'pi_framework')
                        ),
                        'text' => array(
                            'type' => 'textarea',
                            'title' => esc_html__('Text', 'pi_framework'),
                            'description' => esc_html__('Please enter description.', 'pi_framework')
                        ),
                    ),
                    'condition' => array('type', '==', 'process-box-container')
                )
            );
        }

    }

}
?>
