<?php

/* -------------------------------------------------------------------- 
 * Post formats and portfolio template scripts
  -------------------------------------------------------------------- */

function volcanno_enqueue_additional_metabox_scripts() {
    $screen = get_current_screen();

    if ($screen->base == 'post') {
        wp_enqueue_script('rwmb-custom-scripts', TEMPLATEURL . '/core/meta-box/custom-fields/custom-scripts.js', array('jquery'), '1.0', true);
    }
}

if (is_admin()) {
    add_action('admin_enqueue_scripts', 'volcanno_enqueue_additional_metabox_scripts');
}

/* -------------------------------------------------------------------- 
 * MetaBox for Custom Post Types
  -------------------------------------------------------------------- */

function volcanno_register_meta_boxes($meta_boxes) {
    global $volcanno_theme_config;

    // Get avaliable pages
    $all_avaliable_pages = get_pages('sort_column=post_parent,menu_order');
    $pages[''] = 'Select a page';
    foreach ($all_avaliable_pages as $page) {
        $pages[$page->ID] = $page->post_title;
    }

    // Define a meta box for Pages

    $prefix = 'pg_';

    $meta_boxes[] = array('title' => esc_html__('Page Options', 'pi_framework'),
        'pages' => array('page'),
        // Works with Meta Box Tabs plugin
        'tabs' => array(
            'page_title' => esc_html__('Page title', 'pi_framework'),
            'portfolio' => esc_html__('Portfolio options', 'pi_framework'),
            'gallery' => esc_html__('Gallery options', 'pi_framework'),
            'common' => esc_html__('Common options', 'pi_framework'),
            'single' => esc_html__('Single page options', 'pi_framework'),
        ),
        'fields' => array(
            /*
             * PAGE TITLE
             */
            array(
                'name' => esc_html__('Title style', 'pi_framework'),
                'desc' => esc_html__('Select desired title style.', 'pi_framework'),
                'id' => "{$prefix}title_style",
                'type' => 'select',
                'std' => 'large',
                'options' => array(
                    '1' => esc_html__('Black background behind text', 'pi_framework'),
                    '2' => esc_html__('Simple thick', 'pi_framework'),
                    '3' => esc_html__('With icon', 'pi_framework'),
                    '4' => esc_html__('Centered', 'pi_framework'),
                    '5' => esc_html__('Centered large', 'pi_framework'),
                    '6' => esc_html__('With additional image', 'pi_framework'),
                    '7' => esc_html__('Classic', 'pi_framework')
                ),
                'tab' => 'page_title'
            ),
            array(
                'name' => esc_html__('Sidebar', 'pi_framework'),
                'desc' => esc_html__('Page can have left or right sidebar.', 'pi_framework'),
                'id' => "{$prefix}sidebar",
                'type' => 'image_select',
                'std' => 'fullwidth',
                'options' => array(
                    'fullwidth' => TEMPLATEURL . '/core/assets/images/fullwidth.png',
                    'left' => TEMPLATEURL . '/core/assets/images/left.png',
                    'right' => TEMPLATEURL . '/core/assets/images/right.png'
                ),
                'tab' => 'page_title',
            ),
            array(
                'name' => esc_html__('Hide page title', 'pi_framework'),
                'id' => "{$prefix}hide_title",
                'desc' => esc_html__('Check this to hide page title.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'page_title'
            ),
            array(
                'name' => esc_html__('Nice title', 'pi_framework'),
                'id' => "{$prefix}page_description",
                'desc' => esc_html__('Nice title will replace page title.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'page_title'
            ),
            array(
                'name' => esc_html__('Subtitle', 'pi_framework'),
                'id' => "{$prefix}subtitle",
                'desc' => esc_html__('Small title that appears above/below title.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'page_title'
            ),
            array(
                'name' => esc_html__('Second Subtitle', 'pi_framework'),
                'id' => "{$prefix}subtitle_under",
                'desc' => esc_html__('Small title that appears below title.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'page_title'
            ),
            array(
                'name' => esc_html__('Background color', 'pi_framework'),
                'desc' => esc_html__('Set title background color.', 'pi_framework'),
                'id' => "{$prefix}title_color",
                'type' => 'color',
                'tab' => 'page_title'
            ),
            // Image Upload
            array(
                'name' => esc_html__('Background image', 'pi_framework'),
                'desc' => esc_html__('Set background image..', 'pi_framework'),
                'id' => "{$prefix}title_image",
                'type' => 'image_advanced',
                'max_file_uploads' => 1,
                'tab' => 'page_title'
            ),
            // Image Upload
            array(
                'name' => esc_html__('Image (right side)', 'pi_framework'),
                'desc' => esc_html__('Upload image that will appear on the right side of title.', 'pi_framework'),
                'id' => "{$prefix}title_image_right",
                'type' => 'image_advanced',
                'max_file_uploads' => 1,
                'tab' => 'page_title'
            ),
            // Icon
            array(
                'name' => esc_html__('Icon', 'pi_framework'),
                'id' => "{$prefix}title_icon",
                'type' => 'select_advanced',
                'options' => volcanno_font_awesome_classes(),
                'std' => '',
                'desc' => esc_html__('Select icon for this Page title style.', 'pi_framework'),
                'tab' => 'page_title'
            ),
            /*
             * PORTFOLIO
             */
            array(
                'name' => esc_html__('Style', 'pi_framework'),
                'id' => "{$prefix}portfolio_style",
                'type' => 'select',
                'options' => array(
                    '1-col' => esc_html__('1 Column', 'pi_framework'),
                    '2-col' => esc_html__('2 Column', 'pi_framework'),
                    '3-col' => esc_html__('3 Column', 'pi_framework'),
                    'full' => esc_html__('Full width', 'pi_framework'),
                    'masonry' => esc_html__('Masonry', 'pi_framework'),
                    'masonry_full' => esc_html__('Masonry Full width', 'pi_framework')
                ),
                'std' => '1-col',
                'desc' => esc_html__('Select portfolio style.', 'pi_framework'),
                'tab' => 'portfolio'
            ),
            array(
                'name' => esc_html__('Hover Style', 'pi_framework'),
                'id' => "{$prefix}portfolio_hover_style",
                'type' => 'select',
                'options' => array(
                    'simple' => esc_html__('Simple - plus', 'pi_framework'),
                    'zoom_link' => esc_html__('Zoom & Link icons', 'pi_framework')
                ),
                'std' => 'simple',
                'desc' => esc_html__('Select portfolio style.', 'pi_framework'),
                'tab' => 'portfolio'
            ),
            /*
             * GALLERY
             */
            array(
                'name' => esc_html__('Style', 'pi_framework'),
                'id' => "{$prefix}gallery_style",
                'type' => 'select',
                'options' => array(
                    '2-col' => esc_html__('2 Column', 'pi_framework'),
                    '3-col' => esc_html__('3 Column', 'pi_framework'),
                    'full' => esc_html__('Full width', 'pi_framework'),
                    'masonry' => esc_html__('Masonry', 'pi_framework')
                ),
                'std' => '2-col',
                'desc' => esc_html__('Select gallery style.', 'pi_framework'),
                'tab' => 'gallery'
            ),
            array(
                'name' => esc_html__('Hover Style', 'pi_framework'),
                'id' => "{$prefix}gallery_hover_style",
                'type' => 'select',
                'options' => array(
                    'simple' => esc_html__('Simple - plus icon', 'pi_framework'),
                    'simple_flyin' => esc_html__('Plus icon & title fly-in', 'pi_framework')
                ),
                'std' => 'simple',
                'desc' => esc_html__('Select portfolio style.', 'pi_framework'),
                'tab' => 'gallery'
            ),
            /*
             * COMMON
             */
            array(
                'name' => esc_html__('Order', 'pi_framework'),
                'id' => "{$prefix}portfolio_gallery_order",
                'type' => 'select',
                'options' => array(
                    'ASC' => esc_html__('Ascending', 'pi_framework'),
                    'DESC' => esc_html__('Descending', 'pi_framework')
                ),
                'std' => 'ASC',
                'desc' => esc_html__('Select items order.', 'pi_framework'),
                'tab' => 'common'
            ),
            array(
                'name' => esc_html__('Order By', 'pi_framework'),
                'id' => "{$prefix}portfolio_gallery_order_by",
                'type' => 'select',
                'options' => array(
                    'id' => esc_html__('ID', 'pi_framework'),
                    'title' => esc_html__('Title', 'pi_framework'),
                    'date' => esc_html__('Date', 'pi_framework'),
                    'rand' => esc_html__('Random', 'pi_framework'),
                ),
                'std' => 'id',
                'desc' => esc_html__('Order items by one of available parameters.', 'pi_framework'),
                'tab' => 'common'
            ),
            array(
                'name' => esc_html__('Pagination', 'pi_framework'),
                'id' => "{$prefix}portfolio_gallery_pagination",
                'desc' => esc_html__('Number of items per page.', 'pi_framework'),
                'type' => 'slider',
                'std' => '12',
                'tab' => 'common'
            ),
            array(
                'name' => esc_html__('Lightbox', 'pi_framework'),
                'desc' => esc_html__('Change Lightbox options.', 'pi_framework'),
                'id' => "{$prefix}portfolio_gallery_lightbox_options",
                'type' => 'radio',
                'options' => array(
                    'animated' => esc_html__('Animated hover button', 'pi_framework'),
                    'image_link' => esc_html__('Image as lightbox link', 'pi_framework'),
                    'disabled' => esc_html__('Disabled', 'pi_framework')
                ),
                'std' => 'animated',
                'tab' => 'common'
            ),
            array(
                'name' => esc_html__('Images from project', 'pi_framework'),
                'id' => "{$prefix}portfolio_gallery_project_images",
                'desc' => esc_html__('In lightbox show images from project instead gallery of all project images.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'common'
            ),
            array(
                'name' => esc_html__('Include Categories', 'pi_framework'),
                'id' => $prefix . 'portfolio_gallery_include_cats',
                'desc' => esc_html__('Enter categories that you want to show on this page (category IDs)', 'pi_framework'),
                'type' => 'number',
                'clone' => true,
                'tab' => 'common'
            ),
            /*
             * SINGLE
             */
            array(
                'name' => esc_html__('Page title', 'pi_framework'),
                'id' => "{$prefix}single_page_title",
                'desc' => esc_html__('Show/Hide Page title section.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '1',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('CONTENT', 'pi_framework'),
                'id' => $prefix . 'heading_single_page_title',
                'desc' => esc_html__('Change appearance of content.', 'pi_framework'),
                'type' => 'heading',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Hide title', 'pi_framework'),
                'id' => "{$prefix}single_title",
                'desc' => esc_html__('Hide title that appears in content.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Hide Categories', 'pi_framework'),
                'id' => "{$prefix}single_hide_categories",
                'desc' => esc_html__('Hide categories that appear above title.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Hide Button', 'pi_framework'),
                'id' => "{$prefix}single_show_hide_button",
                'desc' => esc_html__('Hide button from content.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Custom Button Text', 'pi_framework'),
                'id' => $prefix . 'single_button_text',
                'desc' => esc_html__('Enter the button text. This value will override default value from Theme options.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Custom Button URL', 'pi_framework'),
                'id' => $prefix . 'single_button_url',
                'desc' => esc_html__('Enter the button URL. This value will override default value from Theme options.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('SLIDER', 'pi_framework'),
                'id' => $prefix . 'single_heading_slider',
                'desc' => esc_html__('Customize slider appearance.', 'pi_framework'),
                'type' => 'heading',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Slider', 'pi_framework'),
                'desc' => esc_html__('Select slider type.', 'pi_framework'),
                'id' => "{$prefix}single_slider_type",
                'type' => 'select',
                'std' => 'classic',
                'options' => array(
                    'classic' => 'Classic - simple slider',
                    'revolution' => 'Revolution Slider'
                ),
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Revolution slider alias', 'pi_framework'),
                'id' => $prefix . 'single_revolution_alias',
                'desc' => esc_html__('Alias of slider that you want to appear on this page.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Slider size', 'pi_framework'),
                'desc' => esc_html__('Select slider size.', 'pi_framework'),
                'id' => "{$prefix}single_slider_size",
                'type' => 'select',
                'std' => '8',
                'options' => array(
                    '4' => esc_html__('Grid 4', 'pi_framework'),
                    '6' => esc_html__('Grid 6', 'pi_framework'),
                    '7' => esc_html__('Grid 7', 'pi_framework'),
                    '8' => esc_html__('Grid 8', 'pi_framework'),
                    '9' => esc_html__('Grid 9', 'pi_framework'),
                    '12' => esc_html__('Grid 12', 'pi_framework')
                ),
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Auto Slide', 'pi_framework'),
                'id' => "{$prefix}single_slider_autoslide",
                'desc' => esc_html__('Enable autosliding.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Hide Arrows', 'pi_framework'),
                'id' => "{$prefix}single_slider_hide_arrows",
                'desc' => esc_html__('Hide slider arrows.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Image Cropping', 'pi_framework'),
                'id' => "{$prefix}single_image_cropping",
                'desc' => esc_html__('Image cropping - image will have full height.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '1',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Height', 'pi_framework'),
                'id' => $prefix . 'single_slider_height',
                'desc' => esc_html__('Set slider height (working only on classic slider).', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            /*
             * RELATED POSTS SECTION 
             */
            array(
                'name' => esc_html__('RELATED POSTS', 'pi_framework'),
                'id' => $prefix . 'single_heading_related',
                'desc' => esc_html__('Customize related posts section.', 'pi_framework'),
                'type' => 'heading',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Hide section', 'pi_framework'),
                'id' => "{$prefix}single_related_hide",
                'desc' => esc_html__('Hide Related posts section.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Title', 'pi_framework'),
                'id' => $prefix . 'single_related_posts_title',
                'desc' => esc_html__('Title for Related posts section.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Subtitle', 'pi_framework'),
                'id' => $prefix . 'single_related_posts_subtitle',
                'desc' => esc_html__('Subtitle for Related posts section.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Number of items', 'pi_framework'),
                'id' => $prefix . 'single_related_posts_number',
                'desc' => esc_html__('Enter number of items to load.', 'pi_framework'),
                'type' => 'slider',
                'std' => '5',
                'tab' => 'single'
            ),
            array(
                'name' => esc_html__('Filter', 'pi_framework'),
                'desc' => esc_html__('Select which posts should be generated.', 'pi_framework'),
                'id' => "{$prefix}single_related_posts_filter",
                'type' => 'radio',
                'options' => array(
                    'latest' => esc_html__('Latest', 'pi_framework'),
                    'category' => esc_html__('Same category', 'pi_framework'),
                    'random' => esc_html__('Random', 'pi_framework')
                ),
                'std' => 'latest',
                'tab' => 'single'
            ),
        )
    );

    // Define a meta box for Blog

    $prefix = 'pt_';
    $meta_boxes[] = array(
        'title' => esc_html__('Post Format Options', 'pi_framework'),
        'pages' => array('post'),
        'fields' => array(
            array(
                'type' => 'heading',
                'name' => esc_html__('No options for this post format.', 'pi_framework'),
                'id' => 'post_format_options', // Not used but needed for plugin
            ),
            // Video URL
            array(
                'name' => esc_html__('Video Embed Code', 'pi_framework'),
                'id' => $prefix . 'video_url',
                'desc' => esc_html__('Please enter embed code (iframe).', 'pi_framework'),
                'type' => 'textarea',
                'std' => '',
            ),
            // Quote text
            array(
                'name' => esc_html__('Quote text', 'pi_framework'),
                'id' => $prefix . 'quote_text',
                'desc' => esc_html__('Please enter here quote text.', 'pi_framework'),
                'type' => 'textarea',
                'std' => '',
            ),
            array(
                'name' => esc_html__('Author', 'pi_framework'),
                'id' => $prefix . 'quote_author',
                'desc' => esc_html__('Please enter quote author.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
            ),
            // Audio files
            array(
                'name' => esc_html__('Audio files', 'pi_framework'),
                'id' => $prefix . 'audio_files',
                'desc' => wp_kses(__('Please enter link to audio file(s), one per line. Check <a href="http://www.jplayer.org/latest/developer-guide/#reference-html5-audio-format">here</a> which audio formats are supported by popular browsers.', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']),
                'type' => 'textarea',
                'std' => '',
            ),
            // Gallery images
            array(
                'name' => esc_html__('Gallery images', 'pi_framework'),
                'id' => $prefix . 'gallery_images',
                'desc' => wp_kses(__('Upload images for gallery. <strong>Minimum size:</strong> 620px x 308px', 'pi_framework'), $volcanno_theme_config['allowed_html_tags']),
                'type' => 'image_advanced'
            ),
            // Link
            array(
                'name' => esc_html__('Link', 'pi_framework'),
                'id' => $prefix . 'link_url',
                'desc' => esc_html__('Enter URL that will be used for Link post format.', 'pi_framework'),
                'type' => 'text'
            )
        )
    );

    // Define a meta box for Portfolio

    $prefix = 'pf_';
    $meta_boxes[] = array(
        'title' => esc_html__('Item Customization', 'pi_framework'),
        'pages' => array('pi_portfolio', 'pi_gallery'),
        'tabs' => array(
            'basic' => esc_html__('Basic', 'pi_framework'),
            'content' => esc_html__('Content', 'pi_framework'),
            'slider' => esc_html__('Slider', 'pi_framework')
        ),
        'fields' => array(
            // Image Upload
            array(
                'name' => esc_html__('Image', 'pi_framework'),
                'desc' => esc_html__('Use to upload image(s). Minimum image size: 540px x 363px.', 'pi_framework'),
                'id' => "{$prefix}image",
                'type' => 'image_advanced',
                'tab' => 'basic'
            ),
            array(
                'name' => esc_html__('Masonry Image', 'pi_framework'),
                'id' => "{$prefix}masonry_image",
                'desc' => esc_html__('Increase image height (double height) for this item.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'basic'
            ),
            array(
                'name' => esc_html__('Video URL', 'pi_framework'),
                'id' => $prefix . 'video_url',
                'desc' => esc_html__('Enter the video URL.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'basic'
            ),
            array(
                'name' => esc_html__('Custom Fields', 'pi_framework'),
                'id' => $prefix . 'custom_keyval',
                'desc' => esc_html__('Add custom fields after heading.', 'pi_framework'),
                'type' => 'key_value',
                'std' => '',
                'clone' => true,
                'multiple' => true,
                'tab' => 'basic'
            ),
            array(
                'name' => esc_html__('Override Options', 'pi_framework'),
                'id' => "{$prefix}theme_options_override",
                'desc' => esc_html__('Enable this to set different options for this portfolio item.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'basic'
            ),
            /**
             * Content
             */
            array(
                'name' => esc_html__('OVERRIDING VALUES', 'pi_framework'),
                'id' => "{$prefix}heading_override",
                'desc' => esc_html__('Values below will override values set in Theme Options.', 'pi_framework'),
                'type' => 'heading',
                'tab' => 'content'
            ),
            array(
                'name' => esc_html__('Page title', 'pi_framework'),
                'id' => "{$prefix}page_title",
                'desc' => esc_html__('Show/Hide Page title section.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '1',
                'tab' => 'single',
                'tab' => 'content'
            ),
            array(
                'name' => esc_html__('Hide Title (in content)', 'pi_framework'),
                'id' => "{$prefix}hide_title",
                'desc' => esc_html__('Hide title that appears in content.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'content'
            ),
            array(
                'name' => esc_html__('Hide Categories', 'pi_framework'),
                'id' => "{$prefix}hide_categories",
                'desc' => esc_html__('Hide categories that appear above title.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'content'
            ),
            // Show Button
            array(
                'name' => esc_html__('Hide Button', 'pi_framework'),
                'id' => "{$prefix}show_hide_button",
                'desc' => esc_html__('Hide button from content.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'content'
            ),
            array(
                'name' => esc_html__('Custom Button Text', 'pi_framework'),
                'id' => $prefix . 'button_text',
                'desc' => esc_html__('Enter the button text. This value will override default value from Theme options.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'content'
            ),
            array(
                'name' => esc_html__('Custom Button URL', 'pi_framework'),
                'id' => $prefix . 'button_url',
                'desc' => esc_html__('Enter the button URL. This value will override default value from Theme options.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'content'
            ),
            /*
             * Slider
             */
            array(
                'name' => esc_html__('Slider', 'pi_framework'),
                'desc' => esc_html__('Select slider type.', 'pi_framework'),
                'id' => "{$prefix}slider_type",
                'type' => 'select',
                'std' => 'large',
                'options' => array(
                    'classic' => esc_html__('Classic - simple slider', 'pi_framework'),
                    'revolution' => esc_html__('Revolution Slider', 'pi_framework')
                ),
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Revolution slider alias', 'pi_framework'),
                'id' => $prefix . 'revolution_alias',
                'desc' => esc_html__('Alias of slider that you want to appear on this page.', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Slider size', 'pi_framework'),
                'desc' => esc_html__('Select slider size.', 'pi_framework'),
                'id' => "{$prefix}slider_size",
                'type' => 'select',
                'std' => '8',
                'options' => array(
                    '4' => esc_html__('Grid 4', 'pi_framework'),
                    '6' => esc_html__('Grid 6', 'pi_framework'),
                    '7' => esc_html__('Grid 7', 'pi_framework'),
                    '8' => esc_html__('Grid 8', 'pi_framework'),
                    '9' => esc_html__('Grid 9', 'pi_framework'),
                    '12' => esc_html__('Grid 12', 'pi_framework')
                ),
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Hide Arrows', 'pi_framework'),
                'id' => "{$prefix}slider_hide_arrows",
                'desc' => esc_html__('Hide slider arrows.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Auto Slide', 'pi_framework'),
                'id' => "{$prefix}slider_autoslide",
                'desc' => esc_html__('Enable autosliding.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '0',
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Disable Image Cropping', 'pi_framework'),
                'id' => "{$prefix}image_cropping",
                'desc' => esc_html__('Image cropping - image will have full height.', 'pi_framework'),
                'type' => 'checkbox',
                'std' => '1',
                'tab' => 'slider'
            ),
            array(
                'name' => esc_html__('Height', 'pi_framework'),
                'id' => $prefix . 'slider_height',
                'desc' => esc_html__('Set slider height (working only on classic slider).', 'pi_framework'),
                'type' => 'text',
                'std' => '',
                'tab' => 'slider'
            ),
        )
    );

    return $meta_boxes;
}

add_filter('rwmb_meta_boxes', 'volcanno_register_meta_boxes');
?>
