<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "volcanno_options";


$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => 'volcanno_options',
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'submenu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Theme Options', 'pi_framework'),
    'page_title' => esc_html__('Theme Options', 'pi_framework'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => 'AIzaSyBsN1cG-NVXTUyefbmSlbv5NxMWyDzD8Nw',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => "volcanno_options",
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '_vlc_options',
    // Page slug used to denote the panel
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'system_info' => false,
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.		
$args['share_icons'][] = array(
    'url' => 'https://github.com/pixel-industry/',
    'title' => 'Visit us on GitHub',
    'icon' => 'el-icon-github'
// 'img' => '', // You can use icon OR img. IMG needs to be a full URL.
);
$args['share_icons'][] = array(
    'url' => 'https://www.facebook.com/pixel.industry.themes',
    'title' => 'Like us on Facebook',
    'icon' => 'el-icon-facebook'
);
$args['share_icons'][] = array(
    'url' => 'https://twitter.com/pixel_industry',
    'title' => 'Follow us on Twitter',
    'icon' => 'el-icon-twitter'
);
$args['share_icons'][] = array(
    'url' => 'http://www.linkedin.com/company/redux-framework',
    'title' => 'Find us on LinkedIn',
    'icon' => 'el-icon-linkedin'
);
$args['share_icons'][] = array(
    'url' => 'http://dribbble.com/pixel_industry',
    'title' => 'Our Work on Dribbble',
    'icon' => 'el-icon-dribbble'
);
$args['share_icons'][] = array(
    'url' => 'https://www.behance.net/pixel-industry',
    'title' => 'Our Portfolio on Behance',
    'icon' => 'el-icon-behance'
);



Redux::setArgs($opt_name, $args);

/*
 *
 * ---> START SECTIONS
 *
 */


// ACTUAL DECLARATION OF SECTIONS

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-cogs',
    'title' => esc_html__('General Settings', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'page_comments',
            'type' => 'checkbox',
            'title' => esc_html__('Page comments', 'pi_framework'),
            'subtitle' => esc_html__('Disable comments on all pages.', 'pi_framework'),
            'default' => '0'// 1 = on | 0 = off
        ),
        array(
            'id' => 'pagination',
            'type' => 'text',
            'title' => esc_html__('Pagination format', 'pi_framework'),
            'subtitle' => esc_html__('Enter Blog and Portfolio pagination format. %current% - current page, %total% - total pages.', 'pi_framework'),
            'default' => 'Page %current% of %total%',
        )
    )
));



Redux::setSection($opt_name, array(
    'icon' => 'el-icon-tint',
    'title' => esc_html__('Appearance', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'website_layout',
            'type' => 'select',
            'title' => esc_html__('Layout', 'pi_framework'),
            'subtitle' => esc_html__('Boxed or stretched layout.', 'pi_framework'),
            'options' => array('boxed' => 'Boxed', 'stretched' => 'Stretched'),
            'default' => 'stretched',
        ),
        array(
            'id' => 'body-background',
            'type' => 'background',
            'required' => array('website_layout', '=', 'boxed'),
            'output' => array('body'),
            'title' => esc_html__('Body Background', 'pi_framework'),
            'subtitle' => esc_html__('Body background with image, color, etc.', 'pi_framework'),
            'default' => array('background-image' => TEMPLATEURL . "/img/patt1.png"),
        ),
        array(
            'id' => 'container_border',
            'type' => 'border',
            'required' => array('website_layout', '=', 'boxed'),
            'title' => esc_html__('Container border', 'pi_framework'),
            'subtitle' => esc_html__('Set content container border style.', 'pi_framework'),
            'output' => array('#page-wrapper'), // An array of CSS selectors to apply this font style to
            'default' => array('border-color' => 'transparent', 'border-style' => 'solid', 'border-top' => '0', 'border-right' => '0', 'border-bottom' => '0', 'border-left' => '0')
        ),
        array(
            'id' => 'predefined_color_style',
            'type' => 'select',
            'title' => esc_html__('Color style', 'pi_framework'),
            'subtitle' => esc_html__('Choose on of available color styles or set custom in option below.', 'pi_framework'),
            'options' => array(
                'default-color' => 'Default',
                'color-blue2' => 'Blue 2',
                'color-brown' => 'Brown',
                'color-cyan' => 'Cyan',
                'color-green-light' => 'Green Light',
                'color-orange-light' => 'Orange Light',
                'color-orange' => 'Orange',
                'color-purple' => 'Purple',
                'color-red' => 'Red',
                'color-yellow' => 'Yellow'
            ),
            'default' => 'default-color',
        ),
        array(
            'id' => 'custom_color_style',
            'type' => 'color',
            'output' => array('.site-title'),
            'title' => esc_html__('Custom Color Style', 'pi_framework'),
            'subtitle' => esc_html__('Set custom color that will be applied to all elements..', 'pi_framework'),
            'default' => '',
            'validate' => 'color',
        ),
        array(
            'id' => 'scroll_to_top',
            'type' => 'checkbox',
            'title' => esc_html__('Scroll to Top', 'pi_framework'),
            'subtitle' => esc_html__('Show Scroll to Top button for easier navigation.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'responsive',
            'type' => 'checkbox',
            'title' => esc_html__('Responsive', 'pi_framework'),
            'subtitle' => esc_html__('Unheck to disable responsivness.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'parallax',
            'type' => 'checkbox',
            'title' => esc_html__('Parallax', 'pi_framework'),
            'subtitle' => esc_html__('Enable parallax effect (page title and portfolio single).', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'retina',
            'type' => 'checkbox',
            'title' => esc_html__('HiDPI images', 'pi_framework'),
            'subtitle' => esc_html__('Enable HiDPI images feature (Retina).', 'pi_framework'),
            'default' => '0'// 1 = on | 0 = off
        ),
        array(
            'id' => 'custom_css',
            'type' => 'textarea',
            'title' => esc_html__('Custom CSS', 'pi_framework'),
            'subtitle' => esc_html__('Quickly add some CSS to your theme by adding it to this block.', 'pi_framework'),
            'validate' => 'css',
            'output' => 'body'
        )
    )
));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-cogs',
    'title' => esc_html__('Header', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'header_style',
            'type' => 'select_image',
            'title' => esc_html__('Style', 'pi_framework'),
            'subtitle' => esc_html__('Select header style.', 'pi_framework'),
            'options' => array(
                'standard-top-bar' => array('alt' => 'Standard Top Bar', 'img' => TEMPLATEURL . '/img/theme-options/headers/standard-top-bar.JPG'),
                'standard-simple' => array('alt' => 'Standard Simple', 'img' => TEMPLATEURL . '/img/theme-options/headers/standard-simple.JPG'),
                'bottom-top-bar' => array('alt' => 'Bottom Top Bar', 'img' => TEMPLATEURL . '/img/theme-options/headers/bottom-top-bar.JPG'),
                'bottom-simple' => array('alt' => 'Bottom Simple', 'img' => TEMPLATEURL . '/img/theme-options/headers/bottom-simple.JPG'),
                'centered-top-bar' => array('alt' => 'Centered Top Bar', 'img' => TEMPLATEURL . '/img/theme-options/headers/centered-top-bar.JPG'),
                'centered-simple' => array('alt' => 'Centered Simple', 'img' => TEMPLATEURL . '/img/theme-options/headers/centered-simple.JPG'),
                'transparent' => array('alt' => 'Transparent', 'img' => TEMPLATEURL . '/img/theme-options/headers/transparent.JPG')
            ), //Must provide key => value(array:title|img) pairs for radio options
            'default' => 'standard-top-bar'
        ),
        array(
            'id' => 'header_color',
            'type' => 'radio',
            'title' => esc_html__('Background Color', 'pi_framework'),
            'compiler' => 'true',
            'subtitle' => esc_html__('Set dark or light background color.', 'pi_framework'),
            'options' => array(
                'light' => 'Light',
                'dark' => 'Dark'
            ),
            'required' => array('header_style', '!=', 'transparent'),
            'default' => 'light'
        ),
        array(
            'id' => 'static_header',
            'type' => 'checkbox',
            'title' => esc_html__('Static', 'pi_framework'),
            'subtitle' => esc_html__('Make header static.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'header_search',
            'type' => 'checkbox',
            'title' => esc_html__('Search', 'pi_framework'),
            'subtitle' => esc_html__('Show search button.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'logo',
            'type' => 'media',
            'title' => esc_html__('Logo', 'pi_framework'),
            'compiler' => 'true',
            'subtitle' => esc_html__('Upload logo for your website.', 'pi_framework')
        ),
        array(
            'id' => 'retina_logo',
            'type' => 'media',
            'title' => esc_html__('HiDPI Logo', 'pi_framework'),
            'compiler' => 'true',
            'subtitle' => esc_html__('Upload HiDPI (Retina) logo for your website.', 'pi_framework'),
            'required' => array('retina', 'equals', '1'),
        ),
        array(
            'id' => 'header_social_icons',
            'type' => 'select_text',
            'title' => esc_html__('Social Icons', 'pi_framework'),
            'subtitle' => esc_html__('Add social icons to header.', 'pi_framework'),
            'icons' => volcanno_get_pixons_names()
        ),
        array(
            'id' => 'menu_icons',
            'type' => 'select_label',
            'title' => esc_html__('Menu Icons', 'pi_framework'),
            'subtitle' => esc_html__('Add icons to menu items. Can be used only on regular menu, not Mega Menu.', 'pi_framework'),
            'icons' => volcanno_font_awesome_classes(),
            'options' => volcanno_get_top_level_menu_items('primary'),
            'default' => '',
            'key_prefix' => 'fa '
        ),
        array(
            'id' => 'header_contact',
            'type' => 'select_text',
            'title' => esc_html__('Top Bar Contact Text', 'pi_framework'),
            'subtitle' => esc_html__('Icon and text will be rendered above menu.', 'pi_framework'),
            'icons' => volcanno_font_awesome_classes(),
            'key_prefix' => 'fa '
        ),
        array(
            'id' => 'menu_contact_text',
            'type' => 'select_text',
            'title' => esc_html__('Menu Contact Text', 'pi_framework'),
            'subtitle' => esc_html__('Icon and text will be rendered next to logo (only on Header - Bottom Top Bar and Bottom Simple).', 'pi_framework'),
            'icons' => volcanno_font_awesome_classes(),
            'key_prefix' => 'fa '
        )
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-tint',
    'title' => esc_html__('Page title', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'title_text_color',
            'type' => 'color',
            'title' => esc_html__('Text color', 'pi_framework'),
            'subtitle' => esc_html__('Set custom text color for page title.', 'pi_framework'),
            'default' => '#39414b',
            'validate' => 'color',
            'output' => array('.pt-title h1'),
            'mode' => 'color'
        ),
        array(
            'id' => 'title_text_background_color',
            'type' => 'color',
            'title' => esc_html__('Text background color', 'pi_framework'),
            'subtitle' => esc_html__('Set custom text background color for page title.', 'pi_framework'),
            'default' => '',
            'validate' => 'color',
            'output' => array('.pt-title h1'),
            'mode' => 'background-color'
        ),
        array(
            'id' => '21',
            'type' => 'divide'
        ),
        array(
            'id' => 'show_breadcrumbs',
            'type' => 'switch',
            'title' => esc_html__('Breadcrumbs', 'pi_framework'),
            'subtitle' => esc_html__('Set breadcrumbs visibility.', 'pi_framework'),
            "default" => 1,
            'on' => 'Show',
            'off' => 'Hide',
        ),
        array(
            'id' => 'breadcrumbs_navigation_label',
            'type' => 'checkbox',
            'required' => array('show_breadcrumbs', '=', '1'),
            'title' => esc_html__('Breadcrumbs Text', 'pi_framework'),
            'subtitle' => esc_html__('Show navigation label instead page/post title.', 'pi_framework'),
            'default' => '0'// 1 = on | 0 = off
        ),
        array(
            'id' => 'breadcrumbs_length',
            'type' => 'text',
            'required' => array('show_breadcrumbs', '=', '1'),
            'title' => esc_html__('Breadcrumbs Length', 'pi_framework'),
            'desc' => esc_html__('Breadcrumbs will be cut by number of characters entered here.', 'pi_framework'),
            'validate' => 'numeric',
            'default' => 25
        ),
        array(
            'id' => 'breadcrumbs_prefix',
            'type' => 'text',
            'required' => array('show_breadcrumbs', '=', '1'),
            'title' => esc_html__('Breadcrumbs Prefix', 'pi_framework'),
            'desc' => esc_html__('Text that will be added before breadcrumbs.', 'pi_framework'),
            'default' => 'You are here: '
        ),
        array(
            'id' => 'section-title-portfolio-single',
            'type' => 'section',
            'title' => esc_html__('Portfolio single/category', 'pi_framework'),
            'subtitle' => esc_html__('Title on Portfolio single and category page.', 'pi_framework'),
            'indent' => false // Indent all options below until the next 'section' option is set.
        ),
        array(
            'id' => 'portfolio_category_show_title',
            'type' => 'switch',
            'title' => esc_html__('Show title', 'pi_framework'),
            'subtitle' => esc_html__('Check to show title on Portfolio category pages.', 'pi_framework'),
            "default" => 1,
            'on' => 'Show',
            'off' => 'Hide',
        ),
        array(
            'id' => 'portfolio_category_title_style',
            'type' => 'select',
            'title' => esc_html__('Title style', 'pi_framework'),
            'subtitle' => esc_html__('Choose title style.', 'pi_framework'),
            'options' => array('4' => 'Centered', '7' => 'Classic'),
            'default' => '4',
            'required' => array('portfolio_category_show_title', '=', '1')
        ),
        array(
            'id' => 'portfolio_category_title_color',
            'type' => 'color',
            'title' => esc_html__('Background Color', 'pi_framework'),
            'subtitle' => esc_html__('Set custom color for page title background.', 'pi_framework'),
            'default' => '#ededed',
            'validate' => 'color',
        ),
        array(
            'id' => 'portfolio_category_title_image',
            'type' => 'media',
            'title' => esc_html__('Background Image', 'pi_framework'),
            'compiler' => 'true',
            'subtitle' => esc_html__('Upload image that will be use as page title background.', 'pi_framework')
        )
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-font',
    'title' => esc_html__('Typography', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'body_font2',
            'type' => 'typography',
            'title' => esc_html__('Body Font', 'pi_framework'),
            'subtitle' => esc_html__('Specify the body font properties.', 'pi_framework'),
            'google' => true,
            'default' => array(
                'color' => '#777',
                'font-size' => '13px',
                'font-family' => 'Open Sans',
                'font-weight' => 'Normal',
                'line-height' => '22px'
            ),
            'output' => array('body')
        ),
        array(
            'id' => 'paragraphs',
            'type' => 'typography',
            'title' => esc_html__('Paragraph Font', 'pi_framework'),
            'subtitle' => esc_html__('Specify the paragraph font properties.', 'pi_framework'),
            'google' => true,
            'default' => array(
                'color' => '#777',
                'font-size' => '13px',
                'font-family' => 'Open Sans',
                'font-weight' => 'Normal',
                'line-height' => '22px'
            ),
            'output' => array('p')
        ),
        array(
            'id' => 'heading_h1',
            'type' => 'typography',
            'title' => esc_html__('H1 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the body font properties.', 'pi_framework'),
            'google' => true,
            'output' => array('h1'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '31px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '41px'
            ),
        ),
        array(
            'id' => 'heading_h2',
            'type' => 'typography',
            'title' => esc_html__('H2 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the properties for H2.', 'pi_framework'),
            'google' => true,
            'output' => array('h2'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '28px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '38px'
            ),
        ),
        array(
            'id' => 'heading_h3',
            'type' => 'typography',
            'title' => esc_html__('H3 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the properties for H3.', 'pi_framework'),
            'google' => true,
            'output' => array('h3'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '24px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '32px'
            ),
        ),
        array(
            'id' => 'heading_h4',
            'type' => 'typography',
            'title' => esc_html__('H4 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the properties for H4.', 'pi_framework'),
            'google' => true,
            'output' => array('h4'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '21px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '30px'
            ),
        ),
        array(
            'id' => 'heading_h5',
            'type' => 'typography',
            'title' => esc_html__('H5 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the properties for H5.', 'pi_framework'),
            'google' => true,
            'output' => array('h5'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '18px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '26px'
            ),
        ),
        array(
            'id' => 'heading_h6',
            'type' => 'typography',
            'title' => esc_html__('H6 Heading', 'pi_framework'),
            'subtitle' => esc_html__('Specify the properties for H6.', 'pi_framework'),
            'google' => true,
            'output' => array('h6'),
            'default' => array(
                'color' => '#252525',
                'font-size' => '15px',
                'font-family' => 'Raleway',
                'font-weight' => '500',
                'line-height' => '23px'
            ),
        ),
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-book',
    'title' => esc_html__('Blog', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'blog_style',
            'type' => 'select_image',
            'title' => esc_html__('Blog Layout', 'pi_framework'),
            'subtitle' => esc_html__('Choose blog layout.', 'pi_framework'),
            'options' => array(
                'blog-post-small' => array('alt' => 'Small images', 'img' => TEMPLATEURL . '/img/theme-options/blog-sidebar-small.jpg'),
                'blog-post-large' => array('alt' => 'Large images', 'img' => TEMPLATEURL . '/img/theme-options/blog-sidebar-large.jpg'),
                'blog-post-masonry-sidebar' => array('alt' => 'Masonry with sidebar', 'img' => TEMPLATEURL . '/img/theme-options/blog-sidebar-masonry.jpg'),
                'blog-post-masonry-full' => array('alt' => 'Fullwidth Masonry', 'img' => TEMPLATEURL . '/img/theme-options/blog-sidebar-masonry.jpg'),
                'blog-post-timeline' => array('alt' => 'Timeline style', 'img' => TEMPLATEURL . '/img/theme-options/blog-sidebar-masonry-full.jpg')
            ), //Must provide key => value(array:title|img) pairs for radio options
            'default' => 'blog-post-small'
        ),
        array(
            'id' => 'blog_sidebar_position',
            'type' => 'image_select',
            'title' => esc_html__('Sidebar Position', 'pi_framework'),
            'subtitle' => esc_html__('Sidebar on the left or on the right side.', 'pi_framework'),
            'options' => array(
                'left' => array('alt' => 'Left side', 'img' => ReduxFramework::$_url . 'assets/img/2cl.png'),
                'right' => array('alt' => 'Right side', 'img' => ReduxFramework::$_url . 'assets/img/2cr.png')
            ), //Must provide key => value(array:title|img) pairs for radio options
            'default' => 'right',
            'required' => array(
                array('blog_style', '=', array('blog-post-small', 'blog-post-large', 'blog-post-masonry-sidebar'))
            )
        ),
        array(
            'id' => 'blog_image_crop',
            'type' => 'checkbox',
            'title' => esc_html__('Image Cropping', 'pi_framework'),
            'subtitle' => esc_html__('Set image cropping for all images in main blog page.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'blog_hide_readmore',
            'type' => 'checkbox',
            'title' => esc_html__('Read More button', 'pi_framework'),
            'subtitle' => esc_html__('Show Read More button.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'blog_readmore_text',
            'type' => 'text',
            'required' => array('blog_hide_readmore', '=', '1'),
            'title' => esc_html__('Read More text', 'pi_framework'),
            'subtitle' => esc_html__('Read More button text.', 'pi_framework'),
            'default' => 'Read more',
            'validate' => 'no_html'
        ),
        array(
            'id' => 'blog_animation',
            'type' => 'select',
            'title' => esc_html__('Posts Animation', 'pi_framework'),
            'subtitle' => esc_html__('Set blog animation.', 'pi_framework'),
            'options' => volcanno_animate_css_animations(),
            'default' => 'disabled',
        ),
        array(
            'id' => 'blog_sidebar_animation',
            'type' => 'select',
            'title' => esc_html__('Sidebar Animation', 'pi_framework'),
            'subtitle' => esc_html__('Set blog sidebar animation.', 'pi_framework'),
            'options' => volcanno_animate_css_animations(),
            'default' => 'disabled',
        ),
        array(
            'id' => 'section-gallery',
            'type' => 'section',
            'title' => esc_html__('Gallery post format', 'pi_framework'),
            'subtitle' => esc_html__('Gallery post format options', 'pi_framework'),
            'indent' => false // Indent all options below until the next 'section' option is set.
        ),
        array(
            'id' => 'blog_gallery_slider_autoslide',
            'type' => 'checkbox',
            'title' => esc_html__('Slider auto sliding', 'pi_framework'),
            'subtitle' => esc_html__('Check to enable slider auto sliding', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'blog_gallery_slider_delay',
            'type' => 'text',
            'required' => array('blog_gallery_slider_autoslide', '=', '1'),
            'title' => esc_html__('Slider delay', 'pi_framework'),
            'subtitle' => esc_html__('Enter time delay [ms].', 'pi_framework'),
            'validate' => 'numeric',
            'default' => 3000
        ),
        array(
            'id' => 'section-single',
            'type' => 'section',
            'title' => esc_html__('Single post options', 'pi_framework'),
            'subtitle' => esc_html__('Edit single post options.', 'pi_framework'),
            'indent' => false // Indent all options below until the next 'section' option is set.
        ),
        array(
            'id' => 'blog_single_meta',
            'type' => 'checkbox',
            'title' => esc_html__('Post meta', 'pi_framework'),
            'subtitle' => esc_html__('Show/Hide post date and format.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'blog_single_show_author',
            'type' => 'checkbox',
            'title' => esc_html__('Post Author', 'pi_framework'),
            'subtitle' => esc_html__('Show post author below post.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        ),
        array(
            'id' => 'blog_single_author_section_title',
            'type' => 'text',
            'title' => esc_html__('Author Section Title', 'pi_framework'),
            'subtitle' => esc_html__('Change default title for Author section.', 'pi_framework'),
            'default' => esc_html__('About the Author', 'pi_framework'),
            'validate' => 'no_html'
        ),
        array(
            'id' => 'blog_single_image_crop',
            'type' => 'checkbox',
            'title' => esc_html__('Image Cropping', 'pi_framework'),
            'subtitle' => esc_html__('Set image cropping for all images in single post.', 'pi_framework'),
            'default' => '1'// 1 = on | 0 = off
        )
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-picture',
    'title' => esc_html__('Portfolio / Gallery', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'portfolio_page',
            'type' => 'select',
            'title' => esc_html__('Portfolio page', 'pi_framework'),
            'subtitle' => esc_html__('Select portfolio page. Options for single portfolio item will be fetched from this page.', 'pi_framework'),
            'data' => 'pages'
        ),
        array(
            'id' => 'portfolio_category_style',
            'type' => 'select',
            'title' => esc_html__('Portfolio category page style', 'pi_framework'),
            'subtitle' => esc_html__('Select category page style for portfolio.', 'pi_framework'),
            'options' => array('2-col' => '2 Columns', '3-col' => '3 Columns', '4-col' => '4 Columns', 'full' => 'Full width'),
            'default' => '3-col',
        ),
        array(
            'id' => 'portfolio_category_pagination',
            'type' => 'slider',
            'title' => esc_html__('Portfolio category pagination', 'pi_framework'),
            'subtitle' => esc_html__('Number of item to show on Portfolio category page.', 'pi_framework'),
            "default" => "8",
            "min" => "1",
            "step" => "1",
            "max" => "100",
        ),
        array(
            'id' => 'gallery_page',
            'type' => 'select',
            'title' => esc_html__('Gallery page', 'pi_framework'),
            'subtitle' => esc_html__('Select gallery page. Options for single portfolio item will be fetched from this page.', 'pi_framework'),
            'data' => 'pages'
        ),        
        array(
            'id' => 'gallery_category_style',
            'type' => 'select',
            'title' => esc_html__('Gallery category page style', 'pi_framework'),
            'subtitle' => esc_html__('Select category page style for gallery.', 'pi_framework'),
            'options' => array('2-col' => '2 Columns', '3-col' => '3 Columns', '4-col' => '4 Columns', 'full' => 'Full width'),
            'default' => '3-col',
        ),
        array(
            'id' => 'gallery_category_pagination',
            'type' => 'slider',
            'title' => esc_html__('Gallery category pagination', 'pi_framework'),
            'subtitle' => esc_html__('Number of item to show on Gallery category page.', 'pi_framework'),
            "default" => "8",
            "min" => "1",
            "step" => "1",
            "max" => "100",
        ),
        array(
            'id' => 'section-title-portfolio-single-2',
            'type' => 'section',
            'title' => esc_html__('Call to Action (single)', 'pi_framework'),
            'subtitle' => esc_html__('Call to Action on Portfolio single.', 'pi_framework'),
            'indent' => false // Indent all options below until the next 'section' option is set.
        ),
        array(
            'id' => 'portfolio_single_cta',
            'type' => 'switch',
            'title' => esc_html__('Call To Action (single)', 'pi_framework'),
            'subtitle' => esc_html__('Show Call to Action on Portfolio single page.', 'pi_framework'),
            "default" => 1,
            'on' => 'Show',
            'off' => 'Hide',
        ),
        array(
            'id' => 'portfolio_single_cta_title',
            'type' => 'text',
            'required' => array('portfolio_single_cta', '=', '1'),
            'title' => esc_html__('Title', 'pi_framework'),
            'subtitle' => esc_html__('Title for Call to action.', 'pi_framework'),
            'default' => 'Interested in our services? Contact us today'
        ),
        array(
            'id' => 'portfolio_single_cta_subtitle',
            'type' => 'text',
            'required' => array('portfolio_single_cta', '=', '1'),
            'title' => esc_html__('Subtitle', 'pi_framework'),
            'subtitle' => esc_html__('Subtitle for Call to action.', 'pi_framework'),
            'default' => 'This is simple example of call to action element design. It\'s the perfect element to grab your visitor attention.'
        ),
        array(
            'id' => 'portfolio_single_cta_button_text',
            'type' => 'text',
            'required' => array('portfolio_single_cta', '=', '1'),
            'title' => esc_html__('Button Text', 'pi_framework'),
            'subtitle' => esc_html__('Enter button text', 'pi_framework'),
            'default' => 'CONTACT US'
        ),
        array(
            'id' => 'portfolio_single_cta_button_url',
            'type' => 'text',
            'required' => array('portfolio_single_cta', '=', '1'),
            'title' => esc_html__('Button URL', 'pi_framework'),
            'subtitle' => esc_html__('Enter button url.', 'pi_framework'),
            'default' => 'www.pixel-industry.com'
        ),
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-adjust-alt',
    'title' => esc_html__('Footer', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'footer_show',
            'type' => 'switch',
            'title' => esc_html__('Show Footer', 'pi_framework'),
            'subtitle' => esc_html__('Show Footer section.', 'pi_framework'),
            "default" => 1,
            'on' => 'Show',
            'off' => 'Hide',
        ),
        array(
            'id' => 'footer_widget_areas',
            'type' => 'slider',
            'required' => array('footer_show', '=', '1'),
            'title' => esc_html__('Widget areas', 'pi_framework'),
            'subtitle' => esc_html__('Number of widget areas.', 'pi_framework'),
            "default" => "4",
            "min" => "1",
            "step" => "1",
            "max" => "4",
        ),
        array(
            'id' => 'copyright_text',
            'type' => 'textarea',
            'title' => esc_html__('Copyright Text', 'pi_framework'),
            'subtitle' => esc_html__('Enter copyright text.', 'pi_framework'),
            'validate' => 'html', //see http://codex.wordpress.org/Function_Reference/wp_kses_post
            'default' => 'COPYRIGHT PIXEL INDUSTRY 2015. ALL RIGHTS RESERVED.'
        ),
        array(
            'id' => 'widgets_animation',
            'type' => 'select',
            'title' => esc_html__('Widgets animation', 'pi_framework'),
            'subtitle' => esc_html__('Set animation for widgets.', 'pi_framework'),
            'options' => volcanno_animate_css_animations(),
            'default' => 'disabled',
        ),
)));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-inbox',
    'title' => esc_html__('Updates', 'pi_framework'),
    'fields' => array(
        array(
            'id' => 'themeforest_username',
            'type' => 'text',
            'title' => esc_html__('Username', 'pi_framework'),
            'subtitle' => esc_html__('Please enter ThemeForest username that was used to purchase this theme.', 'pi_framework')
        ), array(
            'id' => 'themeforest_api_key',
            'type' => 'text',
            'title' => esc_html__('API key', 'pi_framework'),
            'subtitle' => esc_html__('Please enter ThemeForest API key.', 'pi_framework')
        )
)));


/*
 * Load section for Content Maker and WooCommerce dynamically
 */
if (CONTENT_MAKER)
    add_filter("redux/options/volcanno_options/sections", 'cma_settings_fields');