<?php
/*
 * Title section for pages and posts.
 */

global $vlc_page_title, $volcanno_options, $vlc_is_retina, $volcanno_theme_config;
$title_classes = '';

// get page id
if (is_home() || is_singular('post') || is_category() || is_tag() || is_year() || is_month() || is_day() || is_author() || is_search() || is_404()) {
    if (!is_front_page()) {
        $page_id = ( 'page' == get_option('show_on_front') ? get_option('page_for_posts') : get_the_ID() );
    } else {
        $page_id = false;
    }
} else {
    $page_id = get_the_ID();
}

// defaults if Core plugin isn't activated
if (!RWMB_META_BOX || !$page_id) {
    $style = '1';

    // page title color or background image
    $page_title_color = '#ededed';
    $page_title_image = false;
} else {
    // title style
    if (is_singular('pi_portfolio') || is_tax('portfolio-category') || is_singular('pi_gallery') || is_tax('gallery-category')) {
        $style = $volcanno_options['portfolio_category_title_style'];

        // page title color or background image
        $page_title_color = $volcanno_options['portfolio_category_title_color'];
        $page_title_image = isset($volcanno_options['portfolio_category_title_image']) ? $volcanno_options['portfolio_category_title_image'] : '';
    } else {

        $style = rwmb_meta('pg_title_style', '', $page_id);

        $subtitle = rwmb_meta('pg_subtitle', '', $page_id);

        if ($style == '1') {
            $title_classes = 'light';
        }

        if ($style == '3') {
            $icon = rwmb_meta('pg_title_icon', '', $page_id);
        }

        if ($style == '5') {
            $subtitle_under = rwmb_meta('pg_subtitle_under', '', $page_id);
            $title_classes = 'parallax';
        }

        if ($style == '6') {
            $image_on_right = rwmb_meta('pg_title_image_right', 'type=image&size=full', $page_id);
            if (!empty($image_on_right))
                $image_on_right = reset($image_on_right);
        }

        // page title color
        $page_title_color = rwmb_meta('pg_title_color', '', $page_id);
        if (empty($page_title_color))
            $page_title_color = '#ededed';

        // page title image
        $page_title_image = rwmb_meta('pg_title_image', 'type=image&size=full', $page_id);

        if (!empty($page_title_image))
            $page_title_image = reset($page_title_image);
    }
}

if (!empty($page_title_image['url'])) {
    if ($style == '5') {
        $params = array('height' => 1600);
    } else {
        $params = array('width' => 1920, 'height' => 369);

        // if user is on retina device, double the size of image
        if ($vlc_is_retina) {
            $params = array('width' => 3840, 'height' => 738);
        }
    }

    $cropped_image = bfi_thumb($page_title_image['url'], $params);
    $page_title_style = "style='background-image: url(" . esc_url_raw($cropped_image) . ") !important;'";
} else if (!empty($page_title_color)) {
    $page_title_style = "style='background: " . esc_html($page_title_color) . " !important;'";
} else {
    $page_title_style = '';
}

// breadcrumbs
$show_breadrumbs = $volcanno_options['show_breadcrumbs'];

// check if parallax is enabled
$parallax = $volcanno_options['parallax'];
if (!empty($parallax)) {
    // get parallax background ratio
    if (CONTENT_MAKER) {
        $data_stellar_background_ratio = "data-stellar-background-ratio='" . cma_get_settings('data-stellar-background-ratio') . "'";
    } else {
        $data_stellar_background_ratio = 'data-stellar-background-ratio="0.4"';
    }
}
?>
<!-- #page-title.page-title-1 start -->
<div id="page-title" class="page-title-<?php echo intval($style), " ", sanitize_html_class($title_classes) ?>" <?php if ($style == '4' || $style == '5') { echo $page_title_style; /* do not escape */ } ?> <?php if ($style == '5') echo "data-stellar-background-ratio='0.4'"; ?>>
    <?php if ($style != '5') { ?>
        <?php if ($style == '1' || $style == '3' || $style == '6'): ?>
            <div class="page-title-inner" <?php echo $page_title_style /* do not escape */ ?>>
            <?php endif; ?>

            <!-- .container start -->
            <div class="container">
                <!-- .row start -->
                <div class="row">
                    <div class="col-md-<?php echo ($style == '6' || $style == '7') ? '6' : '12'; ?>">
                        <!-- .title-container start -->
                        <section class="title-container <?php if ($style == '3') echo 'clearfix'; ?>">
                            <?php if ($style == '1' || $style == '4' || $style == '6' || $style == '7'): ?>
                                <div class="title">
                                    <?php if ($style != '7' && !empty($subtitle)): ?>
                                        <h3><?php echo wp_kses($subtitle, $volcanno_theme_config['allowed_html_tags']); ?></h3>
                                    <?php endif; ?>

                                    <h1><?php echo wp_kses($vlc_page_title, $volcanno_theme_config['allowed_html_tags']) ?></h1>
                                </div>
                            <?php endif; ?>

                            <?php if ($style == '2' || $style == '3'): ?>
                                <div class="pt-title">
                                    <h1><?php echo wp_kses($vlc_page_title, $volcanno_theme_config['allowed_html_tags']) ?></h1>
                                </div><!-- .pt-title end -->

                                <div class="pt-info">
                                    <?php if ($style == '3'): ?>
                                        <div class="icon">
                                            <i class="fa <?php echo sanitize_html_class($icon) ?>"></i>
                                        </div>
                                    <?php endif; ?>

                                    <?php if (!empty($subtitle)): ?>
                                        <p><?php echo wp_kses($subtitle, $volcanno_theme_config['allowed_html_tags']); ?></p>
                                    <?php endif; ?>
                                </div><!-- .pt-info end -->
                            <?php endif; ?>
                        </section><!-- .title-container end -->
                    </div><!-- .col-md-12 end -->

                    <?php if ($style == '6'): ?>
                        <div class="col-md-6">
                            <div class="pt-image-container">
                                <div class="pt-image">
                                    <img class="float-right" src="<?php echo esc_url_raw($image_on_right['url']) ?>" alt=""/>
                                </div>
                            </div><!-- .pt-image-container end -->
                        </div><!-- .col-md-6 end -->
                    <?php endif; ?>

                    <?php if ($style == '7') { ?>
                        <?php if (!empty($show_breadrumbs)): ?>
                            <div class="col-md-6">
                                <div class="breadcrumbs-container">
                                    <?php volcanno_breadcrumbs(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php } ?>

                </div><!-- .row end -->                
            </div><!-- .container end -->

            <?php if ($style == '1' || $style == '3' || $style == '6'): ?>
            </div><!-- .page-title-inner end -->            
        <?php endif; ?>

    <?php } ?>

    <?php if ($style == '5') { ?>       
        <!-- .container start -->
        <div class="container">
            <div class="title-container">
                <div class="title">
                    <?php if (!empty($subtitle)): ?>
                        <h3><?php echo wp_kses($subtitle, $volcanno_theme_config['allowed_html_tags']); ?></h3>
                    <?php endif; ?>

                    <h1><?php echo wp_kses($vlc_page_title, $volcanno_theme_config['allowed_html_tags']) ?></h1>

                    <?php if (!empty($subtitle_under)): ?>
                        <p><?php echo wp_kses($subtitle_under, $volcanno_theme_config['allowed_html_tags']) ?></p>
                    <?php endif; ?>
                </div>
            </div><!-- .title-container end -->
        </div><!-- .container end -->

    <?php } ?>

    <?php if (!empty($show_breadrumbs) && ($style == '1' || $style == '2' || $style == '3' || $style == '4' || $style == '6')): ?>
        <!--.breadcrumbs-container start -->
        <div class="breadcrumbs-container <?php if ($style == '3' || $style == '6') echo 'theme-color'; ?>">
            <!-- .CONTAINER START -->
            <div class="container">
                <!-- .row start -->
                <div class="row">
                    <!-- .col-md-12 start -->
                    <div class="col-md-12">
                        <?php volcanno_breadcrumbs(); ?>
                    </div><!-- .col-md-12 end -->
                </div><!-- .row end -->
            </div><!-- .container end -->
        </div><!-- .breadcrumb-container end -->    
    <?php endif; ?>
</div><!-- #page-title.page-title-1 end -->