<?php
/**
 * Singe portfolio item template.
 */
get_header();

if (have_posts()) : the_post();

    global $volcanno_options, $vlc_page_title, $vlc_is_retina, $vlc_portfolio_options, $volcanno_theme_config;

    // hook that will be used to check if all 
    // necessary plugins are loaded before rendering page
    do_action('volcanno_pre_portfolio_single_render');

    $parent_page_id = false;
    $page_id = get_the_ID();
    $vlc_page_title = get_the_title();
    $terms_slugs = '';
    $terms_title = '';

    // get portfolio parent page  
    $args = array(
        'post_type' => 'page',
        'posts_per_page' => -1,
        'meta_query' => array(
            'relation' => 'OR',
            array(
                'key' => '_wp_page_template',
                'value' => 'portfolio-template.php',
                'compare' => '='
            )
        )
    );

    $template_pages = get_posts($args);

    if (count($template_pages) == 1) {
        $parent_page = reset($template_pages);
        $parent_page_id = $parent_page->ID;
    } else if (count($template_pages) > 1 && !empty($volcanno_options['portfolio_page'])) {
        $parent_page_id = $volcanno_options['portfolio_page'];
    } else if (count($template_pages) > 1) {
        foreach ($template_pages as $tmpl_page) {
            $include_categories = get_post_meta($tmpl_page->ID, 'pg_portfolio_gallery_include_cats', true);
            $current_categories = get_the_terms(get_the_ID(), 'portfolio-category');

            if (!empty($include_categories) && count($include_categories) == 1) {
                $current_page = reset($include_categories);
                $parent_page_id = $current_page->ID;
            } else if (!empty($include_categories)) {
                foreach ($current_categories as $category) {
                    if (in_array($category->term_id, $include_categories)) {
                        $parent_page_id = $tmpl_page->ID;
                    }
                }
            } else {
                $parent_page_id = false;
            }
        }
    }

    // allow changing id of the portfolio template page
    // can be used to fetch page options from different page
    $parent_page_id = apply_filters('volcanno_portfolio_page_id', $parent_page_id);

    // default options for portfolio single
    $portfolio_defaults = array(
        'page_title' => '1',
        'hide_title' => '0',
        'hide_categories' => '0',
        'show_hide_button' => '0',
        'button_text' => 'view project',
        'button_url' => '#',
        'slider_type' => 'classic',
        'slider_size' => '8',
        'revolution_alias' => '',
        'slider_hide_arrows' => '1',
        'slider_height' => '',
        'slider_autoslide' => '1',
        'image_cropping' => '1',
        'related_posts_title' => 'You might be also interested in...',
        'related_posts_subtitle' => 'RELATED PROJECTS',
        'related_posts_number' => '5',
        'related_posts_filter' => 'latest'
    );

    // allow changing default values
    $portfolio_defaults = apply_filters('volcanno_portfolio_options_defaults', $portfolio_defaults);

    // duplicate defaults
    $vlc_portfolio_options = $portfolio_defaults;

    // all post meta fields
    $post_meta = get_post_custom(get_the_ID());

    // override values from MetaBox fields
    $fields_override = isset($post_meta['pf_theme_options_override']) ? $post_meta['pf_theme_options_override'] : false;

    // merging default values with user defined
    if ($fields_override[0] == '1') {
        foreach ($portfolio_defaults as $key => $value) {
            $tmp_key = 'pf_' . $key;

            if (isset($post_meta[$tmp_key])) {
                $vlc_portfolio_options[$key] = $post_meta[$tmp_key][0];
            }
        }
    } else {
        if ($parent_page_id) {
            $parent_post_meta = get_post_custom($parent_page_id);

            foreach ($portfolio_defaults as $key => $value) {
                $tmp_key = 'pg_single_' . $key;

                if (isset($parent_post_meta[$tmp_key])) {
                    $vlc_portfolio_options[$key] = $parent_post_meta[$tmp_key][0];
                }
            }
        }
    }

    // escape button url
    $custom_button_url = esc_url($vlc_portfolio_options['button_url']);

    // get portfolio images
    $images = rwmb_meta('pf_image', 'type=image&size=full', get_the_ID());

    // image size in slider depends on selected option in Theme options
    if ($vlc_portfolio_options['slider_size'] == '4') {
        $slider_image_width = 360;
    } else if ($vlc_portfolio_options['slider_size'] == '6') {
        $slider_image_width = 555;
    } else if ($vlc_portfolio_options['slider_size'] == '7') {
        $slider_image_width = 653;
    } else if ($vlc_portfolio_options['slider_size'] == '8') {
        $slider_image_width = 750;
        $slider_image_height = 500;
    } else if ($vlc_portfolio_options['slider_size'] == '9') {
        $slider_image_width = 848;
    } else if ($vlc_portfolio_options['slider_size'] == '12') {
        $slider_image_width = 1140;
        $slider_image_height = 658;
    }

    // calculate image height as 78% of image width if height isn't specified in Theme options
    if (!empty($vlc_portfolio_options['slider_height'])) {
        $slider_image_height = $vlc_portfolio_options['slider_height'];
    } else {
        $slider_image_height = $slider_image_width * 0.78;
    }

    // if user is on retina device, double the size of image
    if ($vlc_is_retina) {
        $slider_image_width = 2 * $slider_image_width;
        $slider_image_height = 2 * intval($slider_image_height);
    }

    // content size calculated based on slider size
    $content_size = ($vlc_portfolio_options['slider_size'] == '12') ? 12 : 12 - intval($vlc_portfolio_options['slider_size']);

    // auto sliding
    $disable_auto_sliding = ($vlc_portfolio_options['slider_autoslide'] == '0' || empty($vlc_portfolio_options['slider_autoslide'])) ? 'true' : 'false';

    // hide slider arrows
    $show_slider_arrows = ( $vlc_portfolio_options['slider_hide_arrows'] != '0' || (count($images) <= 1)) ? 'false' : 'true';

    // get title section
    if ($vlc_portfolio_options['page_title'] == '1') {
        get_template_part('section', 'title');
    }

    // get custom fields
    $custom_fields = isset($post_meta['pf_custom_keyval']) ? $post_meta['pf_custom_keyval'] : false;
    if (!is_array($custom_fields[0]) && !empty($custom_fields)) {
        $custom_fields = unserialize($custom_fields[0]);
    }

    // Get Portfolio categories
    $terms = get_the_terms(get_the_ID(), 'portfolio-category');
    $terms_count = count($terms);
    $i = 0;
    foreach ($terms as $term) {
        $current_term = ++$i;
        $terms_slugs .= $term->slug . ($current_term != $terms_count ? ' ' : "");
        $terms_title .= '<li>' . $term->name . ($current_term != $terms_count ? ', ' . '</li>' : "");
    }
    ?>
    <?php if ($vlc_portfolio_options['slider_type'] == 'classic') { ?>
        <!-- .page-content start -->
        <section class="page-content">

            <!-- .container start -->
            <div class="container">

                <!-- .row start -->
                <div class="row">

                    <!-- .col-md-7 start -->
                    <div class="col-md-<?php echo intval($content_size) ?>">
                        <div class="portfolio-description">
                            <?php if ($vlc_portfolio_options['hide_categories'] != '1'): ?>
                                <ul class="clearfix portfolio-tags">
                                    <li><i class="fa fa-tags"></i></li>
                                    <?php echo wp_kses_post($terms_title) ?>
                                </ul><!-- .portfolio-tags end -->
                            <?php endif; ?>

                            <?php if ($vlc_portfolio_options['hide_title'] != '1'): ?>
                                <div class="simple-heading left">
                                    <h3><?php echo get_the_title() ?></h3>
                                </div>
                            <?php endif; ?>

                            <?php if (!empty($custom_fields) && !empty($custom_fields[0][0])): ?>
                                <ul class="clearfix portfolio-details-list">
                                    <?php
                                    foreach ($custom_fields as $field_key => $field_val) {
                                        ?>
                                        <li>
                                            <span class="mark"><?php echo wp_kses($field_val[0], $volcanno_theme_config['allowed_html_tags']) ?>: </span> <?php echo wp_kses($field_val[1], $volcanno_theme_config['allowed_html_tags']) ?>
                                        </li>
                                    <?php } ?>
                                </ul>
                            <?php endif; ?>

                            <?php if ($content_size < 12): ?>
                                <?php the_content(); ?>
                            <?php endif; ?>

                            <?php if ($vlc_portfolio_options['show_hide_button'] != '1'): ?>
                                <a class="btn btn-big" href="<?php echo esc_url($vlc_portfolio_options['button_url']) ?>">
                                    <span><?php echo esc_html($vlc_portfolio_options['button_text']) ?></span>
                                </a>
                            <?php endif; ?>
                        </div><!-- .portfolio-description end -->
                    </div>                    

                    <div class="col-md-<?php echo intval($vlc_portfolio_options['slider_size']) ?>">
                        <div class="nivo-wrapper">
                            <section id="post-slider" class="nivoSlider">
                                <?php
                                if (isset($images)):
                                    $caption = '';
                                    $captions_html = '';

                                    foreach ($images as $index => $image) {

                                        $image_url = esc_url($image['url']);

                                        $attachment = cma_get_attachment($image['ID']);

                                        $title = empty($attachment['caption']) ? $attachment['title'] : $attachment['caption'];
                                        if (!empty($title)) {
                                            $caption = "title='#slider-caption-{$image['ID']}'";
                                            $captions_html .= "<div id='slider-caption-{$image['ID']}' class='nivo-caption'>
                                                            <h3>{$title}</h3>
                                                        </div>";
                                        }
                                        $alt = empty($attachment['alt']) ? $attachment['title'] : $attachment['alt'];

                                        if ($vlc_portfolio_options['image_cropping'] == '1') {
                                            $params = array('width' => $slider_image_width, 'height' => $slider_image_height);
                                            $featured_image = bfi_thumb($image_url, $params);
                                        } else {
                                            $params = array('width' => $slider_image_width);
                                            $featured_image = bfi_thumb($image_url, $params);
                                        }
                                        
                                        $featured_image = esc_url($featured_image);
                                        $alt = esc_attr($image['title']);

                                        // slider thumbs
                                        $params = array('width' => 135, 'height' => 106);
                                        $thumb_image = bfi_thumb($image_url, $params);                                       

                                        echo "<img src='{$featured_image}' alt='{$alt}' data-thumb='{$thumb_image}' {$caption}/>";
                                    }
                                endif;
                                ?>
                            </section><!-- .nivoSlider end -->
                            <?php echo wp_kses($captions_html, array('div' => array('id' => array(), 'class' => array()), 'h3' => array())) ?>
                        </div>
                    </div>

                    <?php if ($content_size == 12): ?>
                        <div class="col-md-12">
                            <?php the_content(); ?>
                        </div>                
                    <?php endif; ?>

                </div><!-- .row end -->         

            </div><!-- .container end -->
        </section><!-- .page-content.parallax.pattern end -->
    <?php } ?>

    <?php
    if ($vlc_portfolio_options['slider_type'] == 'revolution') {
        get_template_part('content', 'slider');
        the_content();
    }
    ?>

    <?php
    if (!isset($post_meta['pg_single_related_hide']) || $post_meta['pg_single_related_hide'][0] != '1'):
        ?>
        <div class="page-content custom-background bkg-light-blue">
            <div class="container">

                <!-- .row start -->
                <div class="row">
                    <div class="col-md-12">
                        <section class="fancy-heading center">
                            <?php if (!empty($vlc_portfolio_options['related_posts_subtitle'])): ?><span class="heading-top"><?php echo esc_html($vlc_portfolio_options['related_posts_subtitle']) ?></span><?php endif; ?>
                            <?php if (!empty($vlc_portfolio_options['related_posts_title'])): ?><h2><?php echo esc_html($vlc_portfolio_options['related_posts_title']) ?></h2><?php endif; ?>                            
                        </section>
                    </div><!-- .col-md-12 end -->
                </div><!-- .row end -->            

                <!-- .row start -->
                <div class='row'> 
                    <article class="col-md-12">
                        <div class="carousel-container">
                            <div class="owl-carousel dots-carousel">
                                <?php
                                $id_counter = 1;
                                $index = 1;
                                $post_content = '';

                                // parameters for query
                                $items_count = $vlc_portfolio_options['related_posts_number'];
                                $filter = $vlc_portfolio_options['related_posts_filter'];

                                if ($filter == 'latest') {
                                    $args = array(
                                        'post_type' => 'pi_portfolio',
                                        'posts_per_page' => $items_count
                                    );
                                } else if ($filter == 'category') {
                                    $args = array('taxonomy' => 'portfolio-category', 'order' => 'ASC');
                                    $current_category = get_the_terms(get_the_ID(), 'portfolio-category');
                                    foreach ($current_category as $category) {
                                        $categories_list[] = $category->term_id;
                                    }

                                    $args = array(
                                        'post_type' => 'pi_portfolio',
                                        'posts_per_page' => $items_count,
                                        'tax_query' => array(
                                            array(
                                                'taxonomy' => 'portfolio-category',
                                                'field' => 'id',
                                                'terms' => $categories_list
                                            )
                                        )
                                    );
                                } else if ($filter == 'random') {
                                    $args = array(
                                        'post_type' => 'pi_portfolio',
                                        'posts_per_page' => $items_count,
                                        'orderby' => 'rand'
                                    );
                                }

                                // The Query
                                $wp_query = new WP_Query($args);

                                // The Loop
                                while ($wp_query->have_posts()) : $wp_query->the_post();

                                    $post_id = get_the_ID();
                                    $post_title = get_the_title();
                                    $i = 0;
                                    $terms_title = "";
                                    $post_permalink = get_permalink();
                                    // Get Portfolio categories
                                    $terms = get_the_terms($post_id, 'portfolio-category');
                                    $terms_count = count($terms);

                                    foreach ($terms as $term) {
                                        $terms_title .= "<li>" . $term->name . ( ++$i != $terms_count ? ' ' : "") . "</li>";
                                    }

                                    // get all uploaded image IDs for this portfolio item
                                    $images = rwmb_meta('pf_image', 'type=image&size=full', $post_id);
                                    $image_url = reset($images);
                                    $first_item_id = $image_url['ID'];
                                    $image_url = $image_url['url'];

                                    // if user is on retina device, double the size of image
                                    if ($vlc_is_retina) {
                                        $params = array('width' => 776, 'height' => 614);
                                    } else {
                                        $params = array('width' => 388, 'height' => 307);
                                    }

                                    $cropped_image = bfi_thumb($image_url, $params);
                                    ?>

                                    <div class="owl-item">
                                        <figure class="portfolio-item-container">
                                            <div class="portfolio-img zoom-hover">
                                                <img src="<?php echo esc_url($cropped_image) ?>" alt=""/>

                                                <div class="mask-style-1">
                                                    <div class="mask"></div>

                                                    <div class="zoom">
                                                        <a href="<?php echo esc_url($post_permalink); ?>"></a>
                                                    </div>
                                                </div>
                                            </div><!-- .portfolio-img end -->

                                            <figcaption>
                                                <a class="title" href="<?php echo esc_url($post_permalink); ?>"><?php echo wp_kses($post_title, $volcanno_theme_config['allowed_html_tags']); ?></a>
                                                <ul class="portfolio-tags"><?php echo wp_kses_post($terms_title) ?></ul>
                                            </figcaption>
                                        </figure><!-- .portfolio-item end -->
                                    </div><!-- .owl-item end -->
                                    <?php
                                    $id_counter++;

                                endwhile;
                                ?>                             
                            </div>
                        </div>
                    </article><!-- .col-md-12 end -->
                </div><!-- .row end -->          
            </div><!-- .container end -->
        </div><!-- .page-content.custom-background end -->
    <?php endif; ?>

    <?php
    if ($volcanno_options['portfolio_single_cta'] == '1'):
        $cta_title = $volcanno_options['portfolio_single_cta_title'];

        $cta_subtitle = $volcanno_options['portfolio_single_cta_subtitle'];

        $cta_button_text = esc_html($volcanno_options['portfolio_single_cta_button_text']);
        $cta_button_url = esc_url($volcanno_options['portfolio_single_cta_button_url']);
        ?>
        <div class="page-content parallax dark parallax-colored">
            <!-- .container start -->
            <div class="container">
                <!-- .row start -->
                <div class="row">
                    <div class="col-md-12">
                        <!-- .call-to-action start -->
                        <div class="call-to-action clearfix">
                            <div class="text">
                                <h2><?php echo wp_kses($cta_title, $volcanno_theme_config['allowed_html_tags']) ?></h2>
                                <p><?php echo wp_kses($cta_subtitle, $volcanno_theme_config['allowed_html_tags']) ?></p>
                            </div>

                            <a href='<?php echo esc_url($cta_button_url) ?>' class='btn btn-medium white empty'>
                                <span><?php echo wp_kses($cta_button_text, $volcanno_theme_config['allowed_html_tags']) ?></span>
                            </a>
                        </div><!-- .call-to-action end -->
                    </div><!-- .col-md-12 end -->
                </div><!-- .row end -->
            </div><!-- .container end -->
        </div>
    <?php endif; ?>


    <script>
        jQuery(document).ready(function ($) {
            'use strict';

            // init slider
            jQuery('#post-slider').nivoSlider({
                controlNav: false,
                directionNav: <?php echo esc_js($show_slider_arrows) ?>,
                manualAdvance: <?php echo esc_js($disable_auto_sliding) ?>,
                controlNavThumbs: false
            });

            jQuery('.dots-carousel').owlCarousel({
                items: 3,
                loop: true,
                margin: 30,
                responsiveClass: true,
                mouseDrag: true,
                responsive: {
                    0: {
                        items: 1,
                        loop: true,
                        autoplay: true,
                        autoplayTimeout: 3000,
                        autoplayHoverPause: true,
                        responsiveClass: true,
                        dots: true,
                        nav: false
                    },
                    600: {
                        items: 2,
                        loop: true,
                        autoplay: true,
                        autoplayTimeout: 3000,
                        autoplayHoverPause: true,
                        responsiveClass: true,
                        dots: true,
                        nav: false
                    },
                    1000: {
                        items: 3,
                        loop: true,
                        autoplay: true,
                        autoplayTimeout: 3000,
                        autoplayHoverPause: true,
                        responsiveClass: true,
                        mouseDrag: true,
                        dots: true,
                        nav: false
                    }
                }
            });
        });

    </script>
    <?php
endif; // end of the loop.
get_footer();
?>
