<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("CMA_Shortcodes_Grids")) {

    class CMA_Shortcodes_Grids extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = __('Grids', 'pi-cma');
            $settings['description'] = __('Grid elements for content.', 'pi-cma');
            $settings['shortcode'] = 'cma_grid';
            $settings['nested'] = 0;
            $settings['hide_in_ui'] = 1;

            $this->shortcode_settings = $settings;
        }

        function enqueue_stylesheets() {
            /* style */
            wp_enqueue_style('cma-styles-bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), "1.0");
        }

        function shortcode_html($atts = array(), $content = null) {
            global $post;
            $html = '';
            $css = "style='";
            $grid_classes = array();

            extract(shortcode_atts(array(
                'size' => '12',
                'row' => '0',
                'image_bkg' => '',
                'color_bkg' => '',
                'classes' => '',
                'margin_top' => '',
                'margin_bottom' => '',
                'padding_top' => '',
                'padding_bottom' => '',
                'padding_left' => '',
                'padding_right' => '',
                'dark_bkg' => ''
                            ), $atts, 'cma_grid'));
            
            if (!empty($classes)){
                // sanitize classes
                $html_classes = apply_filters('cma_sanitize_user_defined_classes', $classes);
                
                // merge with existing classes
                $grid_classes = array_merge($grid_classes, $html_classes);
            }

            // check if user set custom color or image background
            if (!empty($image_bkg)) {
                $attachment = wp_get_attachment_url($image_bkg, 'full');

                // check if parallax is active and add additional styles
                $css .= "background: url({$attachment});";

                $grid_classes[] = 'custom-background image-background';
            } else if (!empty($color_bkg)) {
                $css .= "background: {$color_bkg};";
                $grid_classes[] = 'custom-background color-background';
            }
            
            // check if section is dark so we can adjust content appearance by adding class 'dark'
            if ($dark_bkg == '1') {
                $grid_classes[] = 'dark';
            }

            // top and bottom margin            
            if ($margin_bottom != "")
                $css .= "margin-bottom:{$margin_bottom}px;";

            if ($margin_top != "")
                $css .= "margin-top:{$margin_top}px;";

            // paddings
            if ($padding_top != "")
                $css .= "padding-top:{$padding_top}px;";

            if ($padding_bottom != "")
                $css .= "padding-bottom:{$padding_bottom}px;";

            if ($padding_left != "")
                $css .= "padding-left:{$padding_left}px;";

            if ($padding_right != "")
                $css .= "padding-right:{$padding_right}px;";

            $css .= "'";

            $html .= "<div class='col-md-{$size} " . join(' ', $grid_classes) . "' {$css}>" . do_shortcode($content) . "</div>";

            return $html;
        }

    }

}
?>
