<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("CMA_Shortcodes_Section")) {

    class CMA_Shortcodes_Section extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = __('Section', 'pi-cma');
            $settings['description'] = __('Section element for separating content.', 'pi-cma');
            $settings['shortcode'] = 'cma_section';
            $settings['nested'] = 0;
            $settings['hide_in_ui'] = 1;

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $post;
            $html = '';
            $parallax_classes = '';
            $stellar_bg_ratio = '';
            $custom_background = '';
            $video_html = '';

            extract(shortcode_atts(array(
                'id' => '',
                'background_type' => 'image',
                'image_bkg' => '',
                //'att_src' => '',
                'color_bkg' => '',
                'bkg_video' => '',
                'bkg_video_poster' => '',
                'bkg_video_autoplay' => '0',
                'bkg_video_controls' => '0',
                'bkg_video_loop' => '0',
                'bkg_video_width' => '',
                'bkg_video_height' => '',
                'classes' => '',
                'parallax' => false,
                'background_size' => 'cover',
                'background_repeat' => 'repeat',
                'full_width' => '0',
                'remove_container_padding' => '0',
                'margin_top' => '',
                'margin_bottom' => '',
                'custom_id' => '',
                'dark_bkg' => ''
                            ), $atts, 'cma_section'));

            $css = "style='";

            // custom section ID
            $custom_id = !empty($custom_id) ? "id='" . $custom_id . "'" : '';

            // custom classes
            $section_classes = array('page-content');

            if (!empty($classes)) {
                // sanitize classes
                $html_classes = apply_filters('cma_sanitize_user_defined_classes', $classes);

                // merge with existing classes
                $section_classes = array_merge($section_classes, $html_classes);
            }

            // parallax settings
            $data_stellar_background_ratio = cma_get_settings('data-stellar-background-ratio');
            $parallax_settings = cma_get_settings('section-parallax');

            // check if user set custom color or image background
            if ($background_type == 'image') {
                if (!empty($image_bkg)) {
                    $attachment = wp_get_attachment_url($image_bkg, 'full');

                    // set background size
                    if ($background_size == "100") {
                        $background_size = '100% 100%';
                    } else if ($background_size == "75" || $background_size == "50" || $background_size == "25") {
                        $background_size = $background_size . "%";
                    }

                    // check if parallax is active and add additional styles
                    if ($parallax_settings && $parallax == '1') {
                        $css .= "background-image: url({$attachment});background-size: {$background_size}; background-attachment: fixed;background-repeat: {$background_repeat};";
                    } else {
                        $css .= "background-image: url({$attachment});background-size: {$background_size};background-repeat: {$background_repeat};";
                    }

                    $section_classes[] = 'custom-background image-background';
                }

                if (!empty($color_bkg)) {
                    $css .= "background-color: {$color_bkg};";
                    $section_classes[] = !in_array('custom-background', $section_classes) ? 'custom-background color-background' : false;
                }

                // check if parallax background is enabled
                if ($parallax_settings && $parallax == '1') {
                    $section_classes[] = 'parallax parallax-' . $id;
                    $stellar_bg_ratio = "data-stellar-background-ratio='{$data_stellar_background_ratio}'";
                }
            } else if ($background_type == 'video' && !empty($bkg_video)) {
                
                $video_parameters = array();

                // sanitize url
                $bkg_video = esc_url($bkg_video);

                // video dimensions
                $video_parameters[] = !empty($bkg_video_width) ? "width='{$bkg_video_width}'" : '';
                $video_parameters[] = !empty($bkg_video_height) ? "height='{$bkg_video_height}'" : '';

                // video poster
                if (!empty($bkg_video_poster)) {
                    $poster_image = wp_get_attachment_url($bkg_video_poster, 'full');
                    $video_parameters[] = "poster='{$poster_image}'";
                }
                
                if($bkg_video_autoplay == '1'){
                    $video_parameters[] = 'autoplay';
                }
                
                if($bkg_video_controls == '1'){
                    $video_parameters[] = 'controls';
                }
                
                if($bkg_video_loop == '1'){
                    $video_parameters[] = 'loop';
                }

                // video html
                $video_html = "<video " . join(' ', $video_parameters) . " class='bg-video' preload='none' src='{$bkg_video}'></video>";

                // additional classes
                array_push($section_classes, 'video-background', 'bg-video-container');
            }

            // check if section is dark so we can adjust content appearance by adding class 'dark'
            if ($dark_bkg == '1') {
                $section_classes[] = 'dark';
            }

            // top and bottom margin            
            if ($margin_bottom != "")
                $css .= "margin-bottom: {$margin_bottom}px;";

            if ($margin_top != "")
                $css .= "margin-top: {$margin_top}px;";

            $css .= "'";

            // open new section with additional classes
            $html .= "<section class='" . join(' ', $section_classes) . "' {$css} {$stellar_bg_ratio} {$custom_id}>";

            // check if full width section is enabled
            if ($full_width == '1') {
                if ($remove_container_padding == '1') {
                    $html .= "<section class='container-fluid' style='padding-left: 0; padding-right: 0;'>";
                } else {
                    $html .= "<section class='container-fluid'>";
                }
            } else {
                $html .= "<section class='container'>";
            }

            if ($background_type == 'video' && !empty($bkg_video)) {
                $html .= $video_html;
            }

            $html .= do_shortcode($content) . "</section></section>";

            return $html;
        }

    }

}
?>
