<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

abstract class Content_Maker_Shortcodes {

    public $shortcode_settings = array();
    public $shortcode_options = array();
    static $active_row;
    static $section_open = false;
    static $new_section = false;
    static $current_grid_index = 1;

    // class constructor
    function __construct() {
        $this->shortcode_block_info();
    }

    // call methods
    function init_shortcode() {
        //add_action('the_posts', $this->wrap_enqueue_scripts());
        // load stylesheets
        if (method_exists($this, 'enqueue_stylesheets') && !is_admin()) {
            add_action('wp_enqueue_scripts', array($this, 'enqueue_stylesheets'));
        }

        // load scripts
        if (method_exists($this, 'enqueue_scripts') && !is_admin()) {
            add_action('wp_enqueue_scripts', array($this, 'wrap_enqueue_scripts'));
        }

        // register settings filter
        $this->add_settings_filter();

        // register shortcode
        $this->register_shortcode();

        // call options fields function
        $this->shortcode_options_fields();

        // add filter for shortcode options fields
        $this->filter_shortcode_options_fields();
    }

    public function wrap_enqueue_scripts() {
        $post_id = cma_get_current_page_id();
        $post = get_post($post_id);

        // shortcode string to search
        $shortcode = "[" . $this->shortcode_settings['shortcode'];



        // if current shortcode is in content, laod it's scripts
        if (!empty($post) && strpos($post->post_content, $shortcode) !== false) {
            $this->enqueue_scripts();
        }
    }

    /*
     * method of child class that will contain array with information for 
     * generating visual block 
     */

    abstract function shortcode_block_info();

    /*
     * method of child class that will contain html that will be outputed in
     * frontend
     */

    abstract function shortcode_html();

    /*
     * method for registering options fields for shortcode
     */

    public function shortcode_options_fields() {
        
    }

    /*
     * method for registering shortcode
     */

    protected function register_shortcode() {

        // register shortcode
        add_shortcode($this->shortcode_settings['shortcode'], array(&$this, 'wrap_shortcode_html'));

        // if shortcode is nested, register all nested shortcodes
        if (!empty($this->shortcode_settings['nested'])) {
            foreach ($this->shortcode_settings['nested'] as $shortcode) {
                if (method_exists($this, $shortcode)) {
                    add_shortcode($shortcode, array(&$this, $shortcode));
                }
            }
        }
    }

    /*
     * method for adding settings filter
     */

    public function add_settings_filter() {
        $shortcode = $this->shortcode_settings['shortcode'];
        $this->shortcode_settings = apply_filters("{$shortcode}_settings", $this->shortcode_settings);
    }

    /*
     * method that wraps shortcode html function
     */

    public function wrap_shortcode_html($atts = array(), $content = null, $shortcode_name) {
        global $grid_counter;

        $post_id = cma_get_current_page_id();

        if (empty($post_id))
            return;

        $top_margin = 0;
        $bottom_margin = 0;
        $margins_style = '';
        $classes = array();
        $top_margin_style = '';
        $bottom_margin_style = '';
        $shortcode = '';

        // reset query to main query because new query might be created in shortcodes
        wp_reset_query();

        if (isset($atts['cma_id']) && !empty($atts['cma_id'])) {
            // get data from database
            $data = get_post_meta($post_id, 'cma_layout_data', true);
            // decode data back to array
            $data = json_decode($data, true);
            // find shortcode in array by id
            $position = cma_shortcode_by_id($data, $atts['cma_id']);
            // get options
            $shortcode_options = $data['rows'][$position[0]]['grids'][$position[1]]['elements'][$position[2]]['options'];
            // merge first array with array that holds options
            $new_atts = array_merge($atts, $shortcode_options);

            // remove empty values
            $new_atts = array_filter($new_atts, array($this, 'filter_shortcode_atts'));
        } else {
            $new_atts = $atts;
        }

        // if we are in new row, reset grid counter
        if ($shortcode_name == 'cma_row') {
            $grid_counter = 0;
        }

        // if this is grid shortcode, check if grid is empty and add additional class
        if ($shortcode_name == 'cma_grid') {

            // fetch data if not available
            if (empty($data)) {
                // get data from database
                $data = get_post_meta($post_id, 'cma_layout_data', true);
                // decode data back to array
                $data = json_decode($data, true);
            }

            // row id
            $row_id = $atts['row'];
            // get options
            $grids = $data['rows'][$row_id]['grids'][$grid_counter];

            // append class "empty" if there aren't any elements in grid
            if (!isset($grids['elements']) || isset($grids['elements']) && empty($grids['elements'])) {
                if (isset($new_atts['classes'])) {
                    $new_atts['classes'] = $new_atts['classes'] . " empty";
                } else {
                    $new_atts['classes'] = "empty";
                }
            }

            // increase grid counter, i.e. grid's position in row
            $grid_counter++;
        }

        // top marging set for element
        if (isset($new_atts['cma_spc_margin_top']) && $new_atts['cma_spc_margin_top'] != "") {
            $top_margin = $new_atts['cma_spc_margin_top'];
            $top_margin = is_numeric($top_margin) ? $top_margin : "";
            $top_margin_style = "margin-top: " . $top_margin . "px;";
        }

        // bottom margin set for element
        if (isset($new_atts['cma_spc_margin_bottom']) && $new_atts['cma_spc_margin_bottom'] != "") {
            $bottom_margin = $new_atts['cma_spc_margin_bottom'];
            $bottom_margin = is_numeric($bottom_margin) ? $bottom_margin : "";
            $bottom_margin_style = "margin-bottom: " . $bottom_margin . "px;";
        }

        if ($top_margin != "" || $bottom_margin != "") {
            $margins_style = "style='{$top_margin_style}{$bottom_margin_style}'";
        }

        // custom classes
        if (!empty($new_atts['cma_spc_classes'])) {

            // sanitize classes
            $html_classes = apply_filters('cma_sanitize_user_defined_classes', $new_atts['cma_spc_classes']);

            // merge with existing classes
            $classes = array_merge($classes, $html_classes);
        }

        $animations = cma_get_settings('elements-animation');

        if (!empty($new_atts['cma_spc_animation']) && $new_atts['cma_spc_animation'] != 'disabled' && $animations) {
            $classes[] = 'triggerAnimation';
            $classes[] = 'animated';

            $wrapper = "<div class='" . join(' ', $classes) . "' data-animate='{$new_atts['cma_spc_animation']}' {$margins_style}>";

            // start buffering an check if we received any content
            // we are actually checking if shortcode echoes value instead of returning
            ob_start();
            $this->shortcode_html($new_atts, $content);
            $shortcode .= ob_get_clean();

            if (empty($buffer)) {
                $shortcode = $this->shortcode_html($new_atts, $content);
            }
            $wrapper .= $shortcode;
            $wrapper .= "</div>";

            return $wrapper;
        } else {
            if (!empty($margins_style) || !empty($classes)) {
                $wrapper = "<div {$margins_style} class='" . join(' ', $classes) . "'>" . $this->shortcode_html($new_atts, $content) . "</div>";
            } else {
                $wrapper = $this->shortcode_html($new_atts, $content);
            }

            return $wrapper;
        }
    }

    /*
     * remove empty shortcode attributes
     */

    public function filter_shortcode_atts($attribute) {
        return ($attribute !== NULL && $attribute !== FALSE && $attribute !== '');
    }

    /*
     * filter shortcode options
     */

    public function filter_shortcode_options_fields() {
        // create unique filter name
        $filter_name = "cma_shortcode_" . $this->shortcode_settings['shortcode'] . "_options";

        // apply filters
        $this->shortcode_options = apply_filters($filter_name, $this->shortcode_options);
    }

}

// class that enabled compatibility between previous and current version of CM
abstract class Content_Manager_Shortcodes extends Content_Maker_Shortcodes {
    
}

?>
