<?php
/*
 * PAGE OPTIONS FORM
 * 
 * Get HTML form for page options
 */

function cma_get_page_options_form() {

    $id = 1;

    $options = array(
        'body_classes' => array(
            'type' => 'text',
            'title' => __('Body classes', 'pi-cma'),
            'description' => __('Classes that will be added only to the body of this page/post. (Comma separated)', 'pi-cma')
        )
    );

    $options = apply_filters('cma_page_options_fields', $options);

    echo get_options_field_html($options, 'page_options', $id, false);

    exit;
}

add_action('wp_ajax_cma_page_options_form', 'cma_get_page_options_form');

/*
 * ROWS DIALOG FORM
 * 
 * Get HTML form for rows dialog
 */

function cma_get_row_form() {

    $id = $_REQUEST['id'];

    $options = array(
        'grid_number' => array(
            'type' => 'image_radio',
            'title' => __('Grids Number', 'pi-cma'),
            'description' => __('Change number of grids in row.', 'pi-cma'),
            'options' => array(
                '1' => array('src' => PICMA_DIR_URL . 'images/grid12.jpg', 'description' => __('Grid 12 (100%)', 'pi-cma')),
                '2' => array('src' => PICMA_DIR_URL . 'images/grid6.jpg', 'description' => __('Grid 6 (50%)', 'pi-cma')),
                '3' => array('src' => PICMA_DIR_URL . 'images/grid4.jpg', 'description' => __('Grid 4 (33%)', 'pi-cma')),
                '4' => array('src' => PICMA_DIR_URL . 'images/grid3.jpg', 'description' => __('Grid 3 (25%)', 'pi-cma'))
            )
        ),
        'margin_top' => array(
            'type' => 'number',
            'title' => __('Top Margin', 'pi-cma'),
            'description' => __('Enter top margin.', 'pi-cma')
        ),
        'margin_bottom' => array(
            'type' => 'number',
            'title' => __('Bottom Margin', 'pi-cma'),
            'description' => __('Enter bottom margin.', 'pi-cma')
        ),
        'class' => array(
            'type' => 'text',
            'title' => __('Custom classes', 'pi-cma'),
            'description' => __('Comma separated custom classes. List of available classes can be found in Documentation.', 'pi-cma'),
            'options' => array('mt-0' => 'Margin top: 0', 'mb-0' => 'Margin bottom: 0', 'pt-0' => 'Padding top: 0', 'pb-0' => 'Padding bottom: 0', 'row-equal-height' => 'Make rows same height')
        )
    );

    $options = apply_filters('cma_row_options_fields', $options);

    echo get_options_field_html($options, 'row_options', $id, false);

    exit;
}

add_action('wp_ajax_cma_row_options_form', 'cma_get_row_form');

/*
 * GRIDS DIALOG FORM
 * 
 * Get HTML form for grid dialog
 */

function cma_get_grid_form() {

    $id = $_REQUEST['id'];

    $options = array(
        'image_bkg' => array(
            'type' => 'image',
            'title' => __('Background Image', 'pi-cma'),
            'description' => __('Set grid background image.', 'pi-cma')
        ),
        'color_bkg' => array(
            'type' => 'color_picker',
            'title' => __('Color background', 'pi-cma'),
            'description' => __('Set grid color background.', 'pi-cma')
        ),
        'dark_bkg' => array(
            'type' => 'checkbox',
            'title' => 'Dark Background',
            'description' => 'Enable this to adjust content appearance on dark background.'
        ),
        'padding_top' => array(
            'type' => 'number',
            'title' => __('Top Padding', 'pi-cma'),
            'description' => __('Enter top padding.', 'pi-cma')
        ),
        'padding_bottom' => array(
            'type' => 'number',
            'title' => __('Bottom Padding', 'pi-cma'),
            'description' => __('Enter bottom padding.', 'pi-cma')
        ),
        'padding_left' => array(
            'type' => 'number',
            'title' => __('Left Padding', 'pi-cma'),
            'description' => __('Enter top padding.', 'pi-cma')
        ),
        'padding_right' => array(
            'type' => 'number',
            'title' => __('Right Padding', 'pi-cma'),
            'description' => __('Enter bottom padding.', 'pi-cma')
        ),
        'margin_top' => array(
            'type' => 'number',
            'title' => __('Top Margin', 'pi-cma'),
            'description' => __('Enter top margin.', 'pi-cma')
        ),
        'margin_bottom' => array(
            'type' => 'number',
            'title' => __('Bottom Margin', 'pi-cma'),
            'description' => __('Enter bottom margin.', 'pi-cma')
        ),
        'classes' => array(
            'type' => 'text',
            'title' => __('Custom classes', 'pi-cma'),
            'description' => __('Comma separated custom classes. List of available classes can be found in Documentation.', 'pi-cma'),
            'options' => array('mt-0' => 'Margin top: 0', 'mb-0' => 'Margin bottom: 0', 'pt-0' => 'Padding top: 0', 'pb-0' => 'Padding bottom: 0', 'clearfix' => 'Clear floats')
        )
    );

    $options = apply_filters('cma_grid_options_fields', $options);

    echo get_options_field_html($options, 'grid_options', $id, false);

    exit;
}

add_action('wp_ajax_cma_grid_options_form', 'cma_get_grid_form');



/*
 * SECTIONS DIALOG FORM
 * 
 * Get HTML form for sections dialog
 */

function cma_get_section_options_form() {

    $id = $_REQUEST['id'];

    $options = array(
        'background_type' => array(
            'type' => 'select',
            'title' => 'Background Type',
            'description' => 'Select what type of background do you want.',
            'options' => array(
                'none' => 'None',
                'image' => 'Image/Color',
                'video' => 'Video'
            ),
            'default' => 'image'
        ),
        'image_bkg' => array(
            'type' => 'image',
            'title' => __('Background Image', 'pi-cma'),
            'description' => __('Set section background image.', 'pi-cma'),
            'condition' => array('background_type', '==', 'image')
        ),
        'color_bkg' => array(
            'type' => 'color_picker',
            'title' => __('Color background', 'pi-cma'),
            'description' => __('Set section color background.', 'pi-cma'),
            'condition' => array('background_type', '==', 'image')
        ),
        'bkg_video' => array(
            'type' => 'text',
            'title' => __('Video URL', 'pi-cma'),
            'description' => __('Enter section background video url.', 'pi-cma'),
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_poster' => array(
            'type' => 'image',
            'title' => __('Video poster', 'pi-cma'),
            'description' => __('Image that will be shown before video is loaded.', 'pi-cma'),
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_autoplay' => array(
            'type' => 'checkbox',
            'title' => 'Autoplay',
            'description' => 'Enable video autoplay.',
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_loop' => array(
            'type' => 'checkbox',
            'title' => 'Loop',
            'description' => 'Enable this to repeat video.',
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_controls' => array(
            'type' => 'checkbox',
            'title' => 'Controls',
            'description' => 'Show video contrls.',
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_width' => array(
            'type' => 'number',
            'title' => __('Video Width', 'pi-cma'),
            'description' => __('Enter section background video width.', 'pi-cma'),
            'condition' => array('background_type', '==', 'video')
        ),
        'bkg_video_height' => array(
            'type' => 'number',
            'title' => __('Video Height', 'pi-cma'),
            'description' => __('Enter section background video height.', 'pi-cma'),
            'condition' => array('background_type', '==', 'video')
        ),
        'parallax' => array(
            'type' => 'checkbox',
            'title' => 'Parallax',
            'description' => 'Enable Parallax effect on this section.',
            'condition' => array('background_type', '==', 'image')
        ),
        'background_size' => array(
            'type' => 'select',
            'title' => 'Background Size',
            'description' => 'Select how background image will stretch.',
            'options' => array(
                'auto' => 'Auto',
                'cover' => 'Cover',
                'contain' => 'Contain',
                '100' => '100% 100%',
                '75' => '75%',
                '50' => '50%',
                '25' => '25%'
            ),
            'default' => 'cover',
            'condition' => array('background_type', '==', 'image')
        ),
        'background_repeat' => array(
            'type' => 'select',
            'title' => 'Background Size',
            'description' => 'Select how background image will stretch.',
            'options' => array(
                'repeat' => 'Repeat',
                'repeat-x' => 'Repeat-x',
                'repeat-y' => 'Repeat-y',
                'no-repeat' => 'No Repeat'
            ),
            'default' => 'repeat',
            'condition' => array('background_type', '==', 'image')
        ),
        'dark_bkg' => array(
            'type' => 'checkbox',
            'title' => 'Dark Background',
            'description' => 'Enable this to adjust content appearance on dark background.'
        ),
        'full_width' => array(
            'type' => 'checkbox',
            'title' => 'Full Width',
            'description' => 'Set Section as full width.'
        ),
        'remove_container_padding' => array(
            'type' => 'checkbox',
            'title' => 'Remove Container Paddings',
            'description' => 'Remove left and right paddings on container to achieve real full width.',
            'condition' => array('full_width', '==', '1')
        ),
        'margin_top' => array(
            'type' => 'number',
            'title' => __('Top Margin', 'pi-cma'),
            'description' => __('Enter top margin.', 'pi-cma')
        ),
        'margin_bottom' => array(
            'type' => 'number',
            'title' => __('Bottom Margin', 'pi-cma'),
            'description' => __('Enter bottom margin.', 'pi-cma')
        ),
        'custom_id' => array(
            'type' => 'text',
            'title' => __('ID', 'pi-cma'),
            'description' => __('Unique ID for this section.', 'pi-cma')
        ),
        'classes' => array(
            'type' => 'text',
            'title' => __('Classes', 'pi-cma'),
            'description' => __('Custom section classes. List of available classes can be found in Documentation.', 'pi-cma'),
            'options' => array('mt-0' => 'Margin top: 0', 'mb-0' => 'Margin bottom: 0', 'pt-0' => 'Padding top: 0', 'pb-0' => 'Padding bottom: 0')
        )
    );

    $options = apply_filters('cma_section_options_fields', $options);

    echo get_options_field_html($options, 'section_options', $id, false);

    exit;
}

add_action('wp_ajax_cma_section_options_form', 'cma_get_section_options_form');

/*
 * ELEMENT OPTIONS DIALOG FORM
 * 
 * Ajax callback for element options form
 */

function cma_get_element_options_form() {

    global $wp_widget_factory, $cma_registered_shortcodes, $post;
    $name = $_REQUEST['name'];
    $type = $_REQUEST['type'];
    $id = $_REQUEST['id'];

    // check that nonce is valid
    if (!wp_verify_nonce($_REQUEST['nonce'], "save_ajax") || empty($name) || empty($type) || empty($id)) {
        exit("Error!");
    }

    if ($type == 'shortcode') {
        // arrange shortcodes in array
        $shortcodes = cma_to_array($cma_registered_shortcodes);

        // get shortcodes in array
        $pos = cma_recursive_array_search($name, $shortcodes);

        // get shortcodes options
        $shortcode_options = $shortcodes[$pos[0]]['shortcode_options'];

        // get shortcode HTML
        echo get_options_field_html($shortcode_options, $name, $id, false);
    } else if ($type == 'widget') {
        $widget = new $name();
        $widget->id = 'wgtid';
        $widget->number = $id;

        // get options fields
        ob_start();
        $widget->form(array());
        $form = ob_get_clean();

        // get field name
        $name = $widget->get_field_name('');
        // remove empty brackets at the end
        $name_clean = substr($name, 0, strrpos($name, '[]'));
        // replace name in all occurances with new name
        $form = str_replace($name_clean, "elements[{$id}]", $form);

        echo $form;
    }

    echo cma_get_element_special_options($id);

    exit;
}

add_action('wp_ajax_cma_element_options_form', 'cma_get_element_options_form');

/*
 * ELEMENT ADDITIONAL OPTIONS DIALOG FORM
 * 
 * Special options like Animation is added for each element.
 */

function cma_get_element_special_options($id) {

    // required prefix for all special options
    $prefix = "cma_spc_";

    // additional options array
    $special_options = array(
        "{$prefix}animation" => array(
            'type' => 'select',
            'title' => __('Element animation', 'pi-cma'),
            'description' => __('Element will animate when you scroll to it.', 'pi-cma'),
            'options' => array(
                'disabled' => 'Animation disabled',
                'Attention-Seekers' => array(
                    'bounce' => "Bounce",
                    'flash' => "Flash",
                    'pulse' => "Pulse",
                    'rubberBand' => "Rubber Band",
                    'shake' => "Shake",
                    'swing' => "Swing",
                    'tada' => "Tada",
                    'wobble' => "Wobble"
                ),
                'Bouncing Entrance' => array(
                    'bounceIn' => "Bounce In",
                    'bounceInDown' => "Bounce In Down",
                    'bounceInLeft' => "Bounce In Left",
                    'bounceInRight' => "Bounce In Right",
                    'bounceInUp' => "Bounce In Up"
                ),
                'Bouncing Exits' => array(
                    'bounceOut' => "Bounce Out",
                    'bounceOutDown' => "Bounce Out Down",
                    'bounceOutLeft' => "Bounce Out Left",
                    'bounceOutRight' => "Bounce Out Right",
                    'bounceOutUp' => "Bounce Out Up"
                ),
                'Fading Entrance' => array(
                    'fadeIn' => "Fade In",
                    'fadeInDown' => "Fade In Down",
                    'fadeInDownBig' => "Fade In Down Big",
                    'fadeInLeft' => "Fade In Left",
                    'fadeInLeftBig' => "Fade In Left Big",
                    'fadeInRight' => "Fade In Right",
                    'fadeInRightBig' => "Fade In Right Big",
                    'fadeInUp' => "Fade In Up",
                    'fadeInUpBig' => "Fade In Up Big"
                ),
                'Fading Exits' => array(
                    'fadeOut' => "Fade Out",
                    'fadeOutDown' => "Fade Out Down",
                    'fadeOutDownBig' => "Fade Out Down Big",
                    'fadeOutLeft' => "Fade Out Left",
                    'fadeOutLeftBig' => "Fade Out Left Big",
                    'fadeOutRight' => "Fade Out Right",
                    'fadeOutRightBig' => "Fade Out Right Big",
                    'fadeOutUp' => "Fade Out Up",
                    'fadeOutUpBig' => "Fade Out Up Big"
                ),
                'Flippers' => array(
                    'flip' => "Flip",
                    'flipInX' => "Flip In-X",
                    'flipInY' => "Flip In-Y",
                    'flipOutX' => "Flip Out-X",
                    'flipOutY' => "Flip Out-Y"
                ),
                'Lightspeed' => array(
                    'lightSpeedIn' => "Light Speed In",
                    'lightSpeedOut' => "Light Speed Out"
                ),
                'Rotating Entrances' => array(
                    'rotateIn' => "Rotate In",
                    'rotateInDownLeft' => "Rotate In Down Left",
                    'rotateInDownRight' => "Rotate In Down Right",
                    'rotateInUpLeft' => "Rotate In Up Left",
                    'rotateInUpRight' => "Rotate In Up Right"
                ),
                'Rotating Exits' => array(
                    'rotateOut' => "Rotate Out",
                    'rotateOutDownLeft' => "Rotate Out Down Left",
                    'rotateOutDownRight' => "Rotate Out Down Right",
                    'rotateOutUpLeft' => "Rotate Out Up Left",
                    'rotateOutUpRight' => "Rotate Out Up Right"
                ),
                'Sliding Entrances' => array(
                    'slideInUp' => "Slide In Up",
                    'slideInDown' => "Slide In Down",
                    'slideInLeft' => "Slide In Left",
                    'slideInRight' => "Slide In Right",
                    'slideOutLeft' => "Slide Out Left",
                    'slideOutRight' => "Slide Out Right",
                    'slideOutUp' => "Slide Out Up"
                ),
                'Sliding Exits' => array(
                    'slideOutUp' => "Slide Out Up",
                    'slideOutDown' => "Slide Out Down",
                    'slideOutLeft' => "Slide Out Left",
                    'slideOutRight' => "Slide Out Right",
                ),
                'Zoom Entrances' => array(
                    'zoomIn' => "Zoom In",
                    'zoomInDown' => "Zoom In Down",
                    'zoomInLeft' => "Zoom In Left",
                    'zoomInRight' => "Zoom In Right",
                    'zoomInUp' => "Zoom In Up"
                ),
                'Zoom Exits' => array(
                    'zoomOut' => "Zoom out",
                    'zoomOutDown' => "Zoom Out Down",
                    'zoomOutLeft' => "Zoom Out Left",
                    'zoomOutRight' => "Zoom Out Right",
                    'zoomOutUp' => "Zoom Out Up"
                ),
                'Specials' => array(
                    'hinge' => "Hinge",
                    'rollIn' => "Roll In",
                    'rollOut' => "Roll Out"
                )
            )
        ),
        "{$prefix}margin_top" => array(
            'type' => 'number',
            'title' => __('Top margin', 'pi-cma'),
            'description' => __('Add top margin to the element.', 'pi-cma')
        ),
        "{$prefix}margin_bottom" => array(
            'type' => 'number',
            'title' => __('Bottom margin', 'pi-cma'),
            'description' => __('Add bottom margin to the element.', 'pi-cma')
        ),
        "{$prefix}classes" => array(
            'type' => 'text',
            'title' => __('Classes', 'pi-cma'),
            'description' => __('Custom element classes. Separate with space. List of available classes can be found in Documentation.', 'pi-cma'),
            'options' => array('mt-0' => 'Margin top: 0', 'mb-0' => 'Margin bottom: 0', 'pt-0' => 'Padding top: 0', 'pb-0' => 'Padding bottom: 0')
        )
    );
    ?>
    <div class="cma-element-additional-options">
        <h4><?php _e('Special options', 'pi-cma') ?></h4>
        <?php echo get_options_field_html($special_options, 'element_special', $id, false); ?>
    </div>
    <?php
}

/*
 * Returns HTML for all options in shortcode
 */
global $group_depth, $field_id, $field_name, $group_name_set, $field_id_base, $field_name_base;
$group_depth = 0;
$group_name_set = false;

function get_options_field_html($shortcode_options, $shortcode_name, $id, $group) {
    global $group_depth, $field_id, $field_name, $group_name_set, $field_id_base, $field_name_base;
    $new_option = true;

    ob_start();
    foreach ($shortcode_options as $name => $option) {

        $condition = '';
        $condition_class = '';

        if ($name == 'count')
            continue;

        $field_label = esc_html($option['title']);
        $field_description = isset($option['description']) ? esc_html($option['description']) : '';
        $class = $shortcode_name;

        // construct field name and id based on it's position in array
        if ($group) {

            // this is first level element, not group
            if ($group_depth == 1 && $option['type'] != 'group') {
                $field_name_base = "elements[{$id}][" . $group . "][1]";
                $field_id_base = "elements-" . $shortcode_name . "-{$id}-" . $group . "-1";

                $field_id = "elements-" . $shortcode_name . "-{$id}-" . $group . "-1-" . $name;
                $field_name = "elements[{$id}][" . $group . "][1][" . $name . "]";

                // this is first level group element
            } else if ($group_depth == 1 & $option['type'] == 'group') {
                $field_name_base = "elements[{$id}][" . $group . "][1]";

                $field_id = "elements-" . $shortcode_name . "-{$id}-" . $group . "-1";
                $field_name = "elements[{$id}][" . $group . "][1]";

                // this is second level (subgroup) element, not group
            } else if ($group_depth == 2 && $option['type'] != 'group') {

                if ($new_option) {
                    $field_name_base .= "[" . $group . "][1]";
                    $field_id_base .= "-" . $group . "-1";
                    $new_option = false;
                }

                $field_id = $field_id_base . "-" . $name;
                $field_name = $field_name_base . "[" . $name . "]";
            }

            // this is regular element on default level
        } else {
            $field_id = "elements-" . $shortcode_name . "-{$id}-" . $name;
            $field_name = "elements[{$id}][" . $name . "]";
        }

        // check for conditionals
        if (!empty($option['condition']) && count($option['condition'] == 3)) {
            $condition = "data-cond-id='{$option['condition'][0]}'";
            $condition .= " data-cond-operation='{$option['condition'][1]}'";
            $condition .= " data-cond-val='{$option['condition'][2]}'";

            $condition_class = 'has-condition';
        }

        // field placeholder
        $placeholder = !empty($option['placeholder']) ? $option['placeholder'] : '';

        // default value
        $default = !empty($option['default']) ? $option['default'] : '';
        ?>
        <div class="option-container">
            <?php if ($option['type'] != 'group'): ?>
                <label for="<?php echo $field_id; ?>"><?php echo $field_label ?>:</label>
                <div class="value-container">
                <?php endif; ?>               
                <?php
                switch ($option['type']) {
                    case 'text' :
                        if (isset($option['options']) && !empty($option['options'])) {
                            $autocomplete = "data-role='tagsinput'";
                            ?>
                            <select id="<?php echo $field_id . '-autocomplete'; ?>" style="display: none;">
                                <?php foreach ($option['options'] as $key => $val) {
                                    ?>
                                    <option value="<?php echo $key ?>"><?php echo $val ?></option>
                                    <?php
                                }
                                ?>
                            </select>
                            <?php
                        } else {
                            $autocomplete = '';
                        }
                        ?><input type="text" class="widefat <?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" value="<?php echo $default ?>" <?php if (empty($autocomplete)) echo "placeholder='{$placeholder}'" ?> <?php echo $condition ?> <?php echo $autocomplete ?>/><?php
                        break;
                    case 'textarea' :
                        if (empty($option['options']['height']))
                            $option['options']['height'] = 6;
                        ?><textarea class="widefat <?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" rows="<?php echo $option['options']['height'] ?>" <?php echo $condition ?> placeholder="<?php echo $placeholder ?>"><?php echo $default ?></textarea><?php
                        break;
                    case 'number' :
                        $min = isset($option['options']['min']) ? $option['options']['min'] : '';
                        $max = isset($option['options']['max']) ? $option['options']['max'] : '';
                        $step = isset($option['options']['step']) ? $option['options']['step'] : '';
                        ?><input type="number" class="<?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" value="<?php echo $default ?>" min="<?php echo $min ?>" max="<?php echo $max ?>" step="<?php echo $step ?>" placeholder="<?php echo $placeholder ?>" <?php echo $condition ?>/><?php
                        break;
                    case 'checkbox' :
                        ?><input type="checkbox" class="<?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" <?php checked($default, '1', true) ?> <?php echo $condition ?>/><?php
                        break;
                    case 'select':
                        ?>
                        <select id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" class="<?php echo $condition_class ?>" <?php echo $condition ?>>
                            <?php
                            if (!isset($option['data'])) {
                                $current_group = '';
                                foreach ($option['options'] as $gk => $gv) {
                                    if (is_array($gv) && $gk != $current_group) {
                                        $current_group = $gk;
                                        ?>
                                        <optgroup label='<?php echo str_replace("-", " ", $current_group); ?>'>
                                            <?php foreach ($gv as $k => $v): ?>
                                                <option value="<?php echo esc_attr($k) ?>" <?php selected($default, $k, true) ?>><?php echo esc_html($v) ?></option>
                                            <?php endforeach; ?>
                                        </optgroup>
                                        <?php
                                    }else {
                                        ?>
                                        <option value="<?php echo esc_attr($gk) ?>" <?php selected($default, $gk, true) ?>><?php echo esc_html($gv) ?></option>
                                        <?php
                                    }
                                    ?>

                                    <?php
                                }
                            } else {

                                // check if parameter data is set
                                if (is_array($option['data'])) {
                                    $select = $option['data']['select'];
                                } else {
                                    $select = $option['data'];
                                }

                                switch ($select) {
                                    case "posts":

                                        // default values
                                        $post_type = isset($option['data']['post_type']) ? $option['data']['post_type'] : 'post';
                                        $taxonomy = isset($option['data']['taxonomy']) ? $option['data']['taxonomy'] : '';
                                        $category = isset($option['data']['category']) ? $option['data']['category'] : '';

                                        // set query arguments
                                        $args = array(
                                            "posts_per_page" => -1,
                                            "post_type" => $post_type,
                                            'tax_query' => array(
                                                array(
                                                    'taxonomy' => $taxonomy,
                                                    'field' => 'slug',
                                                    'terms' => $category
                                                )
                                            )
                                        );

                                        // query
                                        $posts = get_posts($args);

                                        // loop through items and echo options
                                        foreach ($posts as $post) {
                                            echo "<option value='{$post->ID}'>{$post->post_title}</option>";
                                        }

                                        break;
                                    case "pages":
                                        $args = array(
                                            "posts_per_page" => -1
                                        );

                                        $pages = get_pages($args);

                                        echo "<option value='-1'>" . __('Disabled', 'pi-cma') . "</option>";
                                        foreach ($pages as $page) {
                                            echo "<option value='{$page->ID}'>{$page->post_title}</option>";
                                        }
                                        break;

                                    case "terms":
                                        $taxonomy = isset($option['data']['taxonomy']) ? $option['data']['taxonomy'] : 'category';

                                        $terms = get_terms($taxonomy);
                                        foreach ($terms as $term) {
                                            echo "<option value='{$term->term_id}'>{$term->name}</option>";
                                        }

                                        break;
                                    default:
                                        ?>
                                        <option value=""><?php _e('Values not set!', 'pi-cma') ?></option>
                                        <?php
                                        break;
                                }
                            }
                            ?>
                        </select>
                        <?php
                        break;
                    case 'radio':
                        echo "<div class='radio-container'>";

                        // check if default value is set and if it's not set first value
                        if (empty($default)) {
                            reset($option['options']);
                            $default = key($option['options']);
                        }

                        // loop through options set
                        foreach ($option['options'] as $k => $v) {

                            $fid = $field_id . "-" . $k;
                            ?>
                            <p><input type="radio" class="<?php echo $condition_class ?>" id="<?php echo $fid ?>" name="<?php echo $field_name ?>" value="<?php echo $k ?>" <?php checked($default, $k, true) ?> <?php echo $condition ?>/> <label for="<?php echo $fid ?>"><?php echo $v ?></label></p>
                            <?php
                        }

                        echo "</div>";
                        break;
                    case 'editor':
                        $content = '';
                        $editor_id = "cma-tinymce-editor-{$id}-text";
                        $settings = array(
                            'quicktags' => array(
                                'buttons' => 'b,i,ul,ol,li,link,close'
                            )
                        );
                        $toggle_buttons_extra_class = "wp-toggle-buttons";
                        $media_buttons_extra_class = "wp-media-buttons";
                        $type = 'tmce';
                        $text = $default;
                        echo "<input id='cma-tinymce-editor-{$id}-type' name='cma-tinymce-editor-{$id}-type' type='hidden' value='tmce' />";
                        ?>
                        <br/>
                        <div class="editor_toggle_buttons hide-if-no-js <?php echo $toggle_buttons_extra_class; ?>">
                            <a id="cma-tinymce-editor-<?php echo $id ?>-html"<?php if ($type == 'html') { ?> class="active"<?php } ?>><?php _e('HTML', 'pi-cma'); ?></a>
                            <a id="cma-tinymce-editor-<?php echo $id ?>-tmce"<?php if ($type == 'tmce') { ?> class="active"<?php } ?>><?php _e('Visual', 'pi-cma'); ?></a>
                        </div>
                        <div class="editor_media_buttons hide-if-no-js <?php echo $media_buttons_extra_class; ?>">
                            <?php do_action('media_buttons'); ?>
                        </div>
                        <div class="editor_container">
                            <textarea class="widefat <?php echo $condition_class ?>" rows="20" cols="40" id="<?php echo $editor_id; ?>" name="<?php echo $field_name; ?>" <?php echo $condition ?> data-type="wysiwyg"><?php echo $text; ?></textarea>
                        </div>
                        <?php
                        do_action('cma_add_metabox_editor_scripts');
                        break;
                    case 'group':
                        $group_depth++;
                        $group_name_set = false;
                        ?>                
                        <div class="shortcode-options-group <?php if ($group_depth > 1) echo "subgroup" ?> <?php echo $condition_class ?>" <?php echo $condition ?>>
                            <?php echo get_options_field_html($option['options'], $shortcode_name, $id, $name); ?>
                        </div>
                        <input type="hidden" id="<?php echo $field_id; ?>-count" name="elements[<?php echo $id ?>][<?php echo $name ?>][count]" class="shortcode-group-count" value="0"/>
                        <a href="#" class="duplicate-options-group"><?php _e('Add More', 'pi-cma') ?></a>  <a href="#" class="remove-options-group"><?php _e('Remove', 'pi-cma') ?></a>
                        <?php
                        break;
                    case 'image':
                        ?>
                        <div class="shortcode-options-thumb-container">
                            <div class="shortcode-options-thumbs"></div>
                            <a href="" class="shortcode-options-thumb-button button"><?php _e('Choose Image', 'pi-cma') ?></a>
                            <input id="<?php echo $field_id; ?>" class="shortcode-options-thumb-id <?php echo $condition_class ?>" name="<?php echo $field_name; ?>" type="hidden" value="" data-type="image" <?php echo $condition ?>/>
                        </div>               

                        <?php
                        break;
                    case "image_radio":
                        ?>
                        <div class="cma-image-radio-container">
                            <?php foreach ($option['options'] as $key => $val): ?>
                                <img src="<?php echo $val['src'] ?>" title="<?php echo $val['description'] ?>" alt="<?php echo $val['description'] ?>" data-value="<?php echo $key ?>" class="<?php if ($default == $key) echo "active"; ?>"/>
                            <?php endforeach; ?>                        
                        </div>
                        <input type="hidden" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" class="cma-image-radio-value <?php echo $condition_class ?>" value="<?php echo $default ?>" data-type="imageradio" <?php echo $condition ?>/>
                        <?php
                        break;
                    case "color_picker":
                        ?>
                        <input type="text" class="cma-color-picker <?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" value="<?php echo $default ?>" <?php echo $condition ?>/>
                        <?php
                        break;
                    case "icon_picker":
                        ?>
                        <select class="cma-icon-picker <?php echo $condition_class ?>" id="<?php echo $field_id; ?>" name="<?php echo $field_name; ?>" <?php echo $condition ?>>
                            <option value="" selected="selected"><?php _e('No icon', 'pi-cma') ?></option>
                            <?php
                            $default_font = false;
                            if (!empty($option['options'])) {
                                $icons = $option['options'];
                            } else {
                                $path = PICMA_DIR_URL . "/assets/font-awesome/css/font-awesome.css";
                                $icons = cma_get_font_awesome_classes($path);
                                $default_font = true;
                            }

                            foreach ($icons as $key => $icon) {
                                ?>
                                <option value="<?php echo $default_font ? 'fa ' : '' ?><?php echo $icon ?>" <?php selected($default, $icon, true) ?>><?php echo $icon ?></option>
                                <?php
                            }
                            ?>
                        </select>
                        <?php
                        break;
                }

                if (!empty($option['description']))
                    echo '<small class="description">' . esc_html($option['description']) . '</small>';
                ?></div>
                <?php if ($option['type'] != 'group'): ?>
            </div>
            <?php
        endif;
    }
    $html = ob_get_clean();

    return $html;
}
?>