/**
 * Script that inits WYSIWYG Editor.
 */

// TinyMCE initialization parameters
var tinyMCEPreInit;
// Current editor
var wpActiveEditor;

(function($) {

    // Activate visual editor
    function cma_activate_visual_editor(id) {

        $('#' + id).addClass("mceEditor");

        // check if tinyMCE exists and try to init new aditor
        if (typeof (tinyMCE) == "object" && typeof (tinyMCE.execCommand) == "function") {
            cma_deactivate_visual_editor(id);
            tinyMCEPreInit.mceInit[id] = tinyMCEPreInit.mceInit['cma-tinymce-editor'];
            tinyMCEPreInit.mceInit[id]["elements"] = id;
            try {
                // Instantiate new TinyMCE editor by duplicating options from hidden editor "cma-tinymce-editor"
                tinymce.init(
                        tinymce.extend({},
                                tinyMCEPreInit.mceInit['cma-tinymce-editor'],
                                tinyMCEPreInit.mceInit[id],
                                {selector: "#" + id}));

            } catch (e) {
                alert(e);
            }
        }
    }

    // Deactivate visual editor
    function cma_deactivate_visual_editor(id) {

        // check if tinyMCE exists and remove Editor by id
        if (typeof (tinyMCE) == "object" && typeof (tinyMCE.execCommand) == "function") {
            if (tinyMCE.get(id) != null && typeof (tinyMCE.get(id)) == "object" && typeof (tinyMCE.get(id).getContent) == "function") {
                var content = tinyMCE.get(id).getContent();
                tinyMCE.execCommand("mceRemoveEditor", false, id);
                
                // remove empty paragraphs with break tag
                var cleanedContent = content.replace(/<p>\s*<\/p>/gi, '<br />');
                $('textarea#' + id).val(cleanedContent);
            }
        }
    }

    // Activate visual editor upon dialog opening
    $(document).on('elementsdialogopen', function(event, element, dialog) {

        dialog.find('input[id^=cma-tinymce-editor][id$=type][value=tmce]').each(function() {
            dialog.find('a[id^=cma-tinymce-editor][id$=tmce]').click();
        });


    });

    // Deactivate visual editor upon dialog saving ("Done" button)
    $(document).on('elementsdialogclose', function(event, element, dialog) {
        var $text_area = dialog.find('textarea[id^=cma-tinymce-editor]');
        if ($text_area.length > 0) {

            var id = $text_area.attr('id');
            cma_deactivate_visual_editor(id);
        }
    });

    $(document).ready(function() {

        // handle clicking on Visual tab
        $(document).on('click', 'a[id^=cma-tinymce-editor][id$=tmce]', function(event) {
            var $dialog = $(this).closest('div.cma-admin-dialog');
            $dialog.find('input[id^=cma-tinymce-editor][id$=type]').val('tmce');
            $(this).addClass('active');
            $dialog.find('a[id^=cma-tinymce-editor][id$=html]').removeClass('active');
            cma_activate_visual_editor($dialog.find('textarea[id^=cma-tinymce-editor]').attr('id'));
        });

        // handle clicking on HTML tab
        $(document).on('click', 'a[id^=cma-tinymce-editor][id$=html]', function(event) {
            var $dialog = $(this).closest('div.cma-admin-dialog');
            $dialog.find('input[id^=cma-tinymce-editor][id$=type]').val('html');
            $(this).addClass('active');
            $dialog.find('a[id^=cma-tinymce-editor][id$=tmce]').removeClass('active');
            cma_deactivate_visual_editor($dialog.find('textarea[id^=cma-tinymce-editor]').attr('id'));
        });

        // Set wpActiveEditor variables needed for media library
        $(document).on('click', '.editor_media_buttons a', function() {
            var $dialog = $(this).closest('div.cma-admin-dialog');
            wpActiveEditor = $dialog.find('textarea[id^=cma-tinymce-editor]').attr('id');
        });
    });

})(jQuery); // end self-invoked wrapper function